package com.chinaitop.depot;

import com.google.common.base.Function;
import com.google.common.base.Optional;
import com.google.common.base.Predicate;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.RequestHandler;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

@Configuration
@EnableSwagger2
public class SwaggerConfig {

	//@Value("${eureka.instance.hostname}")
	private String eureka_ip = "192.167.12.3";

    // 定义分隔符,配置Swagger多包
    private static final String business = "com.chinaitop.depot.business.controller;";
    private static final String safeProduce = "com.chinaitop.depot.safeProduce.controller;";
    private static final String storage = "com.chinaitop.depot.storage.controller;";
    private static final String registration = "com.chinaitop.depot.registrationTable.controller;";
    private static final String risk = "com.chinaitop.depot.risk.controller;";
    private static final String fumigation = "com.chinaitop.depot.fumigation.controller;";
    private static final String spt = "com.chinaitop.depot.sptData.controller;";
    private static final String warningAndAlarm = "com.chinaitop.depot.warningAndAlarm.controller;";
    /**
     * 1.添加包path
     * 2.append(静态变量)
     *
     * @return
     */
    private static String addPackage() {
        StringBuilder countServer = new StringBuilder();
        countServer.append(business)
        			.append(safeProduce)
        			.append(storage)
        			.append(registration)
        			.append(risk)
        			.append(fumigation)
        			.append(spt)
        			.append(warningAndAlarm);
        return countServer.toString();
    }

    @Bean
    public Docket createRestApi() {
        return new Docket(DocumentationType.SWAGGER_2)
                .apiInfo(apiInfo())
                .select()
                .apis(basePackage(addPackage()))
                .paths(PathSelectors.any())
                .build();
    }

    private ApiInfo apiInfo() {
    	String url = "http://"+eureka_ip+":9001";
        return new ApiInfoBuilder()
                .title("智能粮库管理平台api接口文档")
                .description("药品管理,安全生产,安全检查")
                .termsOfServiceUrl(url.trim())
                .version("1.0")
                .build();
    }

    /**
     * 重写basePackage方法，使能够实现多包访问
     *
     * @param
     * @author jinhaoxun
     * @date 2019/1/26
     */
    public static Predicate<RequestHandler> basePackage(final String basePackage) {
        return input -> declaringClass(input).transform(handlerPackage(basePackage)).or(true);
    }

    private static Function<Class<?>, Boolean> handlerPackage(final String basePackage) {
        return input -> {
            // 循环判断匹配
            for (String strPackage : basePackage.split(";")) {
                boolean isMatch = input.getPackage().getName().startsWith(strPackage);
                if (isMatch) {
                    return true;
                }
            }
            return false;
        };
    }

    private static Optional<? extends Class<?>> declaringClass(RequestHandler input) {
        return Optional.fromNullable(input.declaringClass());
    }

}
