package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugCheck;
import com.chinaitop.depot.business.model.BusinessDrugCheckDetail;
import com.chinaitop.depot.business.model.BusinessDrugCheckExample;
import com.chinaitop.depot.business.service.BusinessDrugCheckDetailService;
import com.chinaitop.depot.business.service.BusinessDrugCheckService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂盘点.
 * <p>Title: BusinessDrugCheckController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月23日 下午5:15:46
 */
@RestController
@RequestMapping(value = "/depot/business/drugCheck")
@Api(value = "BusinessDrugCheckController", description = "药剂盘点")
public class BusinessDrugCheckController {

    @Resource
    private BusinessDrugCheckService drugCheckService;
    @Autowired
    private BusinessDrugCheckDetailService drugCheckDetailService;

    /**
     * 申请列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query")
    })
    public PageInfo<BusinessDrugCheck> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer drugKind, Integer drugName, String startTime, String endTime) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        //查询条件
        BusinessDrugCheckExample example = new BusinessDrugCheckExample();
        BusinessDrugCheckExample.Criteria createCriteria = example.createCriteria();
        if (null != drugKind)
            createCriteria.andDrugKindEqualTo(drugKind);
        if (null != drugName)
            createCriteria.andDrugNameEqualTo(drugName);
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime))
            createCriteria.andCreateTimeBetween(ParameterUtil.string2date(startTime), ParameterUtil.string2date(endTime));
        if (orgId != null)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        example.setOrderByClause("id desc");
        List<BusinessDrugCheck> list = drugCheckService.queryByExample(example);
        PageInfo<BusinessDrugCheck> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> edit(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            BusinessDrugCheck drugCheck = drugCheckService.findById(id);
            modelMap.put("drugCheck", drugCheck);
            List<BusinessDrugCheckDetail> detailList = drugCheckDetailService.getListByZid(id);
            modelMap.put("detailList", detailList);
        }
        return modelMap;
    }

    /**
     * 保存
     *
     * @param drugCheckJson       主表信息json
     * @param drugCheckDetailJson 子表信息json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugCheckJson", value = "主表信息", paramType = "query"),
            @ApiImplicitParam(name = "drugCheckDetailJson", value = "子表信息", paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public Map<String, Object> save(String drugCheckJson, String drugCheckDetailJson, Integer userId, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugCheck drugCheck = (BusinessDrugCheck) mapper.readValue(drugCheckJson, BusinessDrugCheck.class);
            List<BusinessDrugCheckDetail> drugCheckDetailList = null;
            if (drugCheckDetailJson != null) {
                drugCheckDetailList = (List<BusinessDrugCheckDetail>) mapper.readValue(drugCheckDetailJson, new TypeReference<List<BusinessDrugCheckDetail>>() {
                });
            }
            if (drugCheck.getId() == null) {
                Map<String, Object> returnMap = drugCheckService.add(drugCheck, drugCheckDetailList, userId, orgId);
                if (returnMap != null && returnMap.get("error") != null) {
                    modelMap.put("status", "error");
                    modelMap.put("msg", returnMap.get("error"));
                    return modelMap;
                }
            } else {
                // 盘点没有修改.
                //drugCheckService.update(drugCheck, drugCheckDetailList);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }
}
