package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugDestroy;
import com.chinaitop.depot.business.model.BusinessDrugDestroyExample;
import com.chinaitop.depot.business.service.BusinessDrugDestroyService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂销毁
 * <p>Title: BusinessDrugDestroyController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年10月25日 下午5:38:13
 */
@RestController
@RequestMapping(value = "/depot/business/drugDestroy")
@Api(value = "BusinessDrugDestroyController", description = "药剂销毁")
public class BusinessDrugDestroyController {

    @Resource
    private BusinessDrugDestroyService drugDestroyService;

    /**
     * 列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "destroyType", value = "销毁类型", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query")
    })
    public PageInfo<BusinessDrugDestroy> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, String destroyType, String startTime, String endTime) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 封装查询对象
        BusinessDrugDestroyExample example = new BusinessDrugDestroyExample();
        BusinessDrugDestroyExample.Criteria criteria = example.createCriteria();
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime))
            criteria.andCreateTimeBetween(ParameterUtil.string2date(startTime), ParameterUtil.string2date(endTime));
        if (StringUtils.isNotBlank(destroyType))
            criteria.andDestroyTypeEqualTo(destroyType);
        if (orgId != null)
            criteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        // 排序
        example.setOrderByClause("id desc");
        List<BusinessDrugDestroy> list = drugDestroyService.queryByExample(example);
        // 返回分页对象
        PageInfo<BusinessDrugDestroy> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }


    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public BusinessDrugDestroy edit(Integer id) {
        BusinessDrugDestroy drugDestroy = new BusinessDrugDestroy();
        if (id != null) {
            drugDestroy = drugDestroyService.findById(id);
        }
        return drugDestroy;
    }

    /**
     * 保存
     *
     * @param drugDestroyJson 药剂销毁json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParam(name = "drugDestroyJson", value = "保存主表信息", paramType = "query")
    public Map<String, Object> save(String drugDestroyJson) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugDestroy drugDestroy = mapper.readValue(drugDestroyJson, BusinessDrugDestroy.class);
            if (drugDestroy.getId() == null) {
                drugDestroyService.add(drugDestroy);
            } else {
                drugDestroyService.update(drugDestroy);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }


    /**
     * 删除
     *
     * @param id 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<>();
        if (id != null) {
            drugDestroyService.remove(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }


}
