package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugInfo;
import com.chinaitop.depot.business.model.BusinessDrugInfoKey;
import com.chinaitop.depot.business.service.BusinessDrugInfoService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂信息维护.
 * <p>Title: BusinessDrugInfoController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月21日 下午5:41:18
 */
@RestController
@RequestMapping(value = "/depot/business/drugInfo")
@Api(value = "BusinessDrugInfoController", description = "药剂信息维护")
public class BusinessDrugInfoController {

    @Resource
    private BusinessDrugInfoService drugInfoService;

    /**
     * 列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "isEffective", value = "状态(0:未使用,1:使用中)", paramType = "query")
    })
    public PageInfo<BusinessDrugInfo> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, BusinessDrugInfo businessDrugInfo) {
        List<BusinessDrugInfo> list = drugInfoService.getList(request, pageNum, pageSize, businessDrugInfo);
        PageInfo<BusinessDrugInfo> pageInfo = new PageInfo<BusinessDrugInfo>(list);
        return pageInfo;
    }

    /**
     * 生效列表.获取使用中列表
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getEffectiveList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "生效列表", notes = "获取使用中列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10")
    })
    public PageInfo<BusinessDrugInfo> getEffectiveList(HttpServletRequest request, Integer pageNum, Integer pageSize, BusinessDrugInfo businessDrugInfo) {
        List<BusinessDrugInfo> list = drugInfoService.getEffectiveList(request, pageNum, pageSize, businessDrugInfo);
        PageInfo<BusinessDrugInfo> pageInfo = new PageInfo<BusinessDrugInfo>(list);
        return pageInfo;
    }


    /**
     * 根据联合主键查询.
     *
     * @param drugInfoKey 联合主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据主键获取信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
    })
    public BusinessDrugInfo edit(@Validated BusinessDrugInfoKey drugInfoKey, BindingResult bindingResult) {
        BusinessDrugInfo drugInfo = new BusinessDrugInfo();
        if (bindingResult.hasErrors()) {
            return drugInfo;
        }
        drugInfo = drugInfoService.findById(drugInfoKey);
        return drugInfo;
    }

    /**
     * 保存
     *
     * @param drugInfoJson 药剂入库json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugInfoJson", value = "保存信息", paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public Map<String, Object> save(String drugInfoJson, Integer userId, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugInfo drugInfo = mapper.readValue(drugInfoJson, BusinessDrugInfo.class);
            if (drugInfo.getId() == null) {
                Map<String, Object> returnMap = drugInfoService.add(drugInfo, userId, orgId);
                if (returnMap != null && returnMap.get("error") != null) {
                    modelMap.put("status", "error");
                    modelMap.put("msg", returnMap.get("error"));
                    return modelMap;
                }
            } else {
                modelMap = drugInfoService.update(drugInfo);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }


    /**
     * 删除
     *
     * @param drugInfoKey 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
    })
    public Map<String, Object> remove(@Validated BusinessDrugInfoKey drugInfoKey, BindingResult bindingResult) {
        Map<String, Object> modelMap = new HashMap<>();
        if (bindingResult.hasErrors()) {
            modelMap.put("status", "error");
            return modelMap;
        }
        drugInfoService.remove(drugInfoKey);
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 生效.
     *
     * @param id 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/effective", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id修改信息(默认修改为生效信息)", notes = "根据id查询信息(默认修改为生效信息)")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> effective(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            drugInfoService.effective(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

}
