package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugPurchase;
import com.chinaitop.depot.business.model.BusinessDrugPurchaseDetail;
import com.chinaitop.depot.business.model.BusinessDrugPurchaseExample;
import com.chinaitop.depot.business.service.BusinessDrugPurchaseService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂采购申请
 * <p>Title: BusinessDrugPurchaseController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年10月25日 下午5:38:37
 */
@RestController
@RequestMapping(value = "/depot/business/drugPurchase")
@Api(value = "BusinessDrugPurchaseController", description = "药剂采购申请")
public class BusinessDrugPurchaseController {

    @Resource
    private BusinessDrugPurchaseService drugPurchaseService;

    /**
     * 申请列表.
     *
     * @param pageNum   页码
     * @param pageSize  每页显示条数
     * @param startTime 查询申请开始日期
     * @param endTime   查询申请结束日期
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query")
    })
    public PageInfo<BusinessDrugPurchase> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, String startTime, String endTime) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        BusinessDrugPurchaseExample example = new BusinessDrugPurchaseExample();
        BusinessDrugPurchaseExample.Criteria criteria = example.createCriteria();
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime))
            criteria.andCreateTimeBetween(ParameterUtil.string2datetime(startTime + " 00:00:00"), ParameterUtil.string2datetime(endTime + " 23:59:59"));
        if (orgId != null)
            criteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        example.setOrderByClause("id desc");
        List<BusinessDrugPurchase> list = drugPurchaseService.queryByExample(example);
        PageInfo<BusinessDrugPurchase> pageInfo = new PageInfo<BusinessDrugPurchase>(list);
        return pageInfo;
    }

    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public BusinessDrugPurchase edit(Integer id) {
        BusinessDrugPurchase drugPurchase = new BusinessDrugPurchase();
        if (id != null) {
            drugPurchase = drugPurchaseService.findById(id);
        }
        return drugPurchase;
    }

    /**
     * 保存
     *
     * @param drugPurchaseJson       主表信息json
     * @param drugPurchaseDetailJson 子表信息json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @SuppressWarnings("all")
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugPurchaseJson", value = "保存主表信息", paramType = "form"),
            @ApiImplicitParam(name = "drugPurchaseDetailJson", value = "保存子表信息", paramType = "form"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "form")
    })
    public Map<String, Object> save(String drugPurchaseJson, String drugPurchaseDetailJson, Integer userId, Integer orgId, HttpServletRequest request) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugPurchase drugPurchase = (BusinessDrugPurchase) mapper.readValue(drugPurchaseJson, BusinessDrugPurchase.class);
            List<BusinessDrugPurchaseDetail> drugPurchaseDetailList = null;
            if (drugPurchaseDetailJson != null) {
                drugPurchaseDetailList = (List<BusinessDrugPurchaseDetail>) mapper.readValue(drugPurchaseDetailJson, new TypeReference<List<BusinessDrugPurchaseDetail>>() {
                });
            }
            if (drugPurchase.getId() == null) {
                Integer retuenId = drugPurchaseService.add(drugPurchase, drugPurchaseDetailList, userId, orgId);
                modelMap.put("id", retuenId);
            } else {
                drugPurchaseService.update(drugPurchase, drugPurchaseDetailList);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }


    /**
     * 删除
     *
     * @param id
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<>();
        if (id != null) {
            drugPurchaseService.remove(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 更新审批状态
     *
     * @param id
     * @param auditUserId 已选择的审批人userId
     * @return
     */
    @RequestMapping(value = "/updateData", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    public Map<String, Object> updatePurchaseData(Integer id, String userInfoJson, String orgInfoJson, String auditUserId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (null != id) {
            drugPurchaseService.updatePurchaseData(id, userInfoJson, orgInfoJson, auditUserId);
            modelMap.put("status", "success");
        } else {
            modelMap.put("msg", "提交失败");
        }
        return modelMap;
    }
}
