package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugPurchaseDetail;
import com.chinaitop.depot.business.model.BusinessDrugPurchaseDetailExample;
import com.chinaitop.depot.business.model.vo.BusinessDrugPurchaseAuditVO;
import com.chinaitop.depot.business.service.BusinessDrugPurchaseDetailService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂采购子表
 * <p>Title: BusinessDrugPurchaseDetailController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年10月25日 下午5:40:29
 */
@RestController
@RequestMapping(value = "/depot/business/drugPurchaseDetail")
@Api(value = "BusinessDrugPurchaseDetailController", description = "药剂采购子表")
public class BusinessDrugPurchaseDetailController {

    @Resource
    private BusinessDrugPurchaseDetailService drugPurchaseDetailService;

    /**
     * 列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "zid", value = "主表id", paramType = "query")
    })
    public PageInfo<BusinessDrugPurchaseDetail> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer zid) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        BusinessDrugPurchaseDetailExample example = new BusinessDrugPurchaseDetailExample();
        BusinessDrugPurchaseDetailExample.Criteria createCriteria = example.createCriteria();
        createCriteria.andZidEqualTo(zid);
        if (orgId != null)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        List<BusinessDrugPurchaseDetail> list = drugPurchaseDetailService.queryByExample(example);
        PageInfo<BusinessDrugPurchaseDetail> pageInfo = new PageInfo<BusinessDrugPurchaseDetail>(list);
        return pageInfo;
    }


    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public BusinessDrugPurchaseDetail edit(Integer id) {
        BusinessDrugPurchaseDetail drugPurchaseDetail = new BusinessDrugPurchaseDetail();
        if (id != null) {
            drugPurchaseDetail = drugPurchaseDetailService.findById(id);
        }
        return drugPurchaseDetail;
    }

    /**
     * 保存
     *
     * @param drugPurchaseDetailJson 药剂采购详情json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParam(name = "drugPurchaseDetailJson", value = "保存信息", paramType = "query")
    public Map<String, Object> save(String drugPurchaseDetailJson) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugPurchaseDetail drugPurchaseDetail = mapper.readValue(drugPurchaseDetailJson, BusinessDrugPurchaseDetail.class);
            if (drugPurchaseDetail.getId() == null) {
                drugPurchaseDetailService.add(drugPurchaseDetail);
            } else {
                drugPurchaseDetailService.update(drugPurchaseDetail);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }


    /**
     * 删除
     *
     * @param id 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            drugPurchaseDetailService.remove(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 药剂采购详情-获取审批通过的数据 create_unit借用为药剂规格型号,depot_id借用为药剂信息id
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/auditOkGitList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "审批已通过列表", notes = "审批已通过列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public PageInfo auditOkGitList(Integer pageNum, Integer pageSize, Integer orgId) {
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        List<BusinessDrugPurchaseDetail> list = drugPurchaseDetailService.auditOkGitList(orgId);
        PageInfo<BusinessDrugPurchaseDetail> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }
}
