package com.chinaitop.depot.business.controller;

import com.chinaitop.depot.business.model.BusinessDrugRestore;
import com.chinaitop.depot.business.model.BusinessDrugRestoreDetail;
import com.chinaitop.depot.business.model.BusinessDrugRestoreExample;
import com.chinaitop.depot.business.service.BusinessDrugRestoreService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 药剂归还
 * @create 2018-09-15 11:41
 */
@RestController
@RequestMapping(value = "/depot/business/drugRestore")
@Api(value = "BusinessDrugRestoreController", description = "药剂归还")
public class BusinessDrugRestoreController {

    @Resource
    private BusinessDrugRestoreService restoreService;

    /**
     * 条件查询列表
     *
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query")
    })
    public PageInfo<BusinessDrugRestore> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer drugKind,
                                                 Integer drugName, String startTime, String endTime) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        //查询对象
        BusinessDrugRestoreExample restoreExample = new BusinessDrugRestoreExample();
        BusinessDrugRestoreExample.Criteria criteria = restoreExample.createCriteria();
        //查询条件
        if (null != drugKind)
            criteria.andDrugKindEqualTo(drugKind);
        if (null != drugName)
            criteria.andDrugNameEqualTo(drugName);
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime))
            criteria.andRegisterTimeBetween(ParameterUtil.string2date(startTime), ParameterUtil.string2date(endTime));
        if (orgId != null)
            criteria.andOrgIdEqualTo(orgId);
        //分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        //排序规则
        restoreExample.setOrderByClause("register_time desc");
        //查询
        List<BusinessDrugRestore> restoreList = restoreService.queryByExample(restoreExample);
        PageInfo<BusinessDrugRestore> pageInfo = new PageInfo<>(restoreList);
        return pageInfo;
    }

    /**
     * 保存修改
     *
     * @param drugRestoreJson
     * @return
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugRestoreJson", value = "保存信息", paramType = "query"),
            @ApiImplicitParam(name = "drugRestoreDetailJson", value = "保存多条数据", paramType = "query")
    })
    public Map<String, Object> save(String drugRestoreJson, String drugRestoreDetailJson, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            if (StringUtils.isNotBlank(drugRestoreJson) && StringUtils.isNotBlank(drugRestoreDetailJson) && orgId != null) {
                restoreService.add(drugRestoreJson, drugRestoreDetailJson, orgId);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("msg", "error");
            return modelMap;
        }
        return modelMap;
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> edit(Integer id) {
        Map<String, Object> modelMap = new HashMap<>();
        if (id != null) {
            BusinessDrugRestore drugRestore = restoreService.findById(id);
            modelMap.put("drugRestore", drugRestore);
            List<BusinessDrugRestoreDetail> detailList = restoreService.getListByZid(id);
            modelMap.put("detailList", detailList);
        }
        return modelMap;
    }

}
