package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugShelf;
import com.chinaitop.depot.business.service.BusinessDrugShelfService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂货架号管理.
 * <p>Title: BusinessDrugShelfController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月21日 下午5:41:18
 */
@RestController
@RequestMapping(value = "/depot/business/drugShelf")
@Api(value = "BusinessDrugShelfController", description = "药剂货架号管理")
public class BusinessDrugShelfController {

    @Autowired
    private BusinessDrugShelfService drugShelfService;

    /**
     * 列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10")
    })
    public PageInfo<BusinessDrugShelf> getList(HttpServletRequest request, Integer pageNum, Integer pageSize) {
        List<BusinessDrugShelf> list = drugShelfService.selectJoinDrugStorageHouse(request, pageNum, pageSize);
        PageInfo<BusinessDrugShelf> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }


    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public BusinessDrugShelf edit(Integer id) {
        BusinessDrugShelf drugShelf = new BusinessDrugShelf();
        if (id != null) {
            drugShelf = drugShelfService.findById(id);
        }
        return drugShelf;
    }

    /**
     * 保存
     *
     * @param drugShelfJson 药剂入库json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugShelfJson", value = "保存信息", paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public Map<String, Object> save(String drugShelfJson, Integer userId, Integer orgId, HttpServletRequest request) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // 用户信息.
            if (userId == null) {
                modelMap.put("status", "error");
                modelMap.put("msg", "请重新登录！");
            }
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugShelf drugShelf = mapper.readValue(drugShelfJson, BusinessDrugShelf.class);
            if (drugShelf.getId() == null) {
                modelMap = drugShelfService.add(drugShelf, userId, orgId);
            } else {
                modelMap = drugShelfService.update(drugShelf);
            }
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }


    /**
     * 删除
     *
     * @param id 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            drugShelfService.remove(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    //获取当前单位所有的货架号数据
    @RequestMapping(value = "/getShelfMap", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据orgId获取信息", notes = "根据orgId获取信息")
    @ApiImplicitParam(name = "orgId", value = "获取当前单位所有的货架号数据", paramType = "query")
    public Map<Integer, Object> getShelfMap(Integer orgId, HttpServletRequest request) {
        Map<Integer, Object> modelMap = new HashMap<Integer, Object>();
        // 组织机构信息.
        if (orgId != null) {
            modelMap = drugShelfService.getShelfMap(orgId);
        }
        return modelMap;
    }
}
