package com.chinaitop.depot.business.controller;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.business.model.BusinessDrugStandingBook;
import com.chinaitop.depot.business.model.BusinessDrugStandingBookExample;
import com.chinaitop.depot.business.service.BusinessDrugStandingBookService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂台账.
 * <p>Title: BusinessDrugStandingBookController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月22日 下午3:56:29
 */
@RestController
@RequestMapping("/depot/business/drugStandingBook")
@Api(value = "BusinessDrugStandingBookController", description = "药剂台账")
public class BusinessDrugStandingBookController {

    @Autowired
    private BusinessDrugStandingBookService drugStandingBookService;

    @RequestMapping(value = "/getShelfStandingBookList", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query")
    })
    public Map<String, Object> getShelfStandingBookList(HttpServletRequest request, Integer drugKind, Integer drugName) {
        HashMap<String, Object> modelMap = new HashMap<>();
        try {
            if (drugKind == null || drugName == null) {
                throw new RuntimeException("药剂种类或者药剂名称为空！");
            } else {
                List<BusinessDrugStandingBook> list = drugStandingBookService.getShelfStandingBook(request, drugKind, drugName);
                modelMap.put("status", "success");
                modelMap.put("shelfStandingBookList", list);
            }
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "查询货架号台账失败！");
        }
        return modelMap;
    }

    @RequestMapping(value = "/getManufacturerStandingBook", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "destroyType", value = "销毁类型", paramType = "query")
    })
    public PageInfo<BusinessDrugStandingBook> getManufacturerStandingBook(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer drugKind, Integer drugName,String destroyType) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();
        //查询条件
        if (null != drugKind)
            createCriteria.andDrugKindEqualTo(drugKind);
        if (null != drugName)
            createCriteria.andDrugNameEqualTo(drugName);
        if (null != orgId)
            createCriteria.andOrgIdEqualTo(orgId);
        if(null != destroyType && ""!=destroyType){
        	if(destroyType.equals("1")){//药剂销毁1 选择现有药剂库存不为0的药剂信息
        		createCriteria.andAmountNotEqualTo(0);
        	}else if(destroyType.equals("2")){//空瓶/袋销毁2  选择现有所有库存（含库存为0）的药剂信息
        		createCriteria.andAmountEqualTo(0);
        	}
        }
        createCriteria.andIsLastShelfDataEqualTo(1); //是否是最后的货架号盘点数据 0:否, 1:是
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        example.setOrderByClause("id desc");
        List<BusinessDrugStandingBook> list = drugStandingBookService.queryByExample(example);
        PageInfo<BusinessDrugStandingBook> pageInfo = new PageInfo<BusinessDrugStandingBook>(list);
        return pageInfo;
    }

    /**
     * 获取生产厂家指定 药剂id的 台账详情.
     *
     * @param request
     * @param pageNum
     * @param pageSize
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getDetailListByManufacturer", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "台账详情", notes = "台账详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugInfoId", value = "药剂id", paramType = "query"),
            @ApiImplicitParam(name = "manufacturer", value = "生产厂家", paramType = "query")
    })
    public PageInfo<BusinessDrugStandingBook> getDetailListByManufacturer(HttpServletRequest request, Integer pageNum, Integer pageSize,
                                                                          BusinessDrugStandingBook drugStandingBook) throws Exception {
        if (drugStandingBook.getDrugInfoId() == null) {
            throw new Exception("药剂id为空！");
        } else if (drugStandingBook.getManufacturer() == null) {
            throw new Exception("生产厂家为空！");
        }
        List<BusinessDrugStandingBook> list = drugStandingBookService.getDetailListByManufacturer(request, pageNum, pageSize, drugStandingBook);
        PageInfo<BusinessDrugStandingBook> pageInfo = new PageInfo<BusinessDrugStandingBook>(list);
        return pageInfo;
    }

    /**
     * 获取台账剩余存数量.
     *
     * @param drugStandingBookJson
     * @return
     */
    @RequestMapping(value = "/getRemainingQuantity", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "台账剩余存数量", notes = "台账剩余存数量")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugStandingBook", value = "台账对象json", paramType = "query")
    })
    public String getRemainingQuantity(String drugStandingBookJson) {
        BusinessDrugStandingBook drugStandingBook = JSON.parseObject(drugStandingBookJson, BusinessDrugStandingBook.class);
        return drugStandingBookService.getRemainingQuantity(drugStandingBook);
    }

    /**
     * 生产装备汇总统计
     *
     * @return
     */
    @RequestMapping(value = "/getDate")
    @ApiOperation(value = "生产装备汇总统计", notes = "药剂出入库统计")
    public Map<String, Object> getDate(Integer orgId) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        //入库数量
        List<Map<String, Object>> queryCountByType = drugStandingBookService.queryCountByType(orgId);
        String InputCount = "";
        String UseCount = "";
        if (queryCountByType.size() > 0) {
            for (Map<String, Object> map : queryCountByType) {
                String storageCount = map.get("storage_count").toString();
                String deliveryCount = map.get("delivery_count").toString();

                InputCount = InputCount + storageCount + ",";
                UseCount = UseCount + deliveryCount + ",";
            }
            UseCount = UseCount.substring(0, UseCount.length() - 1);
            InputCount = InputCount.substring(0, InputCount.length() - 1);
        }
        returnMap.put("UseCount", UseCount);
        returnMap.put("InputCount", InputCount);

        return returnMap;
    }


}
