package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugInfo;
import com.chinaitop.depot.business.model.BusinessDrugInfoKey;
import com.chinaitop.depot.business.service.BusinessDrugInfoService;
import com.chinaitop.depot.business.service.BusinessDrugStandingBookService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 药剂报表
 * @author My Sunshine
 *
 */
@RestController
@RequestMapping(value = "/depot/business/statement")
@Api(value = "BusinessDrugStatementController", description = "药剂报表")
public class BusinessDrugStatementController {

    @Resource
    private BusinessDrugStandingBookService businessDrugStandingBookService;

    /**
     * 列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query"),
            @ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query")
    })
    public ResponseEntity<List<Map<String,Object>>> getList(Integer orgId,String startDate, String endDate) {
    	
    	Map<String,Object> map = new HashMap<String, Object>();
        if (orgId != null) {
        	map.put("orgId", orgId);
        }
        
    	SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        if (StringUtils.isNotBlank(startDate)) {
        	map.put("startDate", startDate+" 00:00:00");
        }else{
        	//如果没有开始时间  默认 此年的第一天
        	Calendar currCal=Calendar.getInstance();
        	Calendar calendar = Calendar.getInstance();
        	calendar.clear();
        	calendar.set(Calendar.YEAR,currCal.get(Calendar.YEAR));
        	Date time = calendar.getTime();
        	String firstday =  format.format(time);
        	map.put("startDate", firstday+" 00:00:00"); 
        	System.out.println(firstday+"firstday");
        }
        if (StringUtils.isNotBlank(endDate)) {
        	map.put("endDate", endDate+" 23:59:59");
        }else{
        	//默认当前时间
        	map.put("endDate", format.format(new Date())+" 23:59:59");
        	System.out.println(format.format(new Date())+"endDate");
        }
        List<Map<String,Object>> list = businessDrugStandingBookService.getStatementList(map);
        return ResponseEntity.ok(list);
    }

}
