package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugStorage;
import com.chinaitop.depot.business.model.BusinessDrugStorageExample;
import com.chinaitop.depot.business.service.BusinessDrugStorageService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂入库
 * <p>Title: BusinessDrugStorageController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年10月25日 下午5:41:18
 */
@RestController
@RequestMapping(value = "/depot/business/drugStorage")
@Api(value = "BusinessDrugStorageController", description = "药剂入库")
public class BusinessDrugStorageController {

    @Resource
    private BusinessDrugStorageService drugStorageService;

    /**
     * 列表.
     *
     * @param pageNum   页码
     * @param pageSize  每页显示条数
     * @param drugKind  药剂种类
     * @param drugName  药剂名称
     * @param startTime 药剂入库登记开始时间
     * @param endTime   药剂入库登记结束时间
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query")
    })
    public PageInfo<BusinessDrugStorage> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer drugKind, Integer drugName, String startTime, String endTime) {
        BusinessDrugStorageExample example = new BusinessDrugStorageExample();
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        //查询条件
        BusinessDrugStorageExample.Criteria createCriteria = example.createCriteria();
        if (null != drugKind) {
            createCriteria.andDrugKindEqualTo(drugKind);
        }
        if (null != drugName) {
            createCriteria.andDrugNameEqualTo(drugName);
        }
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime)) {
            createCriteria.andCreateTimeBetween(ParameterUtil.string2datetime(startTime + " 00:00:00"), ParameterUtil.string2datetime(endTime + " 23:59:59"));
        }
        if (null != orgId)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        example.setOrderByClause("id desc");
        List<BusinessDrugStorage> list = drugStorageService.queryByExample(example);
        PageInfo<BusinessDrugStorage> pageInfo = new PageInfo<BusinessDrugStorage>(list);
        return pageInfo;
    }


    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public BusinessDrugStorage edit(Integer id) {
        BusinessDrugStorage drugStorage = new BusinessDrugStorage();
        if (id != null) {
            drugStorage = drugStorageService.findById(id);
        }
        return drugStorage;
    }

    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugStorageJson", value = "保存信息", paramType = "form"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "form")
    })
    public Map<String, Object> save(String drugStorageJson, Integer userId, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugStorage drugStorage = (BusinessDrugStorage) mapper.readValue(drugStorageJson, BusinessDrugStorage.class);
            if (drugStorage.getId() == null) {
                Map<String, Object> returnMap = drugStorageService.add(drugStorage, userId, orgId);
                if (returnMap.get("error") != null) {
                    modelMap.put("status", "error");
                    modelMap.put("msg", returnMap.get("error"));
                    return modelMap;
                }
            } else {
                drugStorageService.update(drugStorage);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }


    /**
     * 删除
     *
     * @param id 主键
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            drugStorageService.remove(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 封装药剂生产厂家
     *
     * @return
     */
    @RequestMapping(value = "/getManufacturer", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "获取药剂生产厂家", notes = "药剂生产厂家")
    public List<Map<String, Object>> getManufacturer() {
        List<Map<String, Object>> manufacturerList = drugStorageService.getManufacturer();
        return manufacturerList;
    }

    /**
     * 根据组织编码和申请通过详情id获取药剂采购申请已通过的总数
     * @param drugPurchaseBid
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getRKSum", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "获取药剂采购申请已通过的总数", notes = "采购申请已通过的总数")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugPurchaseBid", value = "采购申请通过详情id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public Integer getRKSum(Integer drugPurchaseBid, Integer orgId) {
        return drugStorageService.getRKSum(drugPurchaseBid, orgId);
    }

}
