package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessApproval;
import com.chinaitop.depot.business.model.vo.BusinessDrugUseApplyAuditVO;
import com.chinaitop.depot.business.model.vo.HistoryList;
import com.chinaitop.depot.business.service.BusinessDrugUseapplyService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂领用申请审批管理
 * <p>Title: BusinessDrugPurchaseAuditController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年10月25日 下午5:49:12
 */
@RestController
@RequestMapping(value = "/depot/business/drugUseApply/audit")
@Api(value = "BusinessDrugUseApplyAuditController", description = "药剂领用审批")
@SuppressWarnings("all")
public class BusinessDrugUseApplyAuditController {

    @Resource
    private BusinessDrugUseapplyService useapplyService;

    /**
     * 获取审批列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "query"),
            @ApiImplicitParam(name = "applyNumber", value = "药剂申请编号", paramType = "query"),
            @ApiImplicitParam(name = "auditState", value = "当前状态", paramType = "query")
    })
    public PageInfo<BusinessDrugUseApplyAuditVO> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer userId, String applyNumber, String state) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        Map<String, Object> paramMap = new HashMap<String, Object>();
        paramMap.put("operator", userId);
        if (StringUtils.isNotBlank(applyNumber))
            paramMap.put("applyNumber", "%"+applyNumber+"%");
        if (StringUtils.isNotBlank(state))
            paramMap.put("result", state);
        if (orgId != null)
            paramMap.put("orgId", orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        List<BusinessDrugUseApplyAuditVO> list = useapplyService.getApprovalList(paramMap);
        PageInfo<BusinessDrugUseApplyAuditVO> pageInfo = new PageInfo<BusinessDrugUseApplyAuditVO>(list);
        return pageInfo;
    }

    /**
     * 获取审批页面详情.
     *
     * @param applyNumber
     * @return
     */
    @RequestMapping(value = "/getAudit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据applyNumber获取信息", notes = "根据applyNumber获取信息")
    @ApiImplicitParam(name = "applyNumber", value = "药剂领用申请编号", paramType = "query")
    public Map<String, Object> getAudit(String applyNumber) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (StringUtils.isNotBlank(applyNumber)) {
            modelMap.put("taskTypeName", applyNumber);
        }
        // 审批历史.
        List<HistoryList> auditList = useapplyService.getAudit(modelMap);
        modelMap.put("auditList", auditList);
        return modelMap;
    }

    /**
     * 审批.
     *
     * @param drugUseApplyId   业务主键
     * @param businessApproval 中间表
     * @param assignee         下一个环节审批人
     * @param result           当前环节审批结果
     * @return
     */
    @RequestMapping(value = "/audit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "审批", notes = "审批")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugUseApplyId", value = "领用申请信息id", paramType = "query"),
            @ApiImplicitParam(name = "businessApproval", value = "审批批准信息", paramType = "query"),
            @ApiImplicitParam(name = "assignee", value = "下一个环节审批人id", paramType = "query"),
            @ApiImplicitParam(name = "result", value = "当前环节审批结果", paramType = "query"),
            @ApiImplicitParam(name = "userInfoJson", value = "用户信息", paramType = "query"),
            @ApiImplicitParam(name = "orgInfoJson", value = "用户组织信息", paramType = "query")
    })
    public Map<String, Object> audit(Integer drugUseApplyId, BusinessApproval businessApproval, String assignee, String result, String userInfoJson, String orgInfoJson) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            useapplyService.audit(drugUseApplyId, businessApproval, assignee, result, userInfoJson, orgInfoJson);
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
        }
        return modelMap;
    }


}
