package com.chinaitop.depot.business.controller;


import com.chinaitop.depot.business.model.BusinessDrugUse;
import com.chinaitop.depot.business.model.BusinessDrugUseDetail;
import com.chinaitop.depot.business.model.BusinessDrugUseExample;
import com.chinaitop.depot.business.service.BusinessDrugUseDetailService;
import com.chinaitop.depot.business.service.BusinessDrugUseService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮库业务管理-药剂领用登记
 * <p>Title: BusinessDrugUseController</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月23日 下午12:26:14
 */
@RestController
@RequestMapping(value = "/depot/business/drugUse")
@Api(value = "BusinessDrugUseController", description = "药剂领用登记")
public class BusinessDrugUseController {

    @Resource
    private BusinessDrugUseService drugUseService;
    @Autowired
    private BusinessDrugUseDetailService drugUseDetailService;

    /**
     * 申请列表.
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query")
    })
    public PageInfo<BusinessDrugUse> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer drugKind, Integer drugName, String startTime, String endTime) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        //查询条件
        BusinessDrugUseExample example = new BusinessDrugUseExample();
        BusinessDrugUseExample.Criteria createCriteria = example.createCriteria();
        if (null != drugKind)
            createCriteria.andDrugKindEqualTo(drugKind);
        if (null != drugName)
            createCriteria.andDrugNameEqualTo(drugName);
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime))
            createCriteria.andCreateTimeBetween(ParameterUtil.string2date(startTime), ParameterUtil.string2date(endTime));
        if (null != orgId)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        example.setOrderByClause("id desc");
        List<BusinessDrugUse> list = drugUseService.queryByExample(example);
        PageInfo<BusinessDrugUse> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> edit(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            BusinessDrugUse drugUse = drugUseService.findById(id);
            modelMap.put("drugUse", drugUse);
            List<BusinessDrugUseDetail> detailList = drugUseDetailService.getListByZid(id);
            modelMap.put("detailList", detailList);
        }
        return modelMap;
    }

    /**
     * 保存
     *
     * @param drugUseJson       主表信息json
     * @param drugUseDetailJson 子表信息json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugUseJson", value = "保存主表信息", paramType = "query"),
            @ApiImplicitParam(name = "drugUseDetailJson", value = "保存子表信息", paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "query")
    })
    public Map<String, Object> save(String drugUseJson, String drugUseDetailJson, Integer userId, Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugUse drugUse = (BusinessDrugUse) mapper.readValue(drugUseJson, BusinessDrugUse.class);
            List<BusinessDrugUseDetail> drugUseDetailList = null;
            if (drugUseDetailJson != null) {
                drugUseDetailList = (List<BusinessDrugUseDetail>) mapper.readValue(drugUseDetailJson, new TypeReference<List<BusinessDrugUseDetail>>() {
                });
            }
            if (drugUse.getId() == null) {
                drugUseService.add(drugUse, drugUseDetailList, userId, orgId);
            } else {
                //领用没有修改
                //drugUseService.update(drugUse, drugUseDetailList);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }

}
