package com.chinaitop.depot.business.controller;

import com.chinaitop.depot.business.model.BusinessDrugUseapply;
import com.chinaitop.depot.business.model.BusinessDrugUseapplyDetail;
import com.chinaitop.depot.business.model.BusinessDrugUseapplyExample;
import com.chinaitop.depot.business.service.BusinessDrugUseapplyDetailService;
import com.chinaitop.depot.business.service.BusinessDrugUseapplyService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 药剂管理-药剂领用申请
 * @create 2018-08-24 14:11
 */
@RestController
@RequestMapping(value = "/depot/business/drugUseapply")
@Api(value = "BusinessDrugUseapplyController", description = "药剂领用申请")
public class BusinessDrugUseapplyController {

    @Resource
    private BusinessDrugUseapplyService drugUseapplyservice;
    @Resource
    private BusinessDrugUseapplyDetailService drugUseapplyDetailService;

    /**
     * 申请列表.
     *
     * @param pageNum   页码
     * @param pageSize  每页显示条数
     * @param startTime 查询申请开始日期
     * @param endTime   查询申请结束日期
     * @return
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "列表信息", notes = "列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "drugKind", value = "药剂种类", paramType = "query"),
            @ApiImplicitParam(name = "drugName", value = "药剂名称", paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始查询时间(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间查询(例:2018-07-04)", paramType = "query"),
            @ApiImplicitParam(name = "state", value = "申请通过标记(2)", paramType = "query"),
            @ApiImplicitParam(name = "isUse", value = "申请领用标记(0:已领用 1未领用)", paramType = "query")
    })
    public PageInfo<BusinessDrugUseapply> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer drugKind, Integer drugName,
                                                  String startTime, String endTime, String state, String isUse) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        BusinessDrugUseapplyExample example = new BusinessDrugUseapplyExample();
        //查询条件
        BusinessDrugUseapplyExample.Criteria createCriteria = example.createCriteria();
        if (null != drugKind)
            createCriteria.andDrugKindEqualTo(drugKind);
        if (null != drugName)
            createCriteria.andDrugNameEqualTo(drugName);
        if (ParameterUtil.isnotnull(startTime) && ParameterUtil.isnotnull(endTime))
            createCriteria.andCreateTimeBetween(ParameterUtil.string2date(startTime), ParameterUtil.string2date(endTime));
        //查询审批通过数据
        if (StringUtils.isNotBlank(state))
            createCriteria.andStateEqualTo(state);
        //申请领用标记 0:已领用 1未领用
        if (StringUtils.isNotBlank(isUse))
            createCriteria.andIsUseEqualTo(isUse);
        if (null != orgId)
            createCriteria.andOrgIdEqualTo(orgId);
        //分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        //降序
        example.setOrderByClause("id desc");
        List<BusinessDrugUseapply> list = drugUseapplyservice.queryByExample(example);
        PageInfo<BusinessDrugUseapply> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 根据id查询.
     *
     * @param id 主键
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id获取信息", notes = "根据id获取信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> edit(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            BusinessDrugUseapply drugUseApply = drugUseapplyservice.findById(id);
            modelMap.put("drugUseApply", drugUseApply);
            List<BusinessDrugUseapplyDetail> detailList = drugUseapplyDetailService.getListByZid(id);
            modelMap.put("detailList", detailList);
        }
        return modelMap;
    }

    /**
     * 保存
     *
     * @param drugUseApplyJson       主表信息json
     * @param drugUseApplyDetailJson 子表信息json
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "保存信息", notes = "保存信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "drugUseApplyJson", value = "保存主表信息", paramType = "form"),
            @ApiImplicitParam(name = "drugUseApplyDetailJson", value = "保存子表信息", paramType = "form"),
            @ApiImplicitParam(name = "applyUser", value = "申请人", paramType = "form"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织id", paramType = "form")
    })
    public Map<String, Object> save(String drugUseApplyJson, String drugUseApplyDetailJson, Integer userId, Integer orgId, String applyUser) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessDrugUseapply drugUseApply = mapper.readValue(drugUseApplyJson, BusinessDrugUseapply.class);
            drugUseApply.setApplyUser(applyUser);
            drugUseApply.setState("0"); // 审批状态 0待提交，1审批中，2审批结束，3驳回，4拒绝
            drugUseApply.setIsUse("1"); //保存数据默认为未领用
            List<BusinessDrugUseapplyDetail> drugUseApplyDetailList = null;
            if (drugUseApplyDetailJson != null) {
                drugUseApplyDetailList = mapper.readValue(drugUseApplyDetailJson, new TypeReference<List<BusinessDrugUseapplyDetail>>() {
                });
            }
            if (drugUseApply.getId() == null) {
                Integer returnId = drugUseapplyservice.add(drugUseApply, drugUseApplyDetailList, userId, orgId);
                modelMap.put("id", returnId);
            } else {
                drugUseapplyservice.updateData(drugUseApply, drugUseApplyDetailList, userId, orgId);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
        return modelMap;
    }

    /**
     * 删除
     *
     * @param id
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/remove", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = "根据id删除信息", notes = "根据id删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id != null) {
            drugUseapplyservice.remove(id);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 更新审批状态 /updateData
     *
     * @param id
     * @param auditUserId 已选择的审批人userId
     * @return
     */
    @RequestMapping(value = "/updateData", method = RequestMethod.POST, produces = MediaType.APPLICATION_JSON_VALUE)
    public Map<String, Object> updateUseApplyData(Integer id, String userInfoJson, String orgInfoJson, String auditUserId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (null != id) {
            drugUseapplyservice.updateUseApplyData(id, userInfoJson, orgInfoJson, auditUserId);
            modelMap.put("status", "success");
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }


}
