/**
 * 
 */
package com.chinaitop.depot.business.service.impl;

import com.chinaitop.depot.business.mapper.BusinessDrugCheckMapper;
import com.chinaitop.depot.business.model.BusinessDrugCheck;
import com.chinaitop.depot.business.model.BusinessDrugCheckDetail;
import com.chinaitop.depot.business.model.BusinessDrugCheckExample;
import com.chinaitop.depot.business.service.BusinessDrugCheckDetailService;
import com.chinaitop.depot.business.service.BusinessDrugCheckService;
import com.chinaitop.depot.business.service.BusinessDrugStandingBookService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * <p>Title: BusinessDrugCheckServiceImpl</p>
 * <p>Description: </p>
 * @author yaoyabin
 * @date 2017年12月23日 下午5:17:10
 */
@Service
public class BusinessDrugCheckServiceImpl implements BusinessDrugCheckService {
    @Autowired
    private BusinessDrugCheckMapper businessDrugCheckMapper;
    
    @Autowired
    private BusinessDrugStandingBookService businessDrugStandingBookService;
    @Autowired
    private BusinessDrugCheckDetailService businessDrugCheckDetailService;

    @Override
    public BusinessDrugCheck findById(Integer id) {
        return businessDrugCheckMapper.selectByPrimaryKey(id);
    }

    @Override
    public List<BusinessDrugCheck> queryByExample(BusinessDrugCheckExample example) {
        return businessDrugCheckMapper.selectByExample(example);
    }

    @Override
    public Map<String, Object> add(BusinessDrugCheck drugCheck, List<BusinessDrugCheckDetail> drugUseDetailList,
                                   Integer userId,Integer orgId) {
        
        Map<String, Object> returnMap = new HashMap<String, Object>();
        
        List<BusinessDrugCheckDetail> detailList = new ArrayList<BusinessDrugCheckDetail>();
        // 盘点原数量和盘点数量是否是空，如果所有的子表信息都是不需要保存的，那么主表数据也不用保存了.
        for (BusinessDrugCheckDetail businessDrugCheckDetail : drugUseDetailList) {
            String shelfAmount = businessDrugCheckDetail.getShelfAmount();
            String checkCount = businessDrugCheckDetail.getCheckCount();
            if (StringUtils.isNotBlank(shelfAmount) && StringUtils.isNotBlank(checkCount)) {
                detailList.add(businessDrugCheckDetail);
            }
        }
        
        if (detailList.size() > 0) {
            /*// 通过规则，获取编号.
            try {
                drugCheck.setCheckNumber(basicCodeRuleService.getCode(CodeRuleType.drugCheck, depotInfo.getOrgId()));
            } catch (Exception e) {
                e.printStackTrace();
                returnMap.put("status", "error");
                returnMap.put("error", e.getMessage());
                return returnMap;
            }*/
            
            drugCheck.setCreater(userId);
            drugCheck.setCreateTime(new Date());
            drugCheck.setOrgId(orgId);
            // 新增.
            businessDrugCheckMapper.insert(drugCheck);
            
            // 插入子表数据.
            for (BusinessDrugCheckDetail businessDrugCheckDetail : detailList) {
                businessDrugCheckDetail.setZid(drugCheck.getId());
                businessDrugCheckDetail.setCreater(userId);
                businessDrugCheckDetail.setCreateTime(new Date());
                businessDrugCheckDetail.setOrgId(orgId);
                businessDrugCheckDetailService.insert(businessDrugCheckDetail);
                businessDrugStandingBookService.countByDrugCheck(businessDrugCheckDetail);
            }
        }
        
        return returnMap;
    }

    // 获取盘点编号.
    public String generatorNumber(String orgCode) {
        String todayStr = new SimpleDateFormat("yyyyMMdd").format(new Date());
        BusinessDrugCheckExample example = new BusinessDrugCheckExample();
        example.createCriteria().andCheckNumberLike(orgCode + "-YJPD-" + todayStr + "%");
        example.setOrderByClause("id desc");
        List<BusinessDrugCheck> list = businessDrugCheckMapper.selectByExample(example);
        String orderStr = "01";
        if (list != null && list.size() > 0) {
            BusinessDrugCheck bean = list.get(0);
            String checkNumber = bean.getCheckNumber();
            Integer number = Integer.parseInt(checkNumber.substring(checkNumber.length()-2));
            orderStr = String.valueOf(number + 1);
            if (number < 9) {
                orderStr = "0" + orderStr;
            }
        } 
        return orgCode + "-YJPD-" + todayStr + "-" + orderStr;
    }

}
