package com.chinaitop.depot.business.service.impl;

import com.chinaitop.depot.business.mapper.BusinessDrugInfoMapper;
import com.chinaitop.depot.business.model.BusinessDrugInfo;
import com.chinaitop.depot.business.model.BusinessDrugInfoExample;
import com.chinaitop.depot.business.model.BusinessDrugInfoExample.Criteria;
import com.chinaitop.depot.business.model.BusinessDrugInfoKey;
import com.chinaitop.depot.business.service.BusinessDrugInfoService;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Service
@Transactional(readOnly = false)
public class BusinessDrugInfoServiceImpl implements BusinessDrugInfoService {
    @Resource
    private BusinessDrugInfoMapper drugInfoMapper;

    /**
     * 新增.
     */
    public Map<String, Object> add(BusinessDrugInfo drugInfo, Integer userId, Integer orgId) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        // 创建人.
        drugInfo.setCreater(userId);
        // 创建时间.
        drugInfo.setCreateTime(new Date());
        // 组织机构id.
        drugInfo.setOrgId(orgId);
        // 没有生效.是否使用 0未使用 1使用中
        drugInfo.setIsEffective(0);
        // 没有删除.
        drugInfo.setIsDelete(0);

        if (ifExit(drugInfo, "add")) {
            returnMap.put("status", "error");
            returnMap.put("error", "已存在所有属性相同的药剂信息！");
        } else {
            // 新增.
            drugInfoMapper.insert(drugInfo);
            returnMap.put("status", "success");
        }
        return returnMap;

    }

    /**
     * 修改
     */
    public Map<String, Object> update(BusinessDrugInfo drugInfo) {
        Map<String, Object> returnMap = new HashMap<String, Object>();

        //添加修改时间
        drugInfo.setUpdateTime(new Date());
        // 修改.
        drugInfoMapper.updateByPrimaryKey(drugInfo);
        returnMap.put("status", "success");
        
        /*if (ifExit(drugInfo, "update")) {
            returnMap.put("status", "error");
            returnMap.put("error", "已存在所有属性相同的药剂信息！");
        } else {
            
        }*/
        return returnMap;
    }

    /**
     * 逻辑删除.
     */
    public void remove(BusinessDrugInfoKey drugInfoKey) {
        drugInfoMapper.deleteByPrimaryKey(drugInfoKey);
    }

    /**
     * 条件查询.
     */
    @Override
    public List<BusinessDrugInfo> queryByExample(BusinessDrugInfoExample example) {
        return drugInfoMapper.selectByExample(example);
    }

    /**
     * id查询.
     */
    @Override
    public BusinessDrugInfo findById(BusinessDrugInfoKey drugInfoKey) {
        return drugInfoMapper.selectByPrimaryKey(drugInfoKey);
    }

    /**
     * 判断是否存在.
     *
     * @param drugInfo
     * @param type
     * @return
     */
    private boolean ifExit(BusinessDrugInfo drugInfo, String type) {
        BusinessDrugInfoExample example = new BusinessDrugInfoExample();
        Criteria createCriteria = example.createCriteria();

        if ("update".equals(type)) {
            createCriteria.andIdNotEqualTo(drugInfo.getId());
        }
        createCriteria.andOrgIdEqualTo(drugInfo.getOrgId());
        createCriteria.andDrugKindEqualTo(drugInfo.getDrugKind());
        createCriteria.andDrugNameEqualTo(drugInfo.getDrugName());
        createCriteria.andDrugTypeEqualTo(drugInfo.getDrugType());
        createCriteria.andDrugPackingEqualTo(drugInfo.getDrugPacking());
        createCriteria.andDrugSpecificationEqualTo(drugInfo.getDrugSpecification());

        List<BusinessDrugInfo> list = drugInfoMapper.selectByExample(example);
        if (list != null && list.size() > 0) {
            return true;
        }
        return false;
    }

    /**
     * 生效.
     */
    @Override
    public void effective(Integer id) {
        BusinessDrugInfo info = new BusinessDrugInfo();
        info.setId(id);
        info.setIsEffective(1);
        info.setUpdateTime(new Date());
        drugInfoMapper.updateByPrimaryKeySelective(info);
    }

    /**
     * 列表
     *
     * @param request
     * @param pageNum
     * @param pageSize
     * @param businessDrugInfo
     * @return
     */
    @Override
    public List<BusinessDrugInfo> getList(HttpServletRequest request, Integer pageNum, Integer pageSize, BusinessDrugInfo businessDrugInfo) {
        // 获取orgId
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 添加查询条件
        BusinessDrugInfoExample example = new BusinessDrugInfoExample();
        Criteria createCriteria = example.createCriteria();
        createCriteria.andIsDeleteEqualTo(0);
        if (null != businessDrugInfo.getDrugKind())
            createCriteria.andDrugKindEqualTo(businessDrugInfo.getDrugKind());
        if (null != businessDrugInfo.getDrugName())
            createCriteria.andDrugNameEqualTo(businessDrugInfo.getDrugName());
        if (null != businessDrugInfo.getIsEffective())
            createCriteria.andIsEffectiveEqualTo(businessDrugInfo.getIsEffective());
        if (orgId != null)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        // 排序
        example.setOrderByClause("is_effective, id desc");
        return drugInfoMapper.selectByExample(example);
    }

    /**
     * 生效列表.获取使用中列表
     *
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     */
    @Override
    public List<BusinessDrugInfo> getEffectiveList(HttpServletRequest request, Integer pageNum, Integer pageSize, BusinessDrugInfo businessDrugInfo) {
        // 获取orgId
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 封装查询条件
        BusinessDrugInfoExample example = new BusinessDrugInfoExample();
        Criteria createCriteria = example.createCriteria();
        createCriteria.andIsDeleteEqualTo(0);
        createCriteria.andIsEffectiveEqualTo(1);
        if (orgId != null)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        return drugInfoMapper.selectByExample(example);
    }

    /**
     * 根据药剂编号更新信息
     *
     * @param drugNumber
     */
    @Override
    public void updateIsEffective(String drugNumber) {
        BusinessDrugInfo drugInfo = new BusinessDrugInfo();
        BusinessDrugInfoExample drugInfoExample = new BusinessDrugInfoExample();
        Criteria criteria = drugInfoExample.createCriteria();
        criteria.andDrugNumberEqualTo(drugNumber);
        drugInfo.setIsEffective(1);
        drugInfoMapper.updateByExampleSelective(drugInfo, drugInfoExample);
    }
}
