package com.chinaitop.depot.business.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.mapper.BusinessApprovalMapper;
import com.chinaitop.depot.business.mapper.BusinessDrugPurchaseMapper;
import com.chinaitop.depot.business.model.*;
import com.chinaitop.depot.business.model.vo.BusinessDrugPurchaseAuditVO;
import com.chinaitop.depot.business.model.vo.HistoryList;
import com.chinaitop.depot.business.service.BusinessApprovalService;
import com.chinaitop.depot.business.service.BusinessDrugInfoService;
import com.chinaitop.depot.business.service.BusinessDrugPurchaseDetailService;
import com.chinaitop.depot.business.service.BusinessDrugPurchaseService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;


@Service
public class BusinessDrugPurchaseServiceImpl implements BusinessDrugPurchaseService {
    @Resource
    private BusinessDrugPurchaseMapper drugPurchaseMapper;
    @Resource
    private BusinessDrugPurchaseDetailService businessDrugPurchaseDetailService;
    @Resource
    private BusinessDrugInfoService drugInfoService;
    @Resource
    private BusinessApprovalService approvalService;
    @Resource
    private BusinessApprovalMapper approvalMapper;

    public List<BusinessDrugPurchase> queryByExample(BusinessDrugPurchaseExample example) {
        return drugPurchaseMapper.selectByExample(example);
    }


    public BusinessDrugPurchase findById(Integer id) {
        return drugPurchaseMapper.selectByPrimaryKey(id);
    }

    /**
     * 新增.
     * 计算总件数，总金额.
     */
    public Integer add(BusinessDrugPurchase drugPurchase,
                                   List<BusinessDrugPurchaseDetail> drugPurchaseDetailList, Integer userId, Integer orgId) {
        // 计算总件数，总金额
        this.ApplySum(drugPurchase, drugPurchaseDetailList);
        // 创建人.
        drugPurchase.setCreater(userId);
        // 创建时间.
        //drugPurchase.setCreateTime(new Date());
        // 组织机构id.
        drugPurchase.setOrgId(orgId);
        //只获取一个药剂名称用于列表展示
        if (drugPurchaseDetailList.size() > 0) {
            Integer drugName = drugPurchaseDetailList.get(0).getDrugName();
            Integer drugKind = drugPurchaseDetailList.get(0).getDrugKind();
            //药剂名称
            drugPurchase.setDrugName(drugName);
            //药剂种类
            drugPurchase.setDrugKind(drugKind);
        }
        //流程实例id
        drugPurchase.setProcessInstanceId("68846884");
        //审批标记 0待提交，1审批中，2审批结束，3审批驳回, 4审批拒绝
        drugPurchase.setAuditState("0");
        // 新增.
        drugPurchaseMapper.insert(drugPurchase);
        this.addAndUpdateData(drugPurchase, drugPurchaseDetailList);
        return drugPurchase.getId();
    }

    /**
     * 修改
     * 计算总件数，总金额.
     */
    public void update(BusinessDrugPurchase drugPurchase,
                       List<BusinessDrugPurchaseDetail> drugPurchaseDetailList) {
        // 计算总件数，总金额
        this.ApplySum(drugPurchase, drugPurchaseDetailList);
        // 修改.
        drugPurchaseMapper.updateByPrimaryKey(drugPurchase);

        // 插入或者修改子表数据.
        if (null != drugPurchase.getId()) {
            BusinessDrugPurchaseDetailExample example = new BusinessDrugPurchaseDetailExample();
            BusinessDrugPurchaseDetailExample.Criteria criteria = example.createCriteria();
            //删除原有子表数据从新添加
            criteria.andZidEqualTo(drugPurchase.getId());
            businessDrugPurchaseDetailService.deleteByExample(example);
            this.addAndUpdateData(drugPurchase, drugPurchaseDetailList);
        }

    }

    /**
     * 删除，主表和子表数据.
     */
    public void remove(Integer id) {
        drugPurchaseMapper.deleteByPrimaryKey(id);
        // 根据主表id,删除子表数据.
        BusinessDrugPurchaseDetailExample example = new BusinessDrugPurchaseDetailExample();
        example.createCriteria().andZidEqualTo(id);
        businessDrugPurchaseDetailService.deleteByExample(example);
    }

    /**
     * 计算申请总件数，总金额
     *
     * @param drugPurchase
     * @param drugPurchaseDetailList
     * @return
     */
    private void ApplySum(BusinessDrugPurchase drugPurchase, List<BusinessDrugPurchaseDetail> drugPurchaseDetailList) {
        // 计算总数量，总金额.
        BigDecimal applyTotalCountB = new BigDecimal("0");
        BigDecimal applyTotalAmountB = new BigDecimal("0");
        for (BusinessDrugPurchaseDetail businessDrugPurchaseDetail : drugPurchaseDetailList) {
            // 数量.
            BigDecimal applyCountB = new BigDecimal(businessDrugPurchaseDetail.getApplyCount());
            // 金额.
            BigDecimal applyAmountB = new BigDecimal(businessDrugPurchaseDetail.getApplyAmount());

            applyTotalCountB = applyTotalCountB.add(applyCountB);
            applyTotalAmountB = applyTotalAmountB.add(applyAmountB);
        }
        // 总数量
        drugPurchase.setApplyTotalCount(applyTotalCountB.toString());
        // 总金额
        drugPurchase.setApplyTotalAmount(applyTotalAmountB.toString());
    }

    /**
     * 公共方法抽取
     * 新增
     * 修改
     *
     * @param drugPurchase
     * @param drugPurchaseDetailList
     */
    private void addAndUpdateData(BusinessDrugPurchase drugPurchase, List<BusinessDrugPurchaseDetail> drugPurchaseDetailList) {
        // 插入子表数据.
        for (BusinessDrugPurchaseDetail businessDrugPurchaseDetail : drugPurchaseDetailList) {
            //更新药剂信息维护为使用状态
            if (businessDrugPurchaseDetail.getId() != null && businessDrugPurchaseDetail.getId() == 0) { //0未使用
                drugInfoService.updateIsEffective(businessDrugPurchaseDetail.getDrugNumber());
            }
            businessDrugPurchaseDetail.setZid(drugPurchase.getId());
            businessDrugPurchaseDetail.setId(null); //清除缓存的用于缓存isEffective是否使用标记--后台使用完重置为空
            businessDrugPurchaseDetail.setOrgId(drugPurchase.getOrgId());
            businessDrugPurchaseDetailService.add(businessDrugPurchaseDetail);
        }
    }

    /**
     * 获取审批列表.
     *
     * @param paramMap
     * @return
     */
    @Override
    public List<BusinessDrugPurchaseAuditVO> getApprovalList(Map<String, Object> paramMap) {
        return drugPurchaseMapper.getApprovalList(paramMap);
    }

    /**
     * 更新审批状态
     *
     * @param id
     * @return
     */
    @Override
    public void updatePurchaseData(Integer id, String userInfoJson, String orgInfoJson, String auditUserId) {
        JSONObject jsonUserInfo = JSON.parseObject(userInfoJson);
        JSONObject jsonOrgInfo = JSON.parseObject(orgInfoJson);
        //更新
        BusinessDrugPurchase drugPurchase = new BusinessDrugPurchase();
        drugPurchase.setId(id);
        drugPurchase.setAuditState("1"); //0待提交，1审批中，2审批结束，3审批驳回, 4审批拒绝
        drugPurchase.setProcessDefinitionId("员工提交");
        drugPurchaseMapper.updateByPrimaryKeySelective(drugPurchase);
        //保存数据到business_approval
        BusinessDrugPurchase drugPurchase1 = drugPurchaseMapper.selectByPrimaryKey(id);
        if (drugPurchase1 != null) {
            BusinessApproval businessApproval = new BusinessApproval();
            businessApproval.setCreateTime(new Date()); //创建时间
            businessApproval.setFromDepartment(jsonOrgInfo.getString("orgName")); //部门 orgName
            businessApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
            businessApproval.setOperator(auditUserId);//已选择的审批人id
            businessApproval.setOperatorName(jsonUserInfo.getString("realName"));//已选择的审批人姓名
            businessApproval.setProcessInstanceId(drugPurchase1.getProcessInstanceId());//流程实例id
            businessApproval.setProjectName("药剂采购申请");//名称
            businessApproval.setResult("待审批");//审批结果
//            businessApproval.setTaskName(jsonUserInfo.getString("realName") + "提交");//任务名称
            businessApproval.setTaskName("员工提交");//任务名称
            businessApproval.setTaskType("drugPurchase");//任务类型
            businessApproval.setTaskTypeName(drugPurchase1.getApplyNumber());//任务类型名
            businessApproval.setIsHide(0);//
            businessApproval.setApplyName(jsonUserInfo.getString("realName"));//申请人
            businessApproval.setApplyNameId(jsonUserInfo.getString("userId"));//申请人id
            businessApproval.setApplyTime(drugPurchase1.getCreateTime());//申请时间
            businessApproval.setContent(jsonUserInfo.getString("realName") + "提交"); //提交人
            approvalService.add(businessApproval);
        }

    }

    /**
     * 添加审批.
     *
     * @param drugPurchaseId
     * @param businessApproval
     * @param nextUserId       下一个审批人id.
     * @param result           审批结论
     * @param userInfoJson     当前用户信息.
     */
    @SuppressWarnings("all")
    @Override
    public void audit(Integer drugPurchaseId, BusinessApproval businessApproval, String nextUserId, String result, String userInfoJson, String orgInfoJson) {
        JSONObject jsonUserInfo = JSON.parseObject(userInfoJson);
        JSONObject jsonOrgInfo = JSON.parseObject(orgInfoJson);
        BusinessApproval oldBusinessApproval = approvalService.findById(businessApproval.getId());
        // 检测是否并发审核
        String oldResult = oldBusinessApproval.getResult();
        if ("同意".equals(oldResult) || "拒绝".equals(oldResult) || "驳回".equals(oldResult)) {
            throw new RuntimeException("该订单已经审核过，不能再次审核！");
        }
        String resultS = "";
        if ("1".equals(result)) {
            resultS = "同意";
        } else if ("2".equals(result)) {
            resultS = "驳回";
        } else if ("3".equals(result)) {
            resultS = "拒绝";
        }

        // 修改当前中间表.
        oldBusinessApproval.setResult(resultS);
        approvalService.updateByPrimaryKeySelective(oldBusinessApproval);

        //修改申请表状态 //1审批中，2审批结束，3审批驳回, 4审批拒绝
        BusinessDrugPurchase drugPurchase = new BusinessDrugPurchase();
        if (null != drugPurchaseId) {
            drugPurchase.setId(drugPurchaseId);
            BusinessDrugPurchase drugPurchase1 = drugPurchaseMapper.selectByPrimaryKey(drugPurchaseId);
            //保存下一审批人节点
            BusinessApproval newApproval = new BusinessApproval();
            newApproval.setCreateTime(new Date()); //创建时间
            newApproval.setFromDepartment(jsonOrgInfo.getString("orgName")); //部门 orgName
            newApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
            newApproval.setOperator(nextUserId);//已选择的下一节点审批人id
            newApproval.setOperatorName(jsonUserInfo.getString("realName"));//已选择的审批人姓名
            newApproval.setProcessInstanceId(drugPurchase1.getProcessInstanceId());//流程实例id
            newApproval.setProjectName("药剂采购申请");//名称
            if ("1".equals(businessApproval.getResult())) {
                newApproval.setResult("待审批");//审批结果
            }
            if ("2".equals(businessApproval.getResult())) {
                newApproval.setResult("驳回");//审批结果
            }
            if ("3".equals(businessApproval.getResult())) {
                newApproval.setResult("拒绝");//审批结果
            }
            newApproval.setTaskType("drugPurchase");//任务类型
            newApproval.setTaskTypeName(drugPurchase1.getApplyNumber());//任务类型名
            newApproval.setIsHide(0);//
            newApproval.setApplyName(jsonUserInfo.getString("realName"));//申请人
            newApproval.setApplyNameId(jsonUserInfo.getString("userId"));//申请人id
            newApproval.setApplyTime(drugPurchase1.getCreateTime());//申请时间
            if (result.equals("1")) { //通过不修改显示审批中
                // 判断审批流程(ProcessDefinitionId为空)
                if(StringUtils.isBlank(drugPurchase1.getProcessDefinitionId()) || "员工提交".equals(drugPurchase1.getProcessDefinitionId())){
                    newApproval.setTaskName("仓储部经理审批");//任务名称
                    drugPurchase.setProcessDefinitionId("仓储部经理审批"); // 员工第一次提交仓储部经理审批
                    newApproval.setContent(businessApproval.getContent());//审批意见
                    drugPurchaseMapper.updateByPrimaryKeySelective(drugPurchase);
                    approvalService.add(newApproval);
                } else if ("仓储部经理审批".equals(drugPurchase1.getProcessDefinitionId())){ // 判断是否仓储部经理已审批(第二次审批)
                    newApproval.setTaskName("库领导审批");//任务名称
                    drugPurchase.setProcessDefinitionId("审批流程结束"); // 仓储部经理审批提交库领导审批审批流程结束
                    drugPurchase.setAuditState("2");
                    newApproval.setResult(resultS);//审批结果
                    newApproval.setContent(businessApproval.getContent());//审批意见
                    newApproval.setOperator(jsonUserInfo.getString("userId"));
                    drugPurchaseMapper.updateByPrimaryKeySelective(drugPurchase);
                    approvalService.add(newApproval);
                } else {
                    throw new IllegalArgumentException("审批失败!审批流程错误!");
                }
            } else if (result.equals("2")) {//驳回
                drugPurchase.setAuditState("3");
                newApproval.setContent(businessApproval.getContent());//审批意见
                newApproval.setOperator(jsonUserInfo.getString("userId"));
                if(StringUtils.isBlank(drugPurchase1.getProcessDefinitionId()) || "员工提交".equals(drugPurchase1.getProcessDefinitionId())){
                    newApproval.setTaskName("仓储部经理审批");//任务名称
                    drugPurchase.setProcessDefinitionId(null); // 员工第一次提交仓储部经理审批
                } else if ("仓储部经理审批".equals(drugPurchase1.getProcessDefinitionId())){ // 判断是否仓储部经理已审批(第二次审批)
                    newApproval.setTaskName("库领导审批");//任务名称
                    drugPurchase.setProcessDefinitionId(null); // 仓储部经理审批提交库领导审批审批流程结束
                    newApproval.setResult(resultS);//审批结果
                    newApproval.setOperator(jsonUserInfo.getString("userId"));
                    // 库领导驳回将所有已审批同意的修改为驳回
                    BusinessApproval b = new BusinessApproval();
                    BusinessApprovalExample bExample = new BusinessApprovalExample();
                    BusinessApprovalExample.Criteria criteria = bExample.createCriteria();
                    criteria.andTaskTypeNameEqualTo(drugPurchase1.getApplyNumber());
                    b.setResult(resultS);
                    approvalMapper.updateByExampleSelective(b,bExample);
                }
                approvalService.add(newApproval);
                drugPurchaseMapper.updateByPrimaryKeySelective(drugPurchase);
            } else if (result.equals("3")) {//拒绝
                drugPurchase.setAuditState("4");
                newApproval.setContent(businessApproval.getContent());//审批意见
                newApproval.setOperator(jsonUserInfo.getString("userId"));
                if(StringUtils.isBlank(drugPurchase1.getProcessDefinitionId()) || "员工提交".equals(drugPurchase1.getProcessDefinitionId())){
                    newApproval.setTaskName("仓储部经理审批");//任务名称
                    drugPurchase.setProcessDefinitionId("仓储部经理审批"); // 员工第一次提交仓储部经理审批
                } else if ("仓储部经理审批".equals(drugPurchase1.getProcessDefinitionId())){ // 判断是否仓储部经理已审批(第二次审批)
                    newApproval.setTaskName("库领导审批");//任务名称
                    drugPurchase.setProcessDefinitionId("审批流程结束"); // 仓储部经理审批提交库领导审批审批流程结束
                    newApproval.setResult(resultS);//审批结果
                    newApproval.setOperator(jsonUserInfo.getString("userId"));
                }
                approvalService.add(newApproval);
                drugPurchaseMapper.updateByPrimaryKeySelective(drugPurchase);
            } else {
                //位置环节
                return;
            }
        }
    }

    /**
     * 获取审批页面详情.
     *
     * @param modelMap 业务主键
     * @return
     */
    @Override
    public List<HistoryList> getAudit(Map<String, Object> modelMap) {
        return drugPurchaseMapper.getAudit(modelMap);
    }


}
