package com.chinaitop.depot.business.service.impl;

import com.chinaitop.depot.business.mapper.BusinessDrugRestoreDetailMapper;
import com.chinaitop.depot.business.mapper.BusinessDrugRestoreMapper;
import com.chinaitop.depot.business.model.BusinessDrugRestore;
import com.chinaitop.depot.business.model.BusinessDrugRestoreDetail;
import com.chinaitop.depot.business.model.BusinessDrugRestoreDetailExample;
import com.chinaitop.depot.business.model.BusinessDrugRestoreExample;
import com.chinaitop.depot.business.service.BusinessDrugRestoreService;
import com.chinaitop.depot.business.service.BusinessDrugStandingBookService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Date;
import java.util.List;

/**
 * @author qingsong.han
 * @description: 药剂归还
 * @create 2018-09-15 11:39
 */
@Service
public class BusinessDrugRestoreServiceImpl implements BusinessDrugRestoreService {

    @Resource
    private BusinessDrugRestoreMapper restoreMapper;
    @Resource
    private BusinessDrugStandingBookService drugStandingBookService;
    @Resource
    private BusinessDrugRestoreDetailMapper drugRestoreDetailMapper;

    /**
     * 对象查询
     *
     * @param restoreExample
     * @return
     */
    @Override
    public List<BusinessDrugRestore> queryByExample(BusinessDrugRestoreExample restoreExample) {
        return restoreMapper.selectByExample(restoreExample);
    }

    /**
     * 保存
     *
     * @param drugRestoreJson
     * @param drugRestoreDetailJson
     * @param orgId
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void add(String drugRestoreJson, String drugRestoreDetailJson, Integer orgId) {
        try {
            ObjectMapper mapper = new ObjectMapper();
            // JSON字符串转对象
            BusinessDrugRestore drugRestore = mapper.readValue(drugRestoreJson, BusinessDrugRestore.class);
            drugRestore.setOrgId(orgId);
            List<BusinessDrugRestoreDetail> drugRestoreDetailList = mapper.readValue(drugRestoreDetailJson, new TypeReference<List<BusinessDrugRestoreDetail>>() {});
            if (drugRestore.getId() == null) {
                // 主表
                //drugRestore.setRegisterTime(new Date()); //完善时间
                restoreMapper.insert(drugRestore);
                // 子表
                drugRestoreDetailList.forEach(drugRestoreDetail -> {
                    drugRestoreDetail.setOrgId(orgId);
                    drugRestoreDetail.setCreateTime(ParameterUtil.datetime2string(drugRestore.getRegisterTime()));
                    drugRestoreDetail.setZid(drugRestore.getId());
                    drugRestoreDetailMapper.insert(drugRestoreDetail);
                    // 更新台账表.
                    drugStandingBookService.addByDrugRestore(drugRestoreDetail);
                });
            }

        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    @Override
    public BusinessDrugRestore findById(Integer id) {
        return restoreMapper.selectByPrimaryKey(id);
    }

    /**
     * 根据zid查询子表数据
     * @param id
     * @return
     */
    @Override
    public List<BusinessDrugRestoreDetail> getListByZid(Integer id) {
        BusinessDrugRestoreDetailExample example = new BusinessDrugRestoreDetailExample();
        BusinessDrugRestoreDetailExample.Criteria criteria = example.createCriteria();
        criteria.andZidEqualTo(id);
        return drugRestoreDetailMapper.selectByExample(example);
    }

}
