package com.chinaitop.depot.business.service.impl;

import com.chinaitop.depot.business.mapper.BusinessDrugShelfMapper;
import com.chinaitop.depot.business.model.BusinessDrugShelf;
import com.chinaitop.depot.business.model.BusinessDrugShelfExample;
import com.chinaitop.depot.business.model.BusinessDrugShelfExample.Criteria;
import com.chinaitop.depot.business.service.BusinessDrugShelfService;
import com.github.pagehelper.PageHelper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>Title: BusinessDrugShelfServiceImpl</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月25日 下午5:48:33
 */
@Service
public class BusinessDrugShelfServiceImpl implements BusinessDrugShelfService {

    @Autowired
    private BusinessDrugShelfMapper businessDrugShelfMapper;

    @Override
    public List<BusinessDrugShelf> selectJoinDrugStorageHouse(HttpServletRequest request, Integer pageNum, Integer pageSize) {
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        BusinessDrugShelfExample example = new BusinessDrugShelfExample();
        Criteria criteria = example.createCriteria();
        criteria.andIsDeleteEqualTo(0);
        if (orgId != null)
            criteria.andOrgIdEqualTo(orgId);
        return businessDrugShelfMapper.selectByExample(example);
    }

    @Override
    public BusinessDrugShelf findById(Integer id) {
        return businessDrugShelfMapper.selectByPrimaryKey(id);
    }

    /**
     * 新增.
     */
    @Override
    public Map<String, Object> add(BusinessDrugShelf drugShelf, Integer userId, Integer orgId) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        // 去除空格.
        String shelfName = drugShelf.getShelfName().replaceAll(" ", "");
        drugShelf.setShelfName(shelfName);
        drugShelf.setIsDelete(0);
        drugShelf.setCreater(userId);
        drugShelf.setCreateTime(new Date());
        drugShelf.setOrgId(orgId);

        if (StringUtils.isBlank(shelfName)) {
            // 判断货架号是否为空
            returnMap.put("status", "error");
            returnMap.put("msg", "货架号不能为空！");
        } else if (ifExit(drugShelf, "add")) {
            returnMap.put("status", "error");
            returnMap.put("msg", "该药剂仓房已存在该货架号！");
        } else {
            businessDrugShelfMapper.insert(drugShelf);
            returnMap.put("status", "success");
        }
        return returnMap;
    }

    /**
     * 修改.
     */
    @Override
    public Map<String, Object> update(BusinessDrugShelf drugShelf) {
        Map<String, Object> returnMap = new HashMap<String, Object>();

        if (StringUtils.isBlank(drugShelf.getShelfName())) {
            // 判断仓房名称是否为空
            returnMap.put("status", "error");
            returnMap.put("msg", "货架号不能为空！");
        } else if (ifExit(drugShelf, "update")) {
            returnMap.put("status", "error");
            returnMap.put("msg", "该药剂仓房已存在该货架号！");
            return returnMap;
        } else {
            drugShelf.setUpdateTime(new Date());
            businessDrugShelfMapper.updateByPrimaryKey(drugShelf);
            returnMap.put("status", "success");
        }
        return returnMap;
    }

    /**
     * 逻辑删除.
     */
    @Override
    public void remove(Integer id) {
        BusinessDrugShelf drugShelf = new BusinessDrugShelf();
        drugShelf.setId(id);
        drugShelf.setIsDelete(1);
        businessDrugShelfMapper.updateByPrimaryKeySelective(drugShelf);
    }

    /**
     * 判断是否存在 同药剂仓房 同货位号 同orgId.
     *
     * @param drugShelf
     * @return
     */
    private Boolean ifExit(BusinessDrugShelf drugShelf, String type) {
        BusinessDrugShelfExample example = new BusinessDrugShelfExample();
        Criteria createCriteria = example.createCriteria();

        if ("update".equals(type)) {
            createCriteria.andIdNotEqualTo(drugShelf.getId());
        }
        createCriteria.andShelfNameEqualTo(drugShelf.getShelfName());
        createCriteria.andStorageHouseNameEqualTo(drugShelf.getStorageHouseName());
        createCriteria.andOrgIdEqualTo(drugShelf.getOrgId());
        // 只判断未删除的.
        createCriteria.andIsDeleteEqualTo(0);
        List<BusinessDrugShelf> list = businessDrugShelfMapper.selectByExample(example);
        if (list != null && list.size() > 0) {
            return true;
        }
        return false;
    }

    /**
     * 获取当前单位下所有仓房数据
     *
     * @param orgId
     * @return
     */
    public Map<Integer, Object> getShelfMap(Integer orgId) {
        BusinessDrugShelfExample example = new BusinessDrugShelfExample();
        Criteria criteria = example.createCriteria();
        List<BusinessDrugShelf> shelfList = null;
        try {
            criteria.andOrgIdEqualTo(orgId);
            shelfList = businessDrugShelfMapper.selectByExample(example); //获取当前单位所有的货架号数据.
        } catch (Exception e) {
            e.printStackTrace();
        }
        Map<Integer, Object> objMap = new HashMap<Integer, Object>();
        for (BusinessDrugShelf obj : shelfList) {
            objMap.put(obj.getId(), obj);
        }
        return objMap;
    }
}
