package com.chinaitop.depot.business.service.impl;

import com.chinaitop.depot.business.mapper.BusinessDrugStandingBookMapper;
import com.chinaitop.depot.business.model.*;
import com.chinaitop.depot.business.service.BusinessDrugStandingBookService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>Title: BusinessDrugStandingBookServiceImpl</p>
 * <p>Description: </p>
 *
 * @author yaoyabin
 * @date 2017年12月22日 下午2:53:28
 */
@Service
@SuppressWarnings("all")
public class BusinessDrugStandingBookServiceImpl implements BusinessDrugStandingBookService {

    public final static String SCALE_ADD = "add";//加法
    public final static String SCALE_DEL = "del";//减法

    @Autowired
    private BusinessDrugStandingBookMapper drugStandingBookMapper;
    
    @Resource
    private RestTemplate restTemplate;
    
    @Value("${jsgjjsjUrl}")
    private String jsgjjsjUrl;


    /**
     * 入库新增台账数据.
     */
    @Override
    public void countByDrugStorage(BusinessDrugStorage drugStorage) {
        Integer drugInfoId = drugStorage.getDrugInfoId();
        String manufacturer = drugStorage.getManufacturer();

        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("id desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();
        createCriteria.andDrugInfoIdEqualTo(drugInfoId);
        createCriteria.andManufacturerEqualTo(manufacturer);
//        createCriteria.andShelfIdEqualTo(drugStorage.getShelfId());
        // 只取最后一条.
        PageHelper.startPage(1, 1);
        List<BusinessDrugStandingBook> standingBook = drugStandingBookMapper.selectByExample(example);

        BusinessDrugStandingBook drugStandingBook = new BusinessDrugStandingBook();
        // 入库.
        drugStandingBook.setType(1);
        drugStandingBook.setDrugInfoId(drugInfoId);
        drugStandingBook.setDrugNumber(drugStorage.getDrugNumber());
        drugStandingBook.setDrugKind(drugStorage.getDrugKind());
        drugStandingBook.setDrugName(drugStorage.getDrugName());
        drugStandingBook.setDrugType(drugStorage.getDrugType());
        drugStandingBook.setDrugPacking(drugStorage.getDrugPacking());
        drugStandingBook.setDrugSpecification(drugStorage.getDrugSpecification());
        drugStandingBook.setDrugSpecificationUnit(drugStorage.getCreateUnit());//药剂规格

        drugStandingBook.setDrugStorageId(drugStorage.getId());
        drugStandingBook.setStorageCount(drugStorage.getStorageCount());
        drugStandingBook.setManufacturer(manufacturer);
        drugStandingBook.setShelfId(drugStorage.getShelfId());
        drugStandingBook.setCreateTime(drugStorage.getCreateTime());
        drugStandingBook.setOrgId(drugStorage.getOrgId());
        drugStandingBook.setIsLastShelfData(1);

        // 原台账数量.
        String amount = getLastManufacturerCount(drugInfoId, manufacturer);
        BigDecimal y_amount = new BigDecimal(amount);//原来的台账数量
        BigDecimal rk_num = new BigDecimal(drugStorage.getStorageCount());//本次入库数量
        if (standingBook != null && standingBook.size() > 0) {
            BusinessDrugStandingBook drugStandingBookBefore = standingBook.get(0);
            String shelfAmount = drugStandingBookBefore.getShelfAmount();

            //入库后的最新台账数量
            String new_amount = amount(amount, drugStorage.getStorageCount(), SCALE_ADD);
            drugStandingBook.setAmount(new_amount);

            // 新的货架号台账数量 = 原货架号台账数量 + 入库数量.
            String new_shelfAmount = amount(shelfAmount, drugStorage.getStorageCount(), SCALE_ADD);
            drugStandingBook.setShelfAmount(new_shelfAmount.trim());

            // 修改原数据的状态.
            drugStandingBookBefore.setIsLastShelfData(0);
            drugStandingBookBefore.setUpdatetime(new Date());
            drugStandingBookMapper.updateByPrimaryKeySelective(drugStandingBookBefore);
            this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "u");
        } else {
            // 第一次，两个台账数量都等于入库数量.
            String new_amount = amount(amount, drugStorage.getStorageCount(), SCALE_ADD);//入库后的最新台账数量
            drugStandingBook.setAmount(new_amount.trim());
            drugStandingBook.setShelfAmount(drugStorage.getStorageCount());
        }
        // 新增.
        drugStandingBook.setUpdatetime(new Date());
        drugStandingBookMapper.insert(drugStandingBook);
        
        this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "i");
    }

    @Override
    public List<BusinessDrugStandingBook> getShelfStandingBook(HttpServletRequest request, Integer drugKind, Integer drugName) {
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        List<BusinessDrugStandingBook> shelfStandingBook = null;
        if (null != orgId)
            shelfStandingBook = drugStandingBookMapper.getShelfStandingBook(orgId, drugKind, drugName);
        return shelfStandingBook;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void countByDrugUse(BusinessDrugUseDetail businessDrugUseDetail) {
        Integer drugInfoId = businessDrugUseDetail.getDrugInfoId();
        String manufacturer = businessDrugUseDetail.getManufacturer();
        Integer shelfId = businessDrugUseDetail.getShelfId();

        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("id desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();

        // 药剂id.
        createCriteria.andDrugInfoIdEqualTo(drugInfoId);
        // 生产厂家.
        createCriteria.andManufacturerEqualTo(manufacturer);
        // 货架号.
        //createCriteria.andShelfIdEqualTo(shelfId);

        // 只取最后一条.
        PageHelper.startPage(1, 1);
        List<BusinessDrugStandingBook> standingBook = drugStandingBookMapper.selectByExample(example);

        BusinessDrugStandingBook drugStandingBook = new BusinessDrugStandingBook();
        // 出库.
        drugStandingBook.setType(3);
        drugStandingBook.setDrugInfoId(drugInfoId);
        drugStandingBook.setDrugNumber(businessDrugUseDetail.getDrugNumber());
        drugStandingBook.setDrugKind(businessDrugUseDetail.getDrugKind());
        drugStandingBook.setDrugName(businessDrugUseDetail.getDrugName());
        drugStandingBook.setDrugType(businessDrugUseDetail.getDrugType());
        drugStandingBook.setDrugPacking(businessDrugUseDetail.getDrugPacking());
        drugStandingBook.setDrugSpecification(businessDrugUseDetail.getDrugSpecification());
        drugStandingBook.setDrugUseId(businessDrugUseDetail.getZid());
        drugStandingBook.setDeliveryCount(businessDrugUseDetail.getUseCount());
        drugStandingBook.setManufacturer(manufacturer);
        drugStandingBook.setShelfId(shelfId);
        drugStandingBook.setCreateTime(businessDrugUseDetail.getCreateTime());
        drugStandingBook.setOrgId(businessDrugUseDetail.getOrgId());
        drugStandingBook.setIsLastShelfData(1);
        drugStandingBook.setDrugSpecificationUnit(businessDrugUseDetail.getDrugSpecificationUnit());

        if (standingBook != null && standingBook.size() > 0) {
            BusinessDrugStandingBook drugStandingBookBefore = standingBook.get(0);
            String amount = getLastManufacturerCount(drugInfoId, manufacturer);
            String shelfAmount = drugStandingBookBefore.getShelfAmount();

            // 新的台账数量 = 原台账数量 - 出库数量.
            String new_amount = amount(amount, businessDrugUseDetail.getUseCount(), SCALE_DEL);
            drugStandingBook.setAmount(new_amount);
            // 新的货架号台账数量 = 原货架号台账数量 - 出库数量.
            String new_shelfAmount = amount(shelfAmount, businessDrugUseDetail.getUseCount(), SCALE_DEL);
            drugStandingBook.setShelfAmount(new_shelfAmount);

            // 修改原数据的状态.
            drugStandingBookBefore.setIsLastShelfData(0);
            drugStandingBookBefore.setUpdatetime(new Date());
            drugStandingBookMapper.updateByPrimaryKeySelective(drugStandingBookBefore);
            this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "u");
        } else {
            // 第一次.
            throw new RuntimeException("没有对应的数据可以出库!");
        }
        // 新增.
        drugStandingBook.setUpdatetime(new Date());
        drugStandingBookMapper.insert(drugStandingBook);
        this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "i");
    }

    private String amount(String y_num, String rk_num, String type) {
        String new_amount = "";

        BigDecimal amount = new BigDecimal(y_num);//原来的台账数量
        BigDecimal num = new BigDecimal(rk_num);//本次入库或出库的数量

        //加法
        if ("add".equals(type)) {
            // 新的数量 = 原数量 + 入库数量.
            BigDecimal new_num = amount.add(num);//入库后的最新台账数量
            new_amount = new_num.toString().trim();
        }
        //减法
        if ("del".equals(type)) {
            // 新的数量 = 原数量 - 出库数量.
            BigDecimal new_num = amount.subtract(num);
            new_amount = new_num.toString().trim();
        }

        return new_amount;
    }


    private String getLastManufacturerCount(Integer drugInfoId, String manufacturer) {
        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("id desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();

        // 药剂id.
        createCriteria.andDrugInfoIdEqualTo(drugInfoId);
        // 生产厂家.
        createCriteria.andManufacturerEqualTo(manufacturer);

        // 只取最后一条.
        PageHelper.startPage(1, 1);
        List<BusinessDrugStandingBook> standingBook = drugStandingBookMapper.selectByExample(example);
        if (standingBook != null && standingBook.size() > 0) {
            BusinessDrugStandingBook drugStandingBookBefore = standingBook.get(0);
            String amount = drugStandingBookBefore.getAmount();
            return amount;
        } else {
            return "0";
        }
    }

    /*@Override
    public List<BusinessDrugStandingBook> getManufacturerStandingBook(Integer pageNum, Integer pageSize) {
//        PageHelper.startPage(pageNum, pageSize);
        return drugStandingBookMapper.getManufacturerStandingBook();
    }*/

    /**
     * 获取生产厂家的台账详情.
     */
    @Override
    public List<BusinessDrugStandingBook> getDetailListByManufacturer(HttpServletRequest request, Integer pageNum, Integer pageSize, BusinessDrugStandingBook drugStandingBook) {
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        // 查询条件
        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("create_time desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();
        // 药剂id.
        if (drugStandingBook.getDrugInfoId() != null) {
            createCriteria.andDrugInfoIdEqualTo(drugStandingBook.getDrugInfoId());
        }
        // 生产厂家.
        if (drugStandingBook.getManufacturer() != null) {
            createCriteria.andManufacturerEqualTo(drugStandingBook.getManufacturer());
        }
        if (null != orgId)
            createCriteria.andOrgIdEqualTo(orgId);
        // 分页.
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        return drugStandingBookMapper.selectByExample(example);
    }

    /**
     * 通过盘点修改台账.
     */
    @Override
    public void countByDrugCheck(BusinessDrugCheckDetail businessDrugCheckDetail) {
        Integer drugInfoId = businessDrugCheckDetail.getDrugInfoId();
        String manufacturer = businessDrugCheckDetail.getManufacturer();
        Integer shelfId = businessDrugCheckDetail.getShelfId();

        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("id desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();
        createCriteria.andDrugInfoIdEqualTo(drugInfoId);
        createCriteria.andManufacturerEqualTo(manufacturer);
        //createCriteria.andShelfIdEqualTo(shelfId);
        // 只取最后一条.
        PageHelper.startPage(1, 1);
        List<BusinessDrugStandingBook> standingBook = drugStandingBookMapper.selectByExample(example);

        BusinessDrugStandingBook drugStandingBook = new BusinessDrugStandingBook();
        // 盘点.
        drugStandingBook.setType(4);
        drugStandingBook.setDrugInfoId(drugInfoId);
        drugStandingBook.setDrugNumber(businessDrugCheckDetail.getDrugNumber());
        drugStandingBook.setDrugKind(businessDrugCheckDetail.getDrugKind());
        drugStandingBook.setDrugName(businessDrugCheckDetail.getDrugName());
        drugStandingBook.setDrugType(businessDrugCheckDetail.getDrugType());
        drugStandingBook.setDrugPacking(businessDrugCheckDetail.getDrugPacking());
        drugStandingBook.setDrugSpecification(businessDrugCheckDetail.getDrugSpecification());
        drugStandingBook.setDrugSpecificationUnit(businessDrugCheckDetail.getDrugSpecificationUnit());
        drugStandingBook.setManufacturer(manufacturer);
        drugStandingBook.setShelfId(shelfId);
        drugStandingBook.setCreateTime(new Date());
        drugStandingBook.setOrgId(businessDrugCheckDetail.getOrgId());
        drugStandingBook.setIsLastShelfData(1);
        // 盘点id.
        drugStandingBook.setDrugCheckId(businessDrugCheckDetail.getId());

        // 货架对应 台账数量.
        String shelfAmount = businessDrugCheckDetail.getShelfAmount();
        // 盘点数量.
        String checkCount = businessDrugCheckDetail.getCheckCount();

        if (checkCount != null && shelfAmount != null) {
            // 原台账数量.
            String amount = getLastManufacturerCount(drugInfoId, manufacturer);
            if (Double.parseDouble(checkCount) > Double.parseDouble(shelfAmount)) {
                // 盘点数量大于货架对应 台账数量，相当于入库.
                BigDecimal storageCount = new BigDecimal(new BigDecimal(checkCount).subtract(new BigDecimal(shelfAmount)).toString());
                //Integer storageCount = checkCount - shelfAmount;
                drugStandingBook.setStorageCount(storageCount.toString().trim());
                if (standingBook != null && standingBook.size() > 0) {
                    BusinessDrugStandingBook drugStandingBookBefore = standingBook.get(0);
                    // 新的台账数量 = 原台账数量 + 入库数量.
                    BigDecimal new_amount = new BigDecimal(new BigDecimal(amount).add(storageCount).toString());
                    drugStandingBook.setAmount(new_amount.toString().trim());
                    // 新的货架号台账数量 = 原货架号台账数量 + 入库数量.
                    BigDecimal new_shelfAmount = new BigDecimal(new BigDecimal(shelfAmount).add(storageCount).toString());
                    drugStandingBook.setShelfAmount(new_shelfAmount.toString().trim());

                    // 修改原数据的状态.
                    drugStandingBookBefore.setIsLastShelfData(0);
                    drugStandingBookBefore.setUpdatetime(new Date());
                    drugStandingBookMapper.updateByPrimaryKeySelective(drugStandingBookBefore);
                    this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "u");
                }

            } else if (Double.parseDouble(checkCount) < Double.parseDouble(shelfAmount)) {
                // 盘点数量小于货架对应 台账数量，相当于出库.
                BigDecimal new_deliveryCount = new BigDecimal(new BigDecimal(shelfAmount).subtract(new BigDecimal(checkCount)).toString());
                drugStandingBook.setDeliveryCount(new_deliveryCount.toString().trim());
                if (standingBook != null && standingBook.size() > 0) {
                    BusinessDrugStandingBook drugStandingBookBefore = standingBook.get(0);

                    // 新的台账数量 = 原台账数量 - 出库数量.
                    BigDecimal new_amount = new BigDecimal(new BigDecimal(amount).subtract(new_deliveryCount).toString());
                    drugStandingBook.setAmount(new_amount.toString().trim());

                    // 新的货架号台账数量 = 原货架号台账数量 - 出库数量.
                    BigDecimal new_shelfAmount = new BigDecimal(new BigDecimal(shelfAmount).subtract(new_deliveryCount).toString());
                    drugStandingBook.setShelfAmount(new_shelfAmount.toString().trim());

                    // 修改原数据的状态.
                    drugStandingBookBefore.setIsLastShelfData(0);
                    drugStandingBookBefore.setUpdatetime(new Date());
                    drugStandingBookMapper.updateByPrimaryKeySelective(drugStandingBookBefore);
                    this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "u");
                } else {
                    // 第一次.
                    throw new RuntimeException("没有对应的数据可以出库!");
                }
            } else {
                // 相等就不用盘点了.
                return;
            }
            // 新增台账.
            drugStandingBook.setUpdatetime(new Date());
            drugStandingBookMapper.insert(drugStandingBook);
            this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "i");
        }
    }

    /**
     * 查询搜索列表
     *
     * @param example 查询条件
     * @return list
     */
    @Override
    public List<BusinessDrugStandingBook> queryByExample(BusinessDrugStandingBookExample example) {
        return drugStandingBookMapper.selectByExample(example);
    }

    /**
     * 生产装备汇总统计
     *
     * @return
     */
    @Override
    public List<Map<String, Object>> queryCountByType(Integer orgId) {
        return drugStandingBookMapper.queryCountByType(orgId);
    }

    /**
     * 药剂归还更新台账信息
     *
     * @param drugRestore
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addByDrugRestore(BusinessDrugRestoreDetail drugRestoreDetail) {
        // 查询更新
        Integer drugInfoId = drugRestoreDetail.getDrugInfoId();
        String manufacturer = drugRestoreDetail.getManufacturer();

        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("id desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();
        // 药剂id.
        createCriteria.andDrugInfoIdEqualTo(drugInfoId);
        // 生产厂家.
        createCriteria.andManufacturerEqualTo(manufacturer);

        // 只取最后一条.
        PageHelper.startPage(1, 1);
        List<BusinessDrugStandingBook> standingBook = drugStandingBookMapper.selectByExample(example);

        BusinessDrugStandingBook drugStandingBook = new BusinessDrugStandingBook();
        drugStandingBook.setType(2); // 归还标记
        drugStandingBook.setDrugRestoreId(drugRestoreDetail.getZid()); // 关联id
        drugStandingBook.setDrugNumber(drugRestoreDetail.getDrugNumber()); // 药剂信息编号
        drugStandingBook.setDrugKind(drugRestoreDetail.getDrugKind()); // 种类
        drugStandingBook.setDrugName(drugRestoreDetail.getDrugName()); // 名称
        drugStandingBook.setDrugType(drugRestoreDetail.getDrugType()); // 形态
        drugStandingBook.setDrugPacking(drugRestoreDetail.getDrugPacking()); // 包装
        drugStandingBook.setDrugSpecification(drugRestoreDetail.getDrugSpecification()); // 规格
        drugStandingBook.setDrugSpecificationUnit(drugRestoreDetail.getDrugSpecificationUnit());//规格单位
        drugStandingBook.setManufacturer(manufacturer); // 生产厂家
        drugStandingBook.setStorageCount(drugRestoreDetail.getRestoreNumber()); // 归还数量
        drugStandingBook.setShelfId(drugRestoreDetail.getShelfId()); // 货架id
        drugStandingBook.setCreateTime(ParameterUtil.string2datetime(drugRestoreDetail.getCreateTime())); // 创建时间
        drugStandingBook.setDrugInfoId(drugInfoId); //药剂信息id
        drugStandingBook.setIsLastShelfData(1); // 是否是最后的货架号盘点数据
        drugStandingBook.setOrgId(drugRestoreDetail.getOrgId()); // 组织id
        // 更新台账总数量
        if (standingBook != null && standingBook.size() > 0) {
            BusinessDrugStandingBook drugStandingBookBefore = standingBook.get(0);
            String amount = getLastManufacturerCount(drugInfoId, manufacturer);
            String shelfAmount = drugStandingBookBefore.getShelfAmount();

            // 新的台账数量 = 原台账数量 + 归还数量.
            BigDecimal new_amount = new BigDecimal(new BigDecimal(amount).add(new BigDecimal(drugRestoreDetail.getRestoreNumber())).toString());
            drugStandingBook.setAmount(new_amount.toString().trim());
            // 新的货架号台账数量 = 原货架号台账数量 + 归还数量.
            BigDecimal new_shelfAmount = new BigDecimal(new BigDecimal(shelfAmount).add(new BigDecimal(drugRestoreDetail.getRestoreNumber())).toString());
            drugStandingBook.setShelfAmount(new_shelfAmount.toString().trim());

            // 修改原数据的状态.
            drugStandingBookBefore.setIsLastShelfData(0);
            drugStandingBookBefore.setUpdatetime(new Date());
            drugStandingBookMapper.updateByPrimaryKeySelective(drugStandingBookBefore);
            this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "u");
        } else {
            // 第一次.
            throw new RuntimeException("没有对应的数据可以归还!");
        }
        // 新增
        drugStandingBook.setUpdatetime(new Date());
        drugStandingBookMapper.insertSelective(drugStandingBook);
        this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "i");
    }

    /**
     * 药剂销毁更新台账信息
     *
     * @param drugDestroy
     */
    @Override
    public void countByDrugDestroy(BusinessDrugDestroy drugDestroy) {
        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        example.setOrderByClause("id desc");
        BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();

        // 药剂种类
        createCriteria.andDrugKindEqualTo(drugDestroy.getDrugKind());
        // 药剂名称
        createCriteria.andDrugNameEqualTo(drugDestroy.getDrugName());
        // 药剂形态
        createCriteria.andDrugTypeEqualTo(drugDestroy.getDrugType());
        // 生产厂家.
        createCriteria.andManufacturerEqualTo(drugDestroy.getManufacturer());

        // 只取最后一条.
        PageHelper.startPage(1, 1);
        List<BusinessDrugStandingBook> standingBook = drugStandingBookMapper.selectByExample(example);

        if (null != standingBook && standingBook.size() > 0) {
            BusinessDrugStandingBook standingBookOld = standingBook.get(0);
            BusinessDrugStandingBook drugStandingBook = new BusinessDrugStandingBook();
            // 出库.
            drugStandingBook.setType(5); //销毁标识
            drugStandingBook.setDrugInfoId(standingBookOld.getDrugInfoId());
            drugStandingBook.setDrugNumber(standingBookOld.getDrugNumber());
            drugStandingBook.setDrugKind(drugDestroy.getDrugKind());
            drugStandingBook.setDrugName(drugDestroy.getDrugName());
            drugStandingBook.setDrugType(drugDestroy.getDrugType());
            drugStandingBook.setDrugPacking(standingBookOld.getDrugPacking());
            drugStandingBook.setDrugSpecification(standingBookOld.getDrugSpecification());
            drugStandingBook.setDeliveryCount(drugDestroy.getDestroyAmount());
            drugStandingBook.setManufacturer(drugDestroy.getManufacturer());
            drugStandingBook.setShelfId(standingBookOld.getShelfId());
            drugStandingBook.setCreateTime(drugDestroy.getDestroyDate());
            drugStandingBook.setOrgId(drugDestroy.getOrgId());
            drugStandingBook.setIsLastShelfData(1);
            drugStandingBook.setDrugSpecificationUnit(standingBookOld.getDrugSpecificationUnit());

            //计算修改原数据
            String amount = standingBookOld.getAmount();
            String shelfAmount = standingBookOld.getShelfAmount();
            // 新的台账数量 = 原台账数量 - 出库数量.
            BigDecimal new_amount = new BigDecimal(new BigDecimal(amount).subtract(new BigDecimal(drugDestroy.getDestroyAmount())).toString());
            drugStandingBook.setAmount(new_amount.toString().trim());
            // 新的货架号台账数量 = 原货架号台账数量 - 出库数量.
            BigDecimal new_shelfAmount = new BigDecimal(new BigDecimal(shelfAmount).subtract(new BigDecimal(drugDestroy.getDestroyAmount())).toString());
            drugStandingBook.setShelfAmount(new_shelfAmount.toString().trim());

            // 修改原数据的状态.
            standingBookOld.setIsLastShelfData(0);
            standingBookOld.setUpdatetime(new Date());
            drugStandingBookMapper.updateByPrimaryKeySelective(standingBookOld);
            this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "u");


            // 新增.
            drugStandingBook.setUpdatetime(new Date());
            drugStandingBookMapper.insert(drugStandingBook);
            this.gjjjk(drugStandingBook.getId(), drugStandingBook.getOrgId(), "i");

        } else {
            throw new IllegalArgumentException("没有相应的数据!");
        }

    }

    /**
     * 获取台账剩余存数量.
     *
     * @param drugStandingBook
     * @return
     */
    @Override
    public String getRemainingQuantity(BusinessDrugStandingBook drugStandingBook) {
        BusinessDrugStandingBookExample example = getExapleObject(drugStandingBook);
        List<BusinessDrugStandingBook> businessDrugStandingBooks = drugStandingBookMapper.selectByExample(example);
        if (businessDrugStandingBooks.size() > 0)
            return businessDrugStandingBooks.get(0).getAmount(); // 台账剩余存数量
        return "0";
    }

    // 查询条件
    private synchronized BusinessDrugStandingBookExample getExapleObject(BusinessDrugStandingBook drugStandingBook) {
        BusinessDrugStandingBookExample example = new BusinessDrugStandingBookExample();
        if (drugStandingBook != null) {
            BusinessDrugStandingBookExample.Criteria createCriteria = example.createCriteria();
            // 查询条件
            createCriteria.andIsLastShelfDataEqualTo(1); // 是否是最后的货架号盘点数据
            Integer orgId = drugStandingBook.getOrgId();
            if (null != orgId)
                createCriteria.andOrgIdEqualTo(orgId); // 组织编码
            Integer drugName = drugStandingBook.getDrugName();
            if (null != drugName)
                createCriteria.andDrugNameEqualTo(drugName); // 药剂名称 drug_name
            Integer drugType = drugStandingBook.getDrugType();
            if (null != drugType)
                createCriteria.andDrugTypeEqualTo(drugType); // 药剂形态 drug_type
            Integer drugKind = drugStandingBook.getDrugKind();
            if (null != drugKind)
                createCriteria.andDrugKindEqualTo(drugKind); // 药剂类型 drug_kind
            String manufacturer = drugStandingBook.getManufacturer();
            if (StringUtils.isNotBlank(manufacturer))
                createCriteria.andManufacturerEqualTo(manufacturer); // 生产厂家 manufacturer
        }
        return example;
    }

	@Override
	public List<Map<String, Object>> getStatementList(Map<String, Object> map) {
		// TODO Auto-generated method stub
		List<Map<String, Object>> list = drugStandingBookMapper.getAllDataList(map);//无期初库存----kind name 规格单位分组
		
		Map mapParam = new HashMap<>();
		mapParam.put("orgId", map.get("orgId"));
		mapParam.put("startDate", map.get("startDate"));
		mapParam.put("endDate", map.get("endDate"));
		List<Map<String, Object>> listCr = drugStandingBookMapper.getStatementList(mapParam);
		
		for (Map<String, Object> mapAll : list) {
			for (Map<String, Object> mapCr : listCr) {
				if(mapAll.get("drugkind").equals(mapCr.get("drugkind")) && mapAll.get("drugname").equals(mapCr.get("drugname")) && 
						mapAll.get("drugspecificationunit").equals(mapCr.get("drugspecificationunit"))	){
					mapAll.put("rucount", mapCr.get("rucount"));
					mapAll.put("chucount", mapCr.get("chucount"));
				}
			}
			if(mapAll.get("rucount") == null){
				mapAll.put("rucount", 0);
			}
			if(mapAll.get("chucount") == null){
				mapAll.put("chucount",0);
			}
		}
		
		
		List<Map<String, Object>> list1 = drugStandingBookMapper.getOpeningList(map);//----kind name 规格 规格单位分组
		for (Map<String, Object> map1 : list1) {
			Map mapEvery = new HashMap<>();
			mapEvery.put("org_id", map.get("orgId"));
			mapEvery.put("drug_kind", map1.get("drugkind"));
			mapEvery.put("drug_name", map1.get("drugname"));
			mapEvery.put("drug_specification", map1.get("drugspecification"));
			mapEvery.put("drug_specification_unit", map1.get("drugspecificationunit"));
			mapEvery.put("startDate", map.get("startDate"));
			String everyQkucun = drugStandingBookMapper.getOpeningListEvery(mapEvery);//每一个规格的期初库存
			if(everyQkucun != null){
				map1.put("startAmount", everyQkucun);
			}else{
				map1.put("startAmount", 0);
			}
		}
		for (Map<String, Object> mapMain : list) {
			for (Map<String, Object> map1 : list1) {
				if(mapMain.get("drugkind").equals(map1.get("drugkind")) && mapMain.get("drugname").equals(map1.get("drugname"))
						&& mapMain.get("drugspecificationunit").equals(map1.get("drugspecificationunit"))){
					
					if(mapMain.containsKey("startAmount") && mapMain.get("startAmount")!=null){
						//System.out.println(mapMain.get("startAmount")+"/////"+map1.get("startAmount"));
						//System.out.println((String)mapMain.get("startAmount")+"*****"+(String) map1.get("startAmount"));
						/*BigDecimal BigDecimal = new BigDecimal((String)mapMain.get("startAmount"));
						BigDecimal BigDecima2 = new BigDecimal((String)map1.get("startAmount"));*/
						BigDecimal BigDecimal = new BigDecimal(mapMain.get("startAmount")+"");
						BigDecimal BigDecima2 = new BigDecimal(map1.get("startAmount")+"");
						
						map1.put("startAmount", BigDecimal.add(BigDecima2));
						mapMain.put("startAmount", map1.get("startAmount"));
					}else{
						mapMain.put("startAmount", map1.get("startAmount"));
					}
				}
			}
			
		}
		
		List<Map<String, Object>> list5 = drugStandingBookMapper.getEndAmountList(map);//期末库存
		
		
		//计算期末库存 总量
		
			for (Map<String, Object> map2 : list) {
				if(list5.size()>0){
					for (Map<String, Object> map5 : list5) {
						if(map5.get("drugkind").equals(map2.get("drugkind")) && map5.get("drugname").equals(map2.get("drugname"))
								&& map5.get("drugspecificationunit").equals(map2.get("drugspecificationunit"))){
							map2.put("endAmount", map5.get("endamount"));//期末库存
						}
					}
				}else{
					map2.put("endAmount", 0);//------
				}
				
			}
		
		
		
		int drugKindCount = 0;
		int drugNameCount = 0;
		
		List<Map<String, Object>> list3 = drugStandingBookMapper.getAllDataList(map);
		List<Map<String, Object>> list4 = drugStandingBookMapper.getAllDataList(map);

		//计算合并的行	
		for (int i = 0; i < list.size(); i++) {
			 drugKindCount = 0;
			for (int j = 0; j < list3.size(); j++) {
					
					if(list.get(i).get("drugkind").equals(list3.get(j).get("drugkind"))){
						drugKindCount++;
						list3.remove(j);
						j = j-1;
					 }	
				
			}
			list.get(i).put("drugKindCount", drugKindCount);
		}
		
		//计算合并的行
		for (int i = 0; i < list.size(); i++) {
			 drugNameCount = 0;
			for (int j = 0; j < list4.size(); j++) {
					
					if(list.get(i).get("drugname").equals(list4.get(j).get("drugname"))){
						drugNameCount++;
						list4.remove(j);
						j = j-1;
					}
			}
			list.get(i).put("drugNameCount", drugNameCount);
			 
		}
		
		
		
		return list;
	}
	
	
	/**
	 * 国家局数据
	 */
    public void gjjjk(Integer id, Integer orgId,String czbz) {
        
       String tableName = "ODS_UP_YJXXJK";
		/**
        * restTemplate调用
        */
       //String url = "http://localhost:9022/recPublish/sendMessage";//
       //发送post请求，并打印结果，以String类型接收响应结果JSON字符串
		
       MultiValueMap<String, Object> sendMap = new LinkedMultiValueMap<>();
		sendMap.add("tableName", tableName);
		sendMap.add("czbz", czbz);
		sendMap.add("ywId", id);
		sendMap.add("orgId", orgId);

       restTemplate.postForObject(jsgjjsjUrl, sendMap, String.class);
    }

}
