package com.chinaitop.depot.business.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Service;

import com.chinaitop.depot.business.mapper.BusinessDrugStorageMapper;
import com.chinaitop.depot.business.model.BusinessDrugInfo;
import com.chinaitop.depot.business.model.BusinessDrugInfoKey;
import com.chinaitop.depot.business.model.BusinessDrugStorage;
import com.chinaitop.depot.business.model.BusinessDrugStorageExample;
import com.chinaitop.depot.business.service.BusinessDrugInfoService;
import com.chinaitop.depot.business.service.BusinessDrugStandingBookService;
import com.chinaitop.depot.business.service.BusinessDrugStorageService;


@Service
public class BusinessDrugStorageServiceImpl implements BusinessDrugStorageService {
    @Resource
    private BusinessDrugStorageMapper drugStorageMapper;
    @Resource
    private BusinessDrugStandingBookService drugStandingBookService;
    @Resource
    private BusinessDrugInfoService drugInfoService;
    @Resource
    private BusinessDrugInfoKey drugInfoKey;

    public List<BusinessDrugStorage> queryByExample(BusinessDrugStorageExample example) {
        return drugStorageMapper.selectByExample(example);
    }
    
    public BusinessDrugStorage findById(Integer id) {
        return drugStorageMapper.selectByPrimaryKey(id);
    }

    /**
     * 保存.
     */
    public Map<String, Object> add(@NotNull BusinessDrugStorage drugStorage, Integer userId, Integer orgId) {
        Map<String, Object> returnMap = new HashMap<>();
        
        // 当前登录人，登录部门，登陆库.
        drugStorage.setCreater(userId);
        Integer drugInfoId = drugStorage.getDrugInfoId();
        drugInfoKey.setId(drugInfoId);
        drugInfoKey.setOrgId(orgId);
        if (drugInfoId != null) {
            BusinessDrugInfo drugInfo = drugInfoService.findById(drugInfoKey);
            if (drugInfo != null) {
                if (drugInfo.getIsEffective() != 1) {
                    // 如果该药剂基本信息不是使用中的，设置为使用中.
                    drugInfo.setIsEffective(1);
                    drugInfoService.update(drugInfo);
                }
            } else {
                returnMap.put("error", "该药剂编号已删除，请重新选择！");
                return returnMap;
            }
            drugStorage.setDrugKind(drugInfo.getDrugKind());
            drugStorage.setDrugName(drugInfo.getDrugName());
            drugStorage.setDrugType(drugInfo.getDrugType());
            drugStorage.setDrugPacking(drugInfo.getDrugPacking());
            drugStorage.setDrugSpecification(drugInfo.getDrugSpecification());
            
            drugStorage.setCreateDepot(orgId);
            drugStorage.setOrgId(orgId);
            drugStorageMapper.insert(drugStorage);
            
            // 更新台账表.
            drugStandingBookService.countByDrugStorage(drugStorage);
        } else {
            returnMap.put("error", "请选择药剂编号！");
        }
        return returnMap;
        
    }

    
    public void update(BusinessDrugStorage drugStorage) {
        drugStorageMapper.updateByPrimaryKey(drugStorage);
    }

    
    public void remove(Integer id) {
        drugStorageMapper.deleteByPrimaryKey(id);
    }

    /**
     * 封装药剂生产厂家
     * @return
     */
    @Override
    public List<Map<String,Object>> getManufacturer() {
        List<Map<String,Object>> manufacturerList = drugStorageMapper.getManufacturer();
        return manufacturerList;
    }

    /**
     * 根据组织编码和申请通过详情id获取药剂采购申请已通过的总数
     * @param drugPurchaseBid
     * @param orgId
     * @return
     */
    @Override
    public Integer getRKSum(Integer drugPurchaseBid, Integer orgId) {
        Map<String, Object> map = new HashMap<>();
        map.put("drugPurchaseBid", drugPurchaseBid);
        map.put("orgId", orgId);
        return drugStorageMapper.getRKSum(map);
    }


}
