package com.chinaitop.depot.business.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.mapper.BusinessApprovalMapper;
import com.chinaitop.depot.business.mapper.BusinessDrugUseapplyMapper;
import com.chinaitop.depot.business.model.*;
import com.chinaitop.depot.business.model.vo.BusinessDrugUseApplyAuditVO;
import com.chinaitop.depot.business.model.vo.HistoryList;
import com.chinaitop.depot.business.service.BusinessApprovalService;
import com.chinaitop.depot.business.service.BusinessDrugUseapplyDetailService;
import com.chinaitop.depot.business.service.BusinessDrugUseapplyService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description:
 * @create 2018-08-24 14:10
 */
@Service
public class BusinessDrugUseapplyserviceImpl implements BusinessDrugUseapplyService {

    @Resource
    private BusinessDrugUseapplyMapper drugUseapplyMapper;
    @Resource
    private BusinessDrugUseapplyDetailService drugUseapplyDetailService;
    @Resource
    private BusinessApprovalService approvalService;
    @Resource
    private BusinessApprovalMapper approvalMapper;

    /**
     * 条件查询列表数据
     *
     * @param example
     * @return
     */
    @Override
    public List<BusinessDrugUseapply> queryByExample(BusinessDrugUseapplyExample example) {
        return drugUseapplyMapper.selectByExample(example);
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    @Override
    public BusinessDrugUseapply findById(Integer id) {
        return drugUseapplyMapper.selectByPrimaryKey(id);
    }

    /**
     * 添加数据
     *
     * @param drugUseApply
     * @param drugUseApplyDetailList
     * @param userId
     * @param orgId
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer add(BusinessDrugUseapply drugUseApply, List<BusinessDrugUseapplyDetail> drugUseApplyDetailList, Integer userId, Integer orgId) {
        drugUseApply.setCreater(userId);
        drugUseApply.setCreateTime(new Date());
        drugUseApply.setOrgId(orgId);
        drugUseApply.setProcessInstanceId("68866886");
        // 新增.
        int insert = drugUseapplyMapper.insert(drugUseApply);
        // 插入子表数据.
        if (insert > 0) {
            for (BusinessDrugUseapplyDetail drugUseApplyDetail : drugUseApplyDetailList) {
                drugUseApplyDetail.setZid(drugUseApply.getId());
                drugUseApplyDetail.setOrgId(drugUseApply.getOrgId());
                drugUseApplyDetail.setCreateTime(new Date());
                drugUseapplyDetailService.add(drugUseApplyDetail);
            }
        }
        return drugUseApply.getId();
    }

    /**
     * 修改
     *
     * @param drugUseApply
     * @param drugUseApplyDetailList
     * @param userId
     * @param orgId
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateData(BusinessDrugUseapply drugUseApply, List<BusinessDrugUseapplyDetail> drugUseApplyDetailList, Integer userId, Integer orgId) {
        drugUseApply.setCreater(userId);
        drugUseApply.setCreateTime(new Date());
        drugUseApply.setOrgId(orgId);
        // 新增.
        drugUseapplyMapper.updateByPrimaryKeySelective(drugUseApply);

        // 插入子表数据.
        for (BusinessDrugUseapplyDetail drugUseApplyDetail : drugUseApplyDetailList) {
            drugUseApplyDetail.setZid(drugUseApply.getId());
            drugUseapplyDetailService.updateData(drugUseApplyDetail);
        }

    }

    /**
     * 删除，主表和子表数据.
     */
    @Override
    public void remove(Integer id) {
        drugUseapplyMapper.deleteByPrimaryKey(id);
        //主表id关联子表zid
        BusinessDrugUseapplyDetailExample example = new BusinessDrugUseapplyDetailExample();
        example.createCriteria().andZidEqualTo(id);
        drugUseapplyDetailService.deleteByExample(example);
    }

    /**
     * 根据领用编号更新领用申请信息 是否领用 0:已领用 1未领用
     *
     * @param applyNumber
     */
    @Override
    public void update(String applyNumber) {
        //条件
        BusinessDrugUseapplyExample example = new BusinessDrugUseapplyExample();
        BusinessDrugUseapplyExample.Criteria criteria = example.createCriteria();
        criteria.andApplyNumberEqualTo(applyNumber);
        //更新对象值
        BusinessDrugUseapply drugUseApply = new BusinessDrugUseapply();
        drugUseApply.setIsUse("0"); //更新为已领用
        drugUseapplyMapper.updateByExampleSelective(drugUseApply, example);
    }

    /**
     * 更新审批状态
     *
     * @param id
     * @return
     */
    @Override
    public void updateUseApplyData(Integer id, String userInfoJson, String orgInfoJson, String auditUserId) {
        JSONObject jsonUserInfo = JSON.parseObject(userInfoJson);
        JSONObject jsonOrgInfo = JSON.parseObject(orgInfoJson);
        //更新
        BusinessDrugUseapply drugUseapply = new BusinessDrugUseapply();
        drugUseapply.setId(id);
        drugUseapply.setState("1"); //0待提交，1审批中，2审批结束，3审批驳回, 4审批拒绝
        drugUseapply.setProcessDefinitionId("员工提交");
        drugUseapplyMapper.updateByPrimaryKeySelective(drugUseapply);
        //保存数据到business_approval
        BusinessDrugUseapply drugUseapply1 = drugUseapplyMapper.selectByPrimaryKey(id);
        if (drugUseapply1 != null) {
            BusinessApproval businessApproval = new BusinessApproval();
            businessApproval.setCreateTime(new Date()); //创建时间
            businessApproval.setFromDepartment(jsonOrgInfo.getString("orgName")); //部门 orgName
            businessApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
            businessApproval.setOperator(auditUserId);//已选择的审批人id
            businessApproval.setOperatorName(jsonUserInfo.getString("realName"));//已选择的审批人姓名
            businessApproval.setProcessInstanceId(drugUseapply1.getProcessInstanceId());//流程实例id
            businessApproval.setProjectName("药剂领用申请");//名称
            businessApproval.setResult("待审批");//审批结果
            businessApproval.setTaskName("员工提交");//任务名称
            businessApproval.setTaskType("drugUseApply");//任务类型
            businessApproval.setTaskTypeName(drugUseapply1.getApplyNumber());//任务类型名
            businessApproval.setIsHide(0);//
            businessApproval.setApplyName(jsonUserInfo.getString("realName"));//申请人
            businessApproval.setApplyNameId(jsonUserInfo.getString("userId"));//申请人id
            businessApproval.setApplyTime(drugUseapply1.getCreateTime());//申请时间
            businessApproval.setContent(jsonUserInfo.getString("realName") + "提交"); //提交人
            approvalService.add(businessApproval);
        }
    }

    /**
     * 获取审批列表.
     *
     * @param paramMap
     * @return
     */
    @Override
    public List<BusinessDrugUseApplyAuditVO> getApprovalList(Map<String, Object> paramMap) {
        return drugUseapplyMapper.getApprovalList(paramMap);
    }

    /**
     * 获取审批页面详情.
     *
     * @param modelMap 业务主键
     * @return
     */
    @Override
    public List<HistoryList> getAudit(Map<String, Object> modelMap) {
        return drugUseapplyMapper.getAudit(modelMap);
    }

    /**
     * 添加审批.
     *
     * @param drugUseApplyId 药剂领用数据ID
     * @param businessApproval
     * @param nextUserId       下一个审批人id.
     * @param result           审批结论
     * @param userInfoJson     当前用户信息.
     */
    @SuppressWarnings("all")
    @Override
    public void audit(Integer drugUseApplyId, BusinessApproval businessApproval, String nextUserId, String result, String userInfoJson, String orgInfoJson) {
        JSONObject jsonUserInfo = JSON.parseObject(userInfoJson);
        JSONObject jsonOrgInfo = JSON.parseObject(orgInfoJson);
        BusinessApproval oldBusinessApproval = approvalService.findById(businessApproval.getId());
        // 检测是否并发审核
        String oldResult = oldBusinessApproval.getResult();
        if ("同意".equals(oldResult) || "拒绝".equals(oldResult) || "驳回".equals(oldResult)) {
            throw new RuntimeException("该订单已经审核过，不能再次审核！");
        }
        String resultS = "";
        if ("1".equals(result)) {
            resultS = "同意";
        } else if ("2".equals(result)) {
            resultS = "驳回";
        } else if ("3".equals(result)) {
            resultS = "拒绝";
        }

        // 修改当前中间表.
        oldBusinessApproval.setResult(resultS);
        approvalService.updateByPrimaryKeySelective(oldBusinessApproval);

        //修改申请表状态 //1审批中，2审批结束，3审批驳回, 4审批拒绝
        BusinessDrugUseapply drugUseapply = new BusinessDrugUseapply();
        if (null != drugUseApplyId) {
            drugUseapply.setId(drugUseApplyId);
            BusinessDrugUseapply drugUseapply1 = drugUseapplyMapper.selectByPrimaryKey(drugUseApplyId);
            //保存下一审批人节点
            BusinessApproval newApproval = new BusinessApproval();
            newApproval.setCreateTime(new Date()); //创建时间
            newApproval.setFromDepartment(jsonOrgInfo.getString("orgName")); //部门 orgName
            newApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
            newApproval.setOperator(nextUserId);//已选择的下一节点审批人id
            newApproval.setOperatorName(jsonUserInfo.getString("realName"));//已选择的审批人姓名
            newApproval.setProcessInstanceId(drugUseapply1.getProcessInstanceId());//流程实例id
            newApproval.setProjectName("药剂领用申请");//名称
            if ("1".equals(businessApproval.getResult())) {
                newApproval.setResult("待审批");//审批结果
            }
            if ("2".equals(businessApproval.getResult())) {
                newApproval.setResult("驳回");//审批结果
            }
            if ("3".equals(businessApproval.getResult())) {
                newApproval.setResult("拒绝");//审批结果
            }
            newApproval.setTaskName(jsonUserInfo.getString("realName") + "提交");//任务名称
            newApproval.setTaskType("drugUseApply");//任务类型
            newApproval.setTaskTypeName(drugUseapply1.getApplyNumber());//任务类型名
            newApproval.setIsHide(0);//
            newApproval.setApplyName(jsonUserInfo.getString("realName"));//申请人
            newApproval.setApplyNameId(jsonUserInfo.getString("userId"));//申请人id
            newApproval.setApplyTime(drugUseapply1.getCreateTime());//申请时间
            if (result.equals("1")) { //通过不修改显示审批中
                // 判断审批流程(ProcessDefinitionId为空)
                if (StringUtils.isBlank(drugUseapply1.getProcessDefinitionId()) || "员工提交".equals(drugUseapply1.getProcessDefinitionId())) {
                    newApproval.setTaskName("仓储部经理审批");//任务名称
                    drugUseapply.setProcessDefinitionId("仓储部经理审批"); // 员工第一次提交仓储部经理审批
                    newApproval.setContent(businessApproval.getContent());//审批意见
                    drugUseapplyMapper.updateByPrimaryKeySelective(drugUseapply);
                    approvalService.add(newApproval);
                } else if ("仓储部经理审批".equals(drugUseapply1.getProcessDefinitionId())) { // 判断是否仓储部经理已审批(第二次审批)
                    newApproval.setTaskName("库领导审批");//任务名称
                    drugUseapply.setProcessDefinitionId("审批流程结束"); // 仓储部经理审批提交库领导审批审批流程结束
                    drugUseapply.setState("2");
                    newApproval.setResult(resultS);//审批结果
                    newApproval.setContent(businessApproval.getContent());//审批意见
                    newApproval.setOperator(jsonUserInfo.getString("userId"));
                    drugUseapplyMapper.updateByPrimaryKeySelective(drugUseapply);
                    approvalService.add(newApproval);
                } else {
                    throw new IllegalArgumentException("审批失败!审批流程错误!");
                }
            } else if (result.equals("2")) {//驳回
                drugUseapply.setState("3");
                newApproval.setContent(businessApproval.getContent());//审批意见
                newApproval.setOperator(jsonUserInfo.getString("userId"));
                if (StringUtils.isBlank(drugUseapply1.getProcessDefinitionId()) || "员工提交".equals(drugUseapply1.getProcessDefinitionId())) {
                    newApproval.setTaskName("仓储部经理审批");//任务名称
                    drugUseapply.setProcessDefinitionId(null); // 员工第一次提交仓储部经理审批
                } else if ("仓储部经理审批".equals(drugUseapply1.getProcessDefinitionId())) { // 判断是否仓储部经理已审批(第二次审批)
                    newApproval.setTaskName("库领导审批");//任务名称
                    drugUseapply.setProcessDefinitionId(null); // 仓储部经理审批提交库领导审批审批流程结束
                    newApproval.setResult(resultS);//审批结果
                    newApproval.setOperator(jsonUserInfo.getString("userId"));
                    // 库领导驳回将所有已审批同意的修改为驳回
                    BusinessApproval b = new BusinessApproval();
                    BusinessApprovalExample bExample = new BusinessApprovalExample();
                    BusinessApprovalExample.Criteria criteria = bExample.createCriteria();
                    criteria.andTaskTypeNameEqualTo(drugUseapply1.getApplyNumber());
                    b.setResult(resultS);
                    approvalMapper.updateByExampleSelective(b, bExample);
                }
                drugUseapplyMapper.updateByPrimaryKeySelective(drugUseapply);
                approvalService.add(newApproval);
            } else if (result.equals("3")) {//拒绝
                drugUseapply.setState("4");
                newApproval.setContent(businessApproval.getContent());//审批意见
                newApproval.setOperator(jsonUserInfo.getString("userId"));
                if (StringUtils.isBlank(drugUseapply1.getProcessDefinitionId()) || "员工提交".equals(drugUseapply1.getProcessDefinitionId())) {
                    newApproval.setTaskName("仓储部经理审批");//任务名称
                    drugUseapply.setProcessDefinitionId("仓储部经理审批"); // 员工第一次提交仓储部经理审批
                } else if ("仓储部经理审批".equals(drugUseapply1.getProcessDefinitionId())) { // 判断是否仓储部经理已审批(第二次审批)
                    newApproval.setTaskName("库领导审批");//任务名称
                    drugUseapply.setProcessDefinitionId("审批流程结束"); // 仓储部经理审批提交库领导审批审批流程结束
                    newApproval.setResult(resultS);//审批结果
                    newApproval.setOperator(jsonUserInfo.getString("userId"));
                }
                drugUseapplyMapper.updateByPrimaryKeySelective(drugUseapply);
                approvalService.add(newApproval);
            } else {
                //位置环节
                return;
            }
        }
    }

}
