package com.chinaitop.depot.fumigation.controller;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.fumigation.model.*;
import com.chinaitop.depot.fumigation.service.*;
import com.chinaitop.depot.utils.HttpUtil;
import com.chinaitop.depot.utils.JsonToObjectUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author lvzhikai
 * @description: 熏蒸作业善后
 * @create 2019-1-21 10:57
 */
@RestController
@RequestMapping(value = "/storage/fumigationAfter")
@Api(value = "FumigationAfterController", description = "熏蒸作业善后类")
@Slf4j
@SuppressWarnings("all")
public class FumigationAlterController {

    @Resource
    FumigationAfterService fumigationAfterService;

    @Resource
    private FumigationPlanService fumigationPlanService;

    @Resource
    private FumigationProcessService fumigationProcessService;

    @Resource
    private PesticidePlanService pesticidePlanService;

    @Resource
    private FumigationForRecordService fumigationForRecordService;

    // 获取ip地址
    @Value("${reportUrl}")
    private String reportPath;

    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationAfterList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸作业善后列表", notes = "熏蒸作业善后列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getFumigationAfterList(Integer pageNum, Integer pageSize, Integer houseId, String createTime, Integer orgId) {
        Map<String,Object> map = new HashMap<>();
        List<Map<String,Object>> list = null;

        if (ParameterUtil.isnotnull(orgId))//粮库查询
            map.put("orgId",orgId);

        if (ParameterUtil.isnotnull(houseId))//粮库查询
            map.put("houseId",houseId);

        if (ParameterUtil.isnotnull(createTime)) {//归档用
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            map.put("createTime", date);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        list = fumigationAfterService.getFumigationAfterList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        return pageInfo;
    }

    /**
     * 保存熏蒸善后信息
     * @param fumigation
     * @return
     */
    @RequestMapping(value="/saveFumigationAfterDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸善后信息", notes = "保存熏蒸善后信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fumigationAfter", value = "熏蒸善后数据", paramType = "form")
    })
    public Map<String, Object> saveFumigationAfterDate(String fumigationAfter) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
			modelMap = fumigationAfterService.saveOrUpdate(fumigationAfter);
		} catch (Exception e) {
			modelMap.put("status", "error");
			log.error(e.getMessage(), e);
		}
        return modelMap;
    }

    /**
     * 根据id查询熏蒸过程
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getAfterDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id查询熏蒸过程数据", notes = "根据id查询熏蒸过程数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "afterId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getAfterDeatil(String afterId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (afterId != null) {
            TFumigationAfter tFumigationAfter = fumigationAfterService.findById(afterId);
            modelMap.put("afterEdit",tFumigationAfter);//熏蒸善后数据

            TFumigationProcessExample example = new TFumigationProcessExample();
            TFumigationProcessExample.Criteria criteria = example.createCriteria();
            criteria.andRecordIdEqualTo(tFumigationAfter.getRecordId());
            criteria.andDeleteStateEqualTo("1");
            List<TFumigationProcess> tFumigationProcess = fumigationProcessService.getDataByFumId(example);
            if(!CollectionUtils.isEmpty(tFumigationProcess)){
                modelMap.put("processEdit",tFumigationProcess.get(0));//熏蒸作业过程数据
            }

            try {
                TFumigationForrecord fumigationForrecord = fumigationForRecordService.getById(tFumigationAfter.getRecordId());
                modelMap.put("fumigationEdit",fumigationForrecord);//熏蒸方案数据
            } catch (Exception e) {
                log.error(e.getMessage(), e);
            }
        }

        return modelMap;
    }

    /**
     * 删除熏蒸善后信息
     * @param fumigationId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeAfterPlan", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除熏蒸善后信息", notes = "删除熏蒸善后信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "afterId", value = "主键id", paramType = "form"),
            @ApiImplicitParam(name = "recordId", value = "熏蒸备案表ID", paramType = "form")
    })
    public Map<String, Object> removeAfterPlan(String afterId,String recordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        if (afterId != null) {
            TFumigationAfterExample example = new TFumigationAfterExample();
            TFumigationAfterExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(afterId);

            TFumigationAfter tFumigationAfter = new TFumigationAfter();
            tFumigationAfter.setDeleteState("0");
            fumigationAfterService.updateByExample(tFumigationAfter, example);

            //修改熏蒸状态
            TFumigationForrecordExample forrecordExample = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria exampleCriteria = forrecordExample.createCriteria();
            exampleCriteria.andIdEqualTo(recordId);
            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setState(10);
            fumigationForRecordService.updateByExample(tFumigationForrecord, forrecordExample);
            modelMap.put("status", "success");
        }
        return modelMap;
    }

    /**
     * 查询作业列表数据
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getHomeWorkQueryList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询作业列表数据", notes = "查询作业列表数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getHomeWorkQueryList(Integer pageNum, Integer pageSize, Integer houseId, String orgId) {
        Map<String,Object> map = new HashMap<>();
        List<Map<String,Object>> list = null;
        map.put("houseId",houseId);
        map.put("orgId",orgId);

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        list = fumigationAfterService.selectHomeWorkQueryList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        return pageInfo;
    }
}
