package com.chinaitop.depot.fumigation.controller;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.fumigation.model.TFumigationForrecord;
import com.chinaitop.depot.fumigation.model.TFumigationForrecordExample;
import com.chinaitop.depot.fumigation.model.TFumigationPersonnel;
import com.chinaitop.depot.fumigation.model.TFumigationPersonnelExample;
import com.chinaitop.depot.fumigation.model.TFumigationPesticide;
import com.chinaitop.depot.fumigation.model.TFumigationPesticideExample;
import com.chinaitop.depot.fumigation.model.TFumigationPlan;
import com.chinaitop.depot.fumigation.model.TFumigationPlanExample;
import com.chinaitop.depot.fumigation.service.FumigationForRecordService;
import com.chinaitop.depot.fumigation.service.FumigationPlanService;
import com.chinaitop.depot.fumigation.service.PesticidePlanService;
import com.chinaitop.depot.fumigation.service.SystemOutsideDataService;
import com.chinaitop.depot.utils.HttpUtil;
import com.chinaitop.depot.utils.JsonToObjectUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

/**
 * @author lvzhikai
 * @description: 熏蒸作业记录
 * @create 2019-1-14 10:57
 */
@RestController
@RequestMapping(value = "/storage/fumigationFroRecord")
@Api(value = "FumigationFroRecordController", description = "熏蒸备注类")
@Slf4j
@SuppressWarnings("all")
public class FumigationForRecordController {

    @Resource
    private FumigationForRecordService fumigationFroRecordService;

    @Resource
    private FumigationPlanService fumigationPlanService;

    @Resource
    private PesticidePlanService pesticidePlanService;

    @Resource
    private SystemOutsideDataService systemOutsideDataService;

    // 获取ip地址
    @Value("${reportUrl}")
    private String reportPath;
    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationForRecordList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸备案列表", notes = "熏蒸备案列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "申请开始时间", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "申请结束时间", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "xzzydh", value = "熏蒸作业单号", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<TFumigationForrecord> getFumigationForRecordList(Integer pageNum, Integer pageSize, String searchStartDate, String searchEndDate, Integer houseId, Integer orgId, String xzzydh) throws Exception {

        List<TFumigationForrecord> list = null;

        TFumigationForrecordExample example = new TFumigationForrecordExample();
        example.setOrderByClause(" create_time desc");
        TFumigationForrecordExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        criteria.andDeleteStateEqualTo("1");

        if (ParameterUtil.isnotnull(searchStartDate)) {
            searchStartDate = searchStartDate+" 00:00:00";
            criteria.andCreateTimeGreaterThanOrEqualTo(ParameterUtil.string2datetime(searchStartDate));
        }

        if (ParameterUtil.isnotnull(searchEndDate)) {
            searchEndDate = searchEndDate+" 23:59:59";
            criteria.andCreateTimeLessThanOrEqualTo(ParameterUtil.string2datetime(searchEndDate));
        }

        if (ParameterUtil.isnotnull(xzzydh)) {
        	criteria.andXzzydhEqualTo(xzzydh);
        }

        if (null != houseId) {
        	criteria.andHouseIdEqualTo(houseId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        
       
        list = fumigationFroRecordService.getList(example);
        PageInfo<TFumigationForrecord> pageInfo = new PageInfo<TFumigationForrecord>(list);

        return pageInfo;
    }

    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationPlanList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸列表", notes = "熏蒸信息列表(新增作业过程、作业过程时用)，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query"),
            @ApiImplicitParam(name = "queryType", value = "查询状态", paramType = "query")
    })
    public PageInfo<TFumigationForrecord> getFumigationPlanList(Integer pageNum, Integer pageSize, Integer houseId, String createTime, Integer orgId, String queryType) {
        TFumigationForrecordExample example = new TFumigationForrecordExample();
        example.setOrderByClause(" create_time desc");
        TFumigationForrecordExample.Criteria criteria = example.createCriteria();

        Map<String,Object> map = new HashMap<>();

        if (ParameterUtil.isnotnull(houseId)) {//仓房查询
            criteria.andHouseIdEqualTo(houseId);
        }

        if (ParameterUtil.isnotnull(createTime)) {//归档用
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            criteria.andCreateTimeLessThanOrEqualTo(date);
        }

        if (ParameterUtil.isnotnull(orgId)) {//粮库查询
            criteria.andOrgIdEqualTo(orgId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        //施药数据。过程数据。善后数据。备案数据
        if(ParameterUtil.isequal(queryType,"XZ") || ParameterUtil.isequal(queryType,"GC")){//新增、过程
            criteria.andStateEqualTo(8);
        }else if(ParameterUtil.isequal(queryType,"SH")){//善后
            criteria.andStateEqualTo(9);
        }else if(ParameterUtil.isequal(queryType,"BA")){//备案
            criteria.andStateEqualTo(5);
        }

        criteria.andDeleteStateEqualTo("1");

        List<TFumigationForrecord> list = fumigationFroRecordService.getList(example);
        PageInfo<TFumigationForrecord> pageInfo = new PageInfo<TFumigationForrecord>(list);
        return pageInfo;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFroRecordDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id集合查询熏蒸备案数据", notes = "根据熏蒸备案id集合查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getFroRecordDeatil(String planIds) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (planIds != null) {
            String storehouseNames = "";
            Map<String, Object> map = new HashMap<String, Object>();
            map.put("planIds",planIds.split(","));
            List<Map<String, Object>> forRecordList = fumigationFroRecordService.getFumigationDateByIds(map);
            for (Map<String, Object> forRecord:forRecordList) {
                storehouseNames += forRecord.get("storehouse_name") + ",";
            }
            modelMap.put("fumigationEdit",ParameterUtil.slashCapitals(forRecordList));//熏蒸数据
            modelMap.put("storehouseNames",storehouseNames.substring(0,storehouseNames.length()-1));//仓房名称集合--熏蒸作业地点
        }

        return modelMap;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFroRecordById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸备案数据", notes = "根据熏蒸备案id查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecordId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getFroRecordById(String forRecordId){
        Map<String, Object> modelMap = new HashMap<String, Object>();

        TFumigationForrecord tFumigationForrecord = null;

        try {
            if (forRecordId != null) {
                //获取备案主表数据
                tFumigationForrecord = fumigationFroRecordService.getById(forRecordId);
                modelMap.put("forRecordData",tFumigationForrecord);//熏蒸备案主表数据

                //获取施药人员数据
                TFumigationPersonnelExample tFumigationPersonnelExample = new TFumigationPersonnelExample();
                TFumigationPersonnelExample.Criteria criteria = tFumigationPersonnelExample.createCriteria();
                criteria.andForrecordIdEqualTo(forRecordId);
                List<TFumigationPersonnel> personnelList= fumigationFroRecordService.getPersonnelData(tFumigationPersonnelExample);
                modelMap.put("personnelList",personnelList);//熏蒸施药人员数据
            }

        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

        return modelMap;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸备案数据", notes = "根据熏蒸备案id查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecordId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getInfo(String forRecordId){
        Map<String, Object> modelMap = new HashMap<String, Object>();

        try {
            TFumigationForrecord tFumigationForrecord = fumigationFroRecordService.getById(forRecordId);
            if (forRecordId != null) {
                modelMap.put("record",tFumigationForrecord);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

        return modelMap;
    }

    /**
     * 保存熏蒸备案信息
     * @param fumigation
     * @return
     */
    @RequestMapping(value="/saveFumigationForRecordDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸备案信息", notes = "保存熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "备案备案数据", paramType = "form"),
            @ApiImplicitParam(name = "addedDetail", value = "备案熏蒸人数集合", paramType = "form"),
            @ApiImplicitParam(name = "fumigation", value = "熏蒸数据集合", paramType = "form"),
            @ApiImplicitParam(name = "stateType", value = "保存状态，是提交还是保存", paramType = "form")

    })
    public Map<String, Object> saveFumigationForRecordDate(String forRecord, String addedDetail,String fumigation,String stateType) throws Exception {
        if(ParameterUtil.isequal(stateType,"getSubmit")){
            stateType = "7";
        }else{
            stateType = "6";
        }

        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        String uuid = ParameterUtil.getCode();
        TFumigationForrecord tFumigationForrecord = (TFumigationForrecord) JsonToObjectUtils.jsonToObject(forRecord,"com.chinaitop.depot.fumigation.model.TFumigationForrecord");
        if (tFumigationForrecord.getId() == null) {
            //新增熏蒸备案数据
            tFumigationForrecord.setDeleteState("1");//默认设置删除标志
            tFumigationForrecord.setCreateTime(new Date());//创建时间
            tFumigationForrecord.setId(uuid);
            fumigationFroRecordService.add(tFumigationForrecord);
        } else {
            uuid = tFumigationForrecord.getId();
            tFumigationForrecord.setUpdatetime(new Date());//修改时间
            fumigationFroRecordService.update(tFumigationForrecord);
        }

        //熏蒸人员字段
        String[] personnelDates = addedDetail.split("},");
        for (String personnel:personnelDates) {
            TFumigationPersonnel tFumigationPersonnel = (TFumigationPersonnel) JsonToObjectUtils.jsonToObject(personnel + "}", "com.chinaitop.depot.fumigation.model.TFumigationPersonnel");
            if (tFumigationPersonnel.getId() == null) {
                tFumigationPersonnel.setDeleteState("1");//默认设置删除标志
                tFumigationPersonnel.setCreateTime(new Date());//创建时间
                tFumigationPersonnel.setId(ParameterUtil.getCode());
                tFumigationPersonnel.setForrecordId(uuid);
                tFumigationPersonnel.setOrgId(tFumigationForrecord.getOrgId());
                fumigationFroRecordService.addPersonnel(tFumigationPersonnel);
            } else {
                tFumigationPersonnel.setUpdatetime(new Date());//修改时间
                fumigationFroRecordService.updatePersonnel(tFumigationPersonnel);
            }
        }

        //熏蒸信息字段
        String[] fumigationDates = fumigation.split("},");
        Integer c=1;
        for (String fumigations:fumigationDates) {
            JSONObject fumMap = null;
            if(c != fumigationDates.length){
                fumMap = JSON.parseObject(fumigations+"}");
            }else{
                fumMap = JSON.parseObject(fumigations);
            }
            c++;
            //修改熏蒸状态
            TFumigationPlanExample example = new TFumigationPlanExample();
            TFumigationPlanExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(fumMap.get("planid").toString());

            TFumigationPlan tFumigationPlan = new TFumigationPlan();
            tFumigationPlan.setState(Integer.parseInt(stateType));
            tFumigationPlan.setGrainMoisture(fumMap.get("grainMoisture").toString());
            tFumigationPlan.setStowWay(fumMap.get("stowWay").toString());
            tFumigationPlan.setForRecordId(uuid);
            fumigationPlanService.updateByExample(tFumigationPlan, example);

            //修改熏蒸施药状态
            TFumigationPesticideExample pesticideExample = new TFumigationPesticideExample();
            TFumigationPesticideExample.Criteria pesticideCriteria = pesticideExample.createCriteria();
            pesticideCriteria.andIdEqualTo(fumMap.get("pesticideid").toString());

            TFumigationPesticide tFumigationPesticide = new TFumigationPesticide();
            tFumigationPesticide.setReagentType("3024");
            tFumigationPesticide.setValidity(fumMap.get("validity").toString());
            tFumigationPesticide.setGetNumber(fumMap.get("getNumber").toString());
            tFumigationPesticide.setGetPerson(fumMap.get("getPerson").toString());
            tFumigationPesticide.setGetTime(ParameterUtil.string2datetime(fumMap.get("getTime").toString()));
            pesticidePlanService.updateByExample(tFumigationPesticide, pesticideExample);
        }

        if(ParameterUtil.isequal(stateType,"7")){
            try {
                //如果是提交的话则除了保存还要把数据提交到市级来进行审批
                Map<String, Object> dataMap = fumigationFroRecordService.getFroRecordByIds(uuid);
                String url = reportPath+"/api/cbl-app/cbl/fumigation/insertFumigation";//市级接口
                String strResult = HttpUtil.doPost(url,JSON.toJSONString(dataMap));
            }catch (IOException e) {
                e.printStackTrace();
            } finally {
                modelMap.put("status", "success");
            }
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 删除熏蒸申请信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeDetail", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除熏蒸备案信息", notes = "删除熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "熏蒸主键集合", paramType = "form"),
            @ApiImplicitParam(name = "forrecordId", value = "主键id", paramType = "form")
    })
    public Map<String, Object> removeDetail(String planIds, String forrecordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();

        //修改熏蒸状态
        TFumigationForrecordExample tFumigationForrecordExample = new TFumigationForrecordExample();
        TFumigationForrecordExample.Criteria criteria = tFumigationForrecordExample.createCriteria();
        criteria.andIdEqualTo(forrecordId);

        TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
        tFumigationForrecord.setDeleteState("0");
        fumigationFroRecordService.updateByExample(tFumigationForrecord, tFumigationForrecordExample);
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 提交熏蒸申请信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getSubmit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="提交熏蒸备案信息", notes = "提交熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "熏蒸主键集合", paramType = "form"),
            @ApiImplicitParam(name = "forrecordId", value = "主键id", paramType = "form")
    })
    public Map<String, Object> getSubmit(String planIds, String forrecordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        if (planIds != null) {
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria criteria = example.createCriteria();
                criteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(7);
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }
        try {
            //如果是提交的话则除了保存还要把数据提交到市级来进行审批
            Map<String, Object> dataMap = fumigationFroRecordService.getFroRecordByIds(forrecordId);
            String url = reportPath+"/api/cbl-app/cbl/fumigation/insertFumigation";//市级接口
            String strResult = HttpUtil.doPost(url,JSON.toJSONString(dataMap));
        }catch (IOException e) {
            e.printStackTrace();
        } finally {
            modelMap.put("status", "success");
        }
        return modelMap;
    }

    /**
     * 提交熏蒸审批信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getForRecordApproval", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="提交熏蒸备案信息", notes = "提交熏蒸备案信息-市级用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "主键id", paramType = "form")
    })
    public void getForRecordApproval(String forRecord) throws Exception {
        //市级传输过来的审批过后的备案数据
        JSONObject forRecordData = JSONObject.parseObject(forRecord);
        String forrecordId = forRecordData.get("forrecordId").toString();
        Map<String, Object> modelMap = new HashMap<>();
        if (forrecordId != null) {
            //修改熏蒸备案信息
            TFumigationForrecordExample tFumigationForrecordExample = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria criteria = tFumigationForrecordExample.createCriteria();
            criteria.andIdEqualTo(forrecordId);

            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setOrgansOpinion(forRecordData.get("organsOpinion").toString());
            tFumigationForrecord.setOutPerson(forRecordData.get("outPerson").toString());
            tFumigationForrecord.setOutForrecordTime(ParameterUtil.string2datetime(forRecordData.get("outForrecordTime").toString()));
            fumigationFroRecordService.updateByExample(tFumigationForrecord, tFumigationForrecordExample);

            //获取备案数据
            List<Map<String, Object>> forRecords = fumigationFroRecordService.getFroRecordById(forrecordId);
            String planIds = "";
            for (Map<String, Object> maps:forRecords) {
                planIds+=maps.get("planids")+",";
            }
            planIds = planIds.substring(0,planIds.length()-1);

            //下边获取熏蒸数据
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria planCriteria = example.createCriteria();
                planCriteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(8);
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }
    }

    @RequestMapping(value="/insertRecord", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸信息及备案信息", notes = "保存熏蒸信息及备案信息-市级用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "熏蒸备案基础信息和备案信息", paramType = "form")
    })
    public Map<String, Object> insertRecord(String forRecord) throws Exception {
    	log.info("接收市平台下发的熏蒸备案数据："+forRecord);
        Map<String, Object> modelMap = new HashMap<>();
        try {
			modelMap = fumigationFroRecordService.saveXzbaData(forRecord);
		} catch (Exception e) {
			modelMap.put("status", "500");
	        modelMap.put("msg","接收失败,请检查代码异常");
	        systemOutsideDataService.addlogger("xzba", forRecord, modelMap.toString());
	        log.error(e.getMessage(), e);
		}
        return modelMap;
    }
}