package com.chinaitop.depot.fumigation.controller;

import com.chinaitop.depot.fumigation.model.*;
import com.chinaitop.depot.fumigation.service.FumigationForRecordService;
import com.chinaitop.depot.fumigation.service.FumigationPlanService;
import com.chinaitop.depot.fumigation.service.FumigationProcessService;
import com.chinaitop.depot.fumigation.service.PesticidePlanService;
import com.chinaitop.depot.utils.JsonToObjectUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author lvzhikai
 * @description: 熏蒸作业记录
 * @create 2019-1-14 10:57
 */
@RestController
@RequestMapping(value = "/storage/fumigationProcess")
@Api(value = "FumigationProcessController", description = "熏蒸作业控制类")
@Slf4j
@SuppressWarnings("all")
public class FumigationProcessController {

    @Resource
    private FumigationProcessService fumigationProcessService;

    @Resource
    private FumigationPlanService fumigationPlanService;

    @Resource
    private PesticidePlanService pesticidePlanService;

    @Resource
    private FumigationForRecordService fumigationForRecordService;

    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationProcessList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸作业列表", notes = "熏蒸作业过程列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getFumigationProcessList(Integer pageNum, Integer pageSize, Integer houseId, String createTime, Integer orgId) {
        Map<String,Object> map = new HashMap<>();
        List<Map<String,Object>> list = null;

        if (ParameterUtil.isnotnull(orgId))//粮库查询
            map.put("orgId",orgId);

        if (ParameterUtil.isnotnull(houseId))//粮库查询
            map.put("houseId",houseId);

        if (ParameterUtil.isnotnull(createTime)) {//归档用
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            map.put("createTime", date);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }


        list = fumigationProcessService.getFumigationProcessList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        return pageInfo;
    }

    /**
     * 保存熏蒸作业信息
     * @param fumigation
     * @return
     */
    @RequestMapping(value="/saveFumigationProcessDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸作业信息", notes = "保存熏蒸作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fumigationProcess", value = "熏蒸作业数据", paramType = "form")
    })
    public Map<String, Object> saveFumigationProcessDate(String fumigationProcess) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        TFumigationProcess tFumigationProcess = (TFumigationProcess) JsonToObjectUtils.jsonToObject(fumigationProcess,"com.chinaitop.depot.fumigation.model.TFumigationProcess");
        tFumigationProcess.setDeleteState("1");//默认设置删除标志
        if (tFumigationProcess.getId() == null) {
            tFumigationProcess.setId(ParameterUtil.getCode());
            tFumigationProcess.setCreateTime(new Date());//创建时间
            tFumigationProcess.setUpdateTime(tFumigationProcess.getCreateTime());//修改时间
            fumigationProcessService.add(tFumigationProcess);

            //修改熏蒸状态
            TFumigationForrecordExample example = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(tFumigationProcess.getRecordId());

            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setState(9);
            tFumigationForrecord.setFzsycs(tFumigationProcess.getAuxiliaryMeasures());//辅助施药措施
            tFumigationForrecord.setDjcxz(tFumigationProcess.getDjcxz());//第几次熏蒸
            tFumigationForrecord.setOperationSupervisor(tFumigationProcess.getOperationSupervisor());//熏蒸作业负责人
            tFumigationForrecord.setXzczry(tFumigationProcess.getXzczry());//熏蒸作业人员
            fumigationForRecordService.updateByExample(tFumigationForrecord, example);

        } else {
            tFumigationProcess.setUpdateTime(new Date());//修改时间
            fumigationProcessService.update(tFumigationProcess);

            //修改熏蒸状态
            TFumigationForrecordExample example = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(tFumigationProcess.getRecordId());

            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setFzsycs(tFumigationProcess.getAuxiliaryMeasures());//辅助施药措施
            tFumigationForrecord.setDjcxz(tFumigationProcess.getDjcxz());//第几次熏蒸
            tFumigationForrecord.setOperationSupervisor(tFumigationProcess.getOperationSupervisor());//熏蒸作业负责人
            tFumigationForrecord.setXzczry(tFumigationProcess.getXzczry());//熏蒸作业人员
            fumigationForRecordService.updateByExample(tFumigationForrecord, example);
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 根据id查询熏蒸作业
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getProcessDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id查询熏蒸作业数据", notes = "根据id查询熏蒸作业数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "processId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getProcessDeatil(String processId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        try {
            if (processId != null) {
                TFumigationProcess tFumigationProcess = fumigationProcessService.findById(processId);
                modelMap.put("processEdit",tFumigationProcess);//熏蒸作业过程数据
                TFumigationForrecord fumigationForrecord = fumigationForRecordService.getById(tFumigationProcess.getRecordId());
                modelMap.put("fumigationEdit",fumigationForrecord);//熏蒸方案数据

            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

        return modelMap;
    }

    /**
     * 删除熏蒸作业信息
     * @param fumigationId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeProcessPlan", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除熏蒸作业信息", notes = "删除熏蒸作业信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "processId", value = "主键id", paramType = "form"),
            @ApiImplicitParam(name = "recordId", value = "熏蒸备案表ID", paramType = "form")
    })
    public Map<String, Object> removeProcessPlan(String processId,String recordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        if (processId != null) {
            TFumigationProcessExample example = new TFumigationProcessExample();
            TFumigationProcessExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(processId);

            TFumigationProcess tFumigationProcess = new TFumigationProcess();
            tFumigationProcess.setDeleteState("0");
            fumigationProcessService.updateByExample(tFumigationProcess, example);

            //修改熏蒸状态
            /*TFumigationPlanExample fumExample = new TFumigationPlanExample();
            TFumigationPlanExample.Criteria fumCriteria = fumExample.createCriteria();
            fumCriteria.andIdEqualTo(fumigationId);*/
            TFumigationForrecordExample forrecordExample = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria exampleCriteria = forrecordExample.createCriteria();
            exampleCriteria.andIdEqualTo(recordId);
            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setState(8);
            fumigationForRecordService.updateByExample(tFumigationForrecord, forrecordExample);
            modelMap.put("status", "success");
        }
        return modelMap;
    }

    /**
     * 根据熏蒸计划id查询熏蒸作业
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFumIdByProcessDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸作业过程数据", notes = "根据熏蒸备案id查询熏蒸作业过程数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "recordId", value = "熏蒸备案计划id", paramType = "query")
    })
    public Map<String, Object> getFumIdByProcessDeatil(String recordId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        TFumigationProcessExample example = new TFumigationProcessExample();
        TFumigationProcessExample.Criteria criteria = example.createCriteria();
        criteria.andRecordIdEqualTo(recordId);
        criteria.andDeleteStateEqualTo("1");
        List<TFumigationProcess> tFumigationProcess = fumigationProcessService.getDataByFumId(example);
        modelMap.put("processEdit",tFumigationProcess);//熏蒸作业过程数据
        return modelMap;
    }
}
