package com.chinaitop.depot.fumigation.service.impl;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.fumigation.mapper.TFumigationForrecordMapper;
import com.chinaitop.depot.fumigation.mapper.TFumigationPersonnelMapper;
import com.chinaitop.depot.fumigation.mapper.TFumigationPesticideMapper;
import com.chinaitop.depot.fumigation.model.TFumigationForrecord;
import com.chinaitop.depot.fumigation.model.TFumigationForrecordExample;
import com.chinaitop.depot.fumigation.model.TFumigationPersonnel;
import com.chinaitop.depot.fumigation.model.TFumigationPersonnelExample;
import com.chinaitop.depot.fumigation.model.TFumigationPesticide;
import com.chinaitop.depot.fumigation.service.FumigationForRecordService;
import com.chinaitop.depot.fumigation.service.SystemOutsideDataService;
import com.chinaitop.depot.utils.HttpUtil;
import com.chinaitop.depot.utils.ParameterUtil;

/**
 * @author lvzhikai
 * @description: 熏蒸作业
 * @create 2019-1-15 11:00
 */
@Service
public class FumigationForRecordServiceImpl implements FumigationForRecordService {

    @Resource
    private TFumigationForrecordMapper tFumigationForrecordMapper;
    @Resource
    private TFumigationPersonnelMapper tFumigationPersonnelMapper;
    @Resource
    private TFumigationPesticideMapper tFumigationPesticideMapper;
    @Resource
    private SystemOutsideDataService systemOutsideDataService;

    @Override
    public List<Map<String,Object>> getFumigationFroRecordList(Map<String, Object> map) throws Exception {
        TFumigationForrecordExample example = new TFumigationForrecordExample();
        TFumigationForrecordExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(Integer.parseInt(map.get("orgId").toString()));
        criteria.andDeleteStateEqualTo("1");
        if(ParameterUtil.isnotnull(map.get("searchStartDate")) && ParameterUtil.isnotnull(map.get("searchEndDate"))){
            criteria.andCreateTimeBetween(ParameterUtil.string2datetime(map.get("searchStartDate").toString()),ParameterUtil.string2datetime(map.get("searchEndDate").toString()));
        }
        List<Map<String,Object>> tfList = new ArrayList<Map<String,Object>>();
        List<TFumigationForrecord> tFumigationForrecords = tFumigationForrecordMapper.selectByExample(example);
        for (TFumigationForrecord tf:tFumigationForrecords) {
            //根据熏蒸备案id获取熏蒸数据
            map.put("forRecordId",tf.getId());
            List<Map<String,Object>> planData = tFumigationForrecordMapper.getFumigationForrecordList(map);
            Map<String,Object> tfMap = ParameterUtil.convertBean(tf);
            if(planData.size() != 0){
                String planIds = "",houseId = "";//获取熏蒸计划表id集合和仓房名称集合
                for (Map<String,Object> plan:planData) {
                    planIds += plan.get("planids")+",";
                    houseId += plan.get("houseid")+",";
                }
                tfMap.put("planIds",planIds.substring(0,planIds.length()-1));
                tfMap.put("houseId",houseId.substring(0,houseId.length()-1));
                tfMap.put("state",planData.get(0).get("state"));
                tfMap.put("stateType",planData.get(0).get("statetype"));

            }
            tfList.add(tfMap);
        }
        return tfList;
    }

    @Override
    public List<Map<String, Object>> getFroRecordById(String forRecordId) {
        return tFumigationForrecordMapper.getFroRecordById(forRecordId);
    }

    @Override
    public Map<String, Object> getFroRecordByIds(String forRecordId) {
        Map<String, Object> FroRecordMap = ParameterUtil.slashCapitals(tFumigationForrecordMapper.getFroRecordByIds(forRecordId));
        List<Map<String, Object>> personnelMap = ParameterUtil.slashCapitals(tFumigationForrecordMapper.getpersonnelByIds(forRecordId));
        List<Map<String, Object>> planMap = ParameterUtil.slashCapitals(tFumigationForrecordMapper.getplanByIds(forRecordId));
        List<Map<String, Object>> pesticideMap = ParameterUtil.slashCapitals(tFumigationForrecordMapper.getpesticideByIds(forRecordId));
        FroRecordMap.put("fumigationPersonnels",personnelMap);

        String url = "http://localhost:9026/agile/kcsw/queryLKNewData?orgId="+FroRecordMap.get("orgId");;//粮油性质
        String strResult = HttpUtil.doGet(url);
        JSONArray json = JSONArray.parseArray(strResult);

        for (Map<String, Object> plans:planMap) {
            for (Map<String, Object> pesticide:pesticideMap) {
                if(ParameterUtil.isequal(plans.get("id"),pesticide.get("fumigationId"))){
                    plans.put("fumigationPesticide",pesticide);
                }
            }
            if (json.size() > 0) {//循环添加粮油性质
                for (int i = 0; i < json.size(); i++) {
                    JSONObject job = json.getJSONObject(i);
                    if(ParameterUtil.isequal(plans.get("houseId"),job.get("ch"))){
                        String lyxz = tFumigationForrecordMapper.getLYXZ(job.get("hwxz").toString());
                        plans.put("grainNature",lyxz);
                        String dj = tFumigationForrecordMapper.getLYXZ(job.get("dj").toString());
                        plans.put("grainGrade",dj);
                        plans.remove("rn");
                    }
                }
            }
        }

        FroRecordMap.put("fumigationPlans",planMap);
        return FroRecordMap;
    }

    @Override
    public List<Map<String, Object>> getFumigationDateByIds(Map<String, Object> map) {
        return tFumigationForrecordMapper.getFumigationDateByIds(map);
    }

    @Override
    public void add(TFumigationForrecord tFumigationForrecord) {
        tFumigationForrecordMapper.insert(tFumigationForrecord);
    }

    @Override
    public void addPersonnel(TFumigationPersonnel tFumigationPersonnel) {
        tFumigationPersonnelMapper.insert(tFumigationPersonnel);
    }

    @Override
    public void update(TFumigationForrecord tFumigationForrecord) {
        tFumigationForrecordMapper.updateByPrimaryKey(tFumigationForrecord);
    }

    @Override
    public void updatePersonnel(TFumigationPersonnel tFumigationPersonnel) {
        tFumigationPersonnelMapper.updateByPrimaryKey(tFumigationPersonnel);
    }

    @Override
    public List<TFumigationPersonnel> getPersonnelData(TFumigationPersonnelExample tFumigationPersonnelExample) {
        return tFumigationPersonnelMapper.selectByExample(tFumigationPersonnelExample);
    }

    @Override
    public void updateByExample(TFumigationForrecord tFumigationForrecord,TFumigationForrecordExample tFumigationForrecordExample) {
        tFumigationForrecordMapper.updateByExampleSelective(tFumigationForrecord,tFumigationForrecordExample);
    }

    @Override
    public TFumigationForrecord getById(String recordId) throws Exception {
        return tFumigationForrecordMapper.selectByPrimaryKey(recordId);
    }

    @Override
    public Map<String, Object> findYjxxById(String recordId) {
        return tFumigationForrecordMapper.findYjxxById(recordId);
    }

    @Override
    public List<TFumigationForrecord> getList(TFumigationForrecordExample example) {
        return tFumigationForrecordMapper.selectByExample(example);
    }

    @Override
    public Map<String, Integer> getByCfdm(String cfdm) {
        return tFumigationForrecordMapper.selectByCfdm(cfdm);
    }

	@Override
	public Map<String, Object> saveXzbaData(String forRecord) throws Exception {
		Map<String, Object> modelMap = new HashMap<>();
        if(StringUtils.isEmpty(forRecord)){
        	modelMap.put("status", "500");
            modelMap.put("msg","所传信息为空，请检查");
            systemOutsideDataService.addlogger("xzba", forRecord, modelMap.toString());
            return modelMap;
        }
        JSONObject recordInfo = JSONObject.parseObject(forRecord);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String xzzydh = null;
        String operationSupervisor = null;
        String contactPhone = null;
        String xzzydd = null;
        String lyccdwfzr = null;
        String fumigationStart = null;
        String fumigationEnd = null;
        String creater = null;
        String createTime = null;
        String updateTime = null;
        String enterpriseOpinion = null;
        String organsOpinion = null;
        String spsj = null;
        String spr = null;
        String fhry = null;
        String gasStart = null;
        String gasEnd = null;
        String residueStart = null;
        String residueEnd = null;
        if (StringUtils.isNotBlank(recordInfo.getString("id"))) {
            //熏蒸作业单号
            xzzydh = recordInfo.getString("id");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("operationSupervisor"))) {
            //熏蒸作业制定人
            operationSupervisor = recordInfo.getString("operationSupervisor");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("contactPhone"))){
            //联系电话
            contactPhone = recordInfo.getString("contactPhone");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("operationLocaltion"))) {
            //熏蒸作业地点
            xzzydd = recordInfo.getString("operationLocaltion");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("orgPerson"))) {
            //熏蒸方案起草人
            lyccdwfzr = recordInfo.getString("orgPerson");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("fumigationStart"))) {
            //熏蒸开始时间
            fumigationStart=(String)recordInfo.getString("fumigationStart");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("fumigationEnd"))) {
            //熏蒸结束时间
            fumigationEnd = recordInfo.getString("fumigationEnd");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("creater"))) {
            //申请人
            creater = recordInfo.getString("creater");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("createTime"))) {
            //申请时间
            createTime = recordInfo.getString("createTime");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("updateTime"))) {
            //修改时间
            updateTime = recordInfo.getString("updateTime");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("qyspyj"))) {
           //申请企业意见
           enterpriseOpinion = recordInfo.getString("qyspyj");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("qlbspyj"))) {
            //备案机关意见
            organsOpinion = recordInfo.getString("qlbspyj");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("qlbspsj"))) {
           //审批时间
           spsj = recordInfo.getString("qlbspsj");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("qyfzr"))) {
            //审批人
            spr = recordInfo.getString("qyspr");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("fhry"))) {
            //防护人员
            fhry = recordInfo.getString("fhry");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("gasStart"))) {
        	gasStart = recordInfo.getString("gasStart");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("gasEnd"))) {
        	gasEnd = recordInfo.getString("gasEnd");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("residueStart"))) {
        	residueStart = recordInfo.getString("residueStart");
        }
        if (StringUtils.isNotBlank(recordInfo.getString("residueEnd"))) {
        	residueEnd = recordInfo.getString("residueEnd");
        }
        if (StringUtils.isBlank(recordInfo.getString("detailVOS"))){
        	modelMap.put("status", "500");
        	modelMap.put("msg","缺少库房信息");
            systemOutsideDataService.addlogger("xzba", forRecord, modelMap.toString());
            return modelMap;
        }
        //要熏蒸的仓房集合
        List<Map<String,Object>> details = (List<Map<String,Object>>)recordInfo.get("detailVOS");
        for (Map<String, Object> detail : details) {
            //熏蒸备案表
            TFumigationForrecord fumigationForrecord = new TFumigationForrecord();
            String uuid = ParameterUtil.getCode();
            fumigationForrecord.setFhry(fhry);//防护人员
            fumigationForrecord.setId(uuid);
            fumigationForrecord.setXzzydh(xzzydh);//熏蒸作业单号
            fumigationForrecord.setXzfazd(operationSupervisor);//熏蒸方案制定人
            fumigationForrecord.setXzfaqcr(lyccdwfzr);//熏蒸方案起草人
            fumigationForrecord.setContactPhone(contactPhone);//联系电话
            fumigationForrecord.setXzzydd(xzzydd); //熏蒸作业地点
            if(StringUtils.isNotBlank(fumigationStart)){
                fumigationForrecord.setFumigationStart(format.parse(fumigationStart));//熏蒸作业施药开始时间
            }
            if(StringUtils.isNotBlank(fumigationEnd)){
                fumigationForrecord.setFumigationEnd(format.parse(fumigationEnd));//熏蒸作业施药结束时间
            }
            if (StringUtils.isNotBlank(gasStart)) {
            	fumigationForrecord.setGasStart(ParameterUtil.string2datetime(gasStart));//预计散气开始时间
            }
            if (StringUtils.isNotBlank(gasEnd)) {
            	fumigationForrecord.setGasEnd(ParameterUtil.string2datetime(gasEnd));//预计散气结束时间
            }
            if (StringUtils.isNotBlank(residueStart)) {
            	fumigationForrecord.setResidueStart(ParameterUtil.string2datetime(residueStart));//预计残渣收集作业开始时间
            }
            if (StringUtils.isNotBlank(residueEnd)) {
            	fumigationForrecord.setResidueEnd(ParameterUtil.string2datetime(residueStart));//预计残收集作业结束时间
            }
            fumigationForrecord.setSqr(creater);//申请人
            if(StringUtils.isNotBlank(createTime)){
                fumigationForrecord.setCreateTime(format.parse(createTime));//申请时间
            }
            if(StringUtils.isNotBlank(updateTime)){
                fumigationForrecord.setUpdatetime(format.parse(updateTime));//修改时间
            }
            fumigationForrecord.setEnterpriseOpinion(enterpriseOpinion);//申请企业意见
            fumigationForrecord.setOrgansOpinion(organsOpinion);//备案机关意见
            if(spsj!=null){
                fumigationForrecord.setSpsj(format.parse(spsj));//审批时间
                fumigationForrecord.setOutForrecordTime(format.parse(spsj));//备案时间
            }
            fumigationForrecord.setSpr(spr);//审批人
            fumigationForrecord.setDeleteState("1");//写死为已备案
            fumigationForrecord.setOutPerson(spr);
            String cfdm = null;
            Integer orgId =null;
            Integer houseId =null;
            String cfmc = null;
            BigDecimal lssl = null;
            String lspz = null;
            String lyxz = null;
            String cgxzfs = null;
            String hlxzfs = null;
            Integer xzfs = null;
            String hlxzynhljsjh = null;
            String yjmc = null;
            String jx =null;
            BigDecimal nd =null;
            String syff = null;
            BigDecimal lqsl = null;
            BigDecimal lddwyyl = null;
            BigDecimal kjdwyyl = null;
            BigDecimal zyyl = null;
            String hcjcdh = null;
            BigDecimal lysf = null;
            String dzfs = null;
            String yjyxq = null;
            String lqr = null;
            String lqsj = null;
            String xzzhr = null;
            Integer xzrs = null;
            String xzczry = null;
            String processingInstructions = null;
            if(detail.get("cfbh") != null){
                cfdm = (String)detail.get("cfbh");
                Map<String,Integer> info = getByCfdm(cfdm);
                if(info!=null){
                    orgId = info.get("orgid");
                    houseId = info.get("houseid");
                }else{
                	modelMap.put("status", 500);
                	modelMap.put("msg","未获取到仓房对应org信息和house信息");
                    systemOutsideDataService.addlogger("xzba", forRecord, modelMap.toString());
                    return modelMap;
                }
            }
            if(detail.get("cfmc")!=null){
                //仓房名称
                cfmc = (String)detail.get("cfmc");
            }
            if(detail.get("kcsl")!=null){
                //库存数量
                lssl = new BigDecimal(ObjectUtils.toString(detail.get("kcsl")));
            }
            if(detail.get("lspzCode")!=null){
                //粮食品种
                lspz = ObjectUtils.toString(detail.get("lspzCode"));
            }
            if(detail.get("lsxzCode")!=null){
                //粮食性质
                lyxz = ObjectUtils.toString(detail.get("lsxzCode"));
            }
            if(detail.get("convFumigation")!=null){
                //常规熏蒸方式
                cgxzfs = (String)detail.get("convFumigation");
            }
            if(detail.get("recFumigation")!=null){
                //环流熏蒸方式
                hlxzfs = (String)detail.get("recFumigation");
            }
            if(detail.get("xzfs")!=null){
                //熏蒸方式
                xzfs = (Integer)detail.get("xzfs");
            }
            if(detail.get("recIcCombine")!=null){
                //环流熏蒸与内环流技术结合
                hlxzynhljsjh = (String)detail.get("recIcCombine");
            }
            if(detail.get("drugNameCode")!=null){
                //药剂名称
                yjmc = ObjectUtils.toString(detail.get("drugNameCode"));
            }
            if(detail.get("drugTypeCode")!=null){
                //剂型
                jx = ObjectUtils.toString(detail.get("drugTypeCode"));
            }
            if(detail.get("drugConcentration")!=null){
                //浓度
                nd = new BigDecimal(ObjectUtils.toString(detail.get("drugConcentration")));;
            }
            if(detail.get("applicationMethod")!=null){
                //施药方法
                syff = (String)detail.get("applicationMethod");
            }
            if(detail.get("getNumber")!=null){
                //领取数量
                lqsl = new BigDecimal(detail.get("getNumber").toString());
            }
            if(detail.get("grainDosage")!=null){
                //堆粮单位用药量
                lddwyyl = new BigDecimal(ObjectUtils.toString(detail.get("grainDosage")));
            }
            if(detail.get("spaceDosage")!=null){
                //空间单位用药量(g/m3)
                kjdwyyl = new BigDecimal(ObjectUtils.toString(detail.get("spaceDosage")));
            }
            if(detail.get("totalDosage")!=null){
                //总用药量(kg)
                zyyl = new BigDecimal(ObjectUtils.toString(detail.get("totalDosage")));
            }
            if(detail.get("pestNo")!=null){
                //害虫检测单号
                hcjcdh = (String)detail.get("pestNo");
            }
            if(detail.get("lysf")!=null){
                //粮油水分
                lysf =new BigDecimal(ObjectUtils.toString(detail.get("lysf")));
            }
            if(detail.get("dzfs")!=null){
                //堆装方式
                dzfs =(String)detail.get("dzfs");
            }
            if(detail.get("yjyxq")!=null){
                //药剂有效期
                yjyxq =(String)detail.get("yjyxq");
            }
            if(detail.get("lqr")!=null){
                //领取人
                lqr =(String)detail.get("lqr");
            }
            if(detail.get("lqsj")!=null){
                //领取时间
                lqsj =(String)detail.get("lqsj");
            }
            if(detail.get("xzzhr")!=null){
                //熏蒸指挥人
                xzzhr =(String)detail.get("xzzhr");
            }
            if(detail.get("xzrs")!=null){
                //熏蒸人数
                xzrs =(Integer)detail.get("xzrs");
            }
            if(detail.get("xzczry")!=null){
                //熏蒸操作人员
                xzczry =(String)detail.get("xzczry");
            }
            if(detail.get("processingInstructions")!=null){
                //包装物及药剂残渣处理说明
                processingInstructions =(String)detail.get("processingInstructions");
            }
            fumigationForrecord.setLysf(lysf);//粮油水分
            fumigationForrecord.setDzfs(dzfs);//堆装方式
            fumigationForrecord.setStowWay(dzfs);//堆装方式
            fumigationForrecord.setSyff(syff);//施药方式
            if(yjyxq!=null){
                //药剂有效期
                fumigationForrecord.setYjyxq(format.parse(yjyxq));
            }
            fumigationForrecord.setLqr(lqr);//领取人
            if(lqsj!=null){
                fumigationForrecord.setLqsj(format.parse(lqsj));//领取时间
            }
            fumigationForrecord.setXzzhr(xzzhr);//熏蒸指挥人
            fumigationForrecord.setXzrs(xzrs);//熏蒸人数
            fumigationForrecord.setXzczry(xzczry);//熏蒸操作人员
            fumigationForrecord.setProcessingInstructions(processingInstructions);//包装物及药剂残渣处理说明
            if(detail.get("pestVOS")!=null){
                if(detail.get("pestVOS")!=null){
                    List<Map<String,Object>> pest =  (List<Map<String,Object>>)detail.get("pestVOS");
                    if(!CollectionUtils.isEmpty(pest)){
                        String zyhc = "";
                        String ckmd = "";
                        for (Map<String, Object> stringObjectMap : pest) {
                            TFumigationPesticide pesticide = new TFumigationPesticide();
                            pesticide.setId(ParameterUtil.getCode());
                            pesticide.setRecordId(uuid);
                            pesticide.setUseDrugType(syff);
                            pesticide.setReagentType(jx);
                            pesticide.setCreateTime(new Date());
                            pesticide.setDrugPurity(nd.toString());
                            if(stringObjectMap.get("hczlCode") !=null){
                                zyhc +=ObjectUtils.toString(stringObjectMap.get("hczlCode"))+"#";//主要害虫
                                pesticide.setMajorInsectPests(Integer.valueOf(ObjectUtils.toString(stringObjectMap.get("hczlCode"))));//主要害虫
                            }
                            if(stringObjectMap.get("density") !=null){
                                ckmd += (String)stringObjectMap.get("density") + "|";//虫口密度
                                pesticide.setInsectDensity((String)stringObjectMap.get("density"));//虫口密度
                            }
                            if(yjmc!=null){
                                pesticide.setDrugName(Integer.valueOf(yjmc));//药剂名称
                            }
                            if(stringObjectMap.get("discoveryTime")!=null){
                                pesticide.setInsectProductTime(format.parse((String)stringObjectMap.get("discoveryTime")));//发现虫害日期
                            }
                            if(stringObjectMap.get("happenPosition")!=null){
                                pesticide.setOccurrencePlace((String)stringObjectMap.get("happenPosition"));//发生部位
                            }
                            if(stringObjectMap.get("pestResistance")!=null){
                                pesticide.setDrugResistance((String)stringObjectMap.get("pestResistance"));//害虫抗药性分析
                            }
                            if(stringObjectMap.get("sealType")!=null){
                                pesticide.setSealType((String)stringObjectMap.get("sealType"));//密闭方法
                            }
                            tFumigationPesticideMapper.insert(pesticide);
                        }
                        zyhc = zyhc.substring(0,zyhc.lastIndexOf("#"));
                        ckmd = ckmd.substring(0,ckmd.lastIndexOf("|"));
                        fumigationForrecord.setZyhc(zyhc);//主要害虫
                        fumigationForrecord.setCkmd(ckmd);//虫口密度
                    }
                }
            }
            if(detail.get("fumigationPersonnelList")!=null){
                List<Map<String,String>> person  =  (List<Map<String,String>>)detail.get("fumigationPersonnelList");
                if(!CollectionUtils.isEmpty(person)){
                    for (Map<String, String> stringObjectMap : person) {
                        TFumigationPersonnel personnel = new TFumigationPersonnel();
                        personnel.setDeleteState("1");//默认设置删除标志
                        personnel.setCreateTime(new Date());//创建时间
                        personnel.setId(ParameterUtil.getCode());
                        personnel.setForrecordId(uuid);
                        personnel.setOrgId(orgId);

                        if(stringObjectMap.get("personnelName") !=null){
                            //熏蒸人员姓名
                            personnel.setPersonnelName(stringObjectMap.get("personnelName"));
                        }
                        if(stringObjectMap.get("professionalQualification") !=null){
                            //职业资格
                            personnel.setProfessionalQualification(stringObjectMap.get("professionalQualification"));
                        }
                        if(stringObjectMap.get("physicalCondition") !=null){
                            //身体状况(施药资质审核	)
                            personnel.setPhysicalCondition(stringObjectMap.get("physicalCondition"));
                        }
                        if(stringObjectMap.get("workTask") !=null){
                            //工作任务
                            personnel.setWorkTask(stringObjectMap.get("workTask"));
                        }
                        if(stringObjectMap.get("outside") !=null){
                            //是否为外请
                            personnel.setOutside(stringObjectMap.get("outside").equals("1")?"是":"否");
                        }
                        if ("1".equals(stringObjectMap.get("sffzr"))) {
                        	fumigationForrecord.setXzzyfzr(stringObjectMap.get("personnelName"));//熏蒸作业负责人
                        }
                        addPersonnel(personnel);
                    }
                }
            }
            fumigationForrecord.setCfdm(cfdm);//仓房代码
            fumigationForrecord.setCfmc(cfmc);//仓房名称
            fumigationForrecord.setHouseId(houseId);//仓房id
            fumigationForrecord.setOrgId(orgId);//组织机构ID
            fumigationForrecord.setLssl(lssl);//粮食数量
            fumigationForrecord.setLspz(lspz);//粮食品种
            fumigationForrecord.setLyxz(lyxz);//粮油性质
            fumigationForrecord.setCgxzfs(cgxzfs);//常规熏蒸方式
            fumigationForrecord.setHlxzfs(hlxzfs);//环流熏蒸方式
            fumigationForrecord.setXzfs(xzfs);//熏蒸方式
            fumigationForrecord.setHlxzynhljsjh(hlxzynhljsjh);//环流熏蒸与内环流技术结合
            fumigationForrecord.setYjmc(yjmc);//药剂名称
            fumigationForrecord.setJx(jx);//药剂剂型
            fumigationForrecord.setNd(nd);//药剂浓度
            fumigationForrecord.setSyff(syff);//施药方式
            if(lqsl!=null){
                //领取数量
                fumigationForrecord.setLqsl(lqsl);//领取数量
            }
            fumigationForrecord.setLddwyyl(lddwyyl);//粮堆单位用药量
            fumigationForrecord.setKjdwyyl(kjdwyyl);//空间单位用药量
            fumigationForrecord.setZyyl(zyyl);//总用药量
            fumigationForrecord.setHcjcdh(hcjcdh);//害虫检测单号
            fumigationForrecord.setState(8);//写死为已备案
            add(fumigationForrecord);
        }
        modelMap.put("status", 200);
        modelMap.put("msg","接收成功!");
        //保存接收和返回日志信息
        systemOutsideDataService.addlogger("xzba", forRecord, modelMap.toString());
        return modelMap;
	}
}
