package com.chinaitop.depot.keeperHouse.controller;

import com.chinaitop.depot.keeperHouse.model.StorageHouserepair;
import com.chinaitop.depot.keeperHouse.service.StorageHouserepairService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/10/16
 * 仓房检查/维修
 */
@RestController
@RequestMapping(value= {"/houseRepair"})
@Api(value= "StorageHouserepairController", description = "仓房检查/维修控制类")
public class StorageHouserepairController {
    @Resource
    private StorageHouserepairService houseRepairService;

    /**
     * 分页获取仓房检查记录
     */
    @RequestMapping(value = "/getCheckList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="分页获取仓房检查记录", notes = "分页获取仓房检查记录，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query"),
            @ApiImplicitParam(name = "existFlag", value = "类型", paramType = "query"),
    })
    public PageInfo<StorageHouserepair> listCheckPage(HttpServletRequest request,Integer pageNum, Integer pageSize, Integer houseId, String searchStartDate, String searchEndDate, String existFlag) throws ParseException {

        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        StorageHouserepair houserepair= new StorageHouserepair();
        if(ParameterUtil.isnotnull(houseId)){
            houserepair.setStorehouseId(houseId);
        }
        if(ParameterUtil.isnotnull(orgId)){
            houserepair.setOrgId(orgId);
        }

        if(ParameterUtil.isnotnull(searchStartDate) && ParameterUtil.isnotnull(searchEndDate)){
            houserepair.setSearchStartDate(searchStartDate + " 00:00:00");
            houserepair.setSearchEndDate(searchEndDate + " 23:59:59");
        }

        if(StringUtils.isNotBlank(existFlag)){
            houserepair.setExistFlag(existFlag);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageHouserepair> list = houseRepairService.queryByHouseRepair(houserepair);

        PageInfo<StorageHouserepair> pageInfo = new PageInfo<StorageHouserepair>(list);
        return pageInfo;
    }

    /**
     * 新增和修改的数据进行保存(仓房检查)
     * @param houserepairJson
     * @return
     */
    @RequestMapping(value="/saveCheck", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改仓房检查数据", notes = "新增/修改仓房检查数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houserepairJson", value = "JSON数据对象", paramType = "form"),
    })
    public Map<String, Object> saveCheck(String houserepairJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageHouserepair houseRepair = null;
        try {
           houseRepair = (StorageHouserepair)mapper.readValue(houserepairJson, StorageHouserepair.class);
           houseRepairService.saveCheck(houseRepair);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 新增和修改的数据进行保存（仓房维修）
     * @param houserepairJson
     * @return
     */
    @RequestMapping(value="/saveRepair", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改仓房维修数据", notes = "新增/修改仓房维修数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houserepairJson", value = "JSON数据对象", paramType = "form"),
    })
    public Map<String, Object> saveRepair(String houserepairJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageHouserepair houseRepair = null;
        try {
            houseRepair = (StorageHouserepair)mapper.readValue(houserepairJson, StorageHouserepair.class);
            houseRepairService.saveRepair(houseRepair);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="获取仓房检查/维修ById", notes = "获取仓房检查/维修ById")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public StorageHouserepair loadDataById(Integer id){
        StorageHouserepair houseRepair = null;
        if(id == 0){
            houseRepair = new StorageHouserepair();
            houseRepair.setProblemExist("0");
        }else{
            houseRepair=  houseRepairService.loadDataById(id);
        }
        return houseRepair;
    }
    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据", notes = "根据主键id移除数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        StorageHouserepair houseRepair = null;
        try {
            houseRepair=  houseRepairService.loadDataById(id);
            if(houseRepair.getRepairStatus()!=null){
                retMap.put("msg","设备已维修,不可删除!");
            }else{
                houseRepairService.remove(id);
                retMap.put("msg","success");
            }
        }catch (Exception e){
            retMap.put("status", "error");
            e.printStackTrace();
        }
        return retMap;
    }

    /**
     * 分页获取仓房维修记录列表
     */
    @RequestMapping(value = "/getRepairList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="分页获取仓房维修记录列表", notes = "查询仓房维修记录列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "repairStatus", value = "维修状态", paramType = "query"),
    })
    public PageInfo<StorageHouserepair> listRepairPage(HttpServletRequest request,Integer pageNum, Integer pageSize, Integer houseId, String repairStatus){

        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        StorageHouserepair houserepair = new StorageHouserepair();
        if(ParameterUtil.isnotnull(houseId)){
            houserepair.setStorehouseId(houseId);
        }
        if(ParameterUtil.isnotnull(orgId)){
            houserepair.setOrgId(orgId);
        }

       //状态不为null 说明按照条件查询  否则将维修中和维修完成的都查询出来
        if(ParameterUtil.isnotnull(repairStatus)){
            houserepair.setRepairStatus(repairStatus);
        }else {
            //查询维修状态是维修中和维修完成的，为T说明要查询维修中和维修完成都查询出来
          houserepair.setExistFlag("T");
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageHouserepair> list = houseRepairService.queryByHouseRepair(houserepair);

        PageInfo<StorageHouserepair> pageInfo = new PageInfo<StorageHouserepair>(list);
        return pageInfo;
    }


}
