package com.chinaitop.depot.keeperHouse.controller;

import com.chinaitop.depot.keeperHouse.model.StorageKeeperTransfer;
import com.chinaitop.depot.keeperHouse.model.StorageKeepertransferDetails;
import com.chinaitop.depot.keeperHouse.model.StorageKeepertransferDetailsExample;
import com.chinaitop.depot.keeperHouse.service.StorageKeeperTransferService;
import com.chinaitop.depot.keeperHouse.service.StorageKeepertransferDetailsService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/10/24
 * 保管员移交
 */
@RestController
@RequestMapping(value = {"/keeperTransfer"})
@Api(value= "StorageKeeperTransferController", description = "保管员移交控制类")
public class StorageKeeperTransferController {
    @Resource
    private StorageKeeperTransferService keeperTransferService;

    @Resource
    private StorageKeepertransferDetailsService keepertransferDetailsService;

    /**
     * 分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="查询保管员移交记录列表", notes = "查询保管员移交记录列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query"),
            @ApiImplicitParam(name = "roleId", value = "保管员id", paramType = "query")
    })
    public PageInfo<StorageKeeperTransfer> listPage(HttpServletRequest request,Integer pageNum, Integer pageSize, Integer houseId,
                                                    String searchStartDate, String searchEndDate, Integer roleId) throws ParseException {

        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        StorageKeeperTransfer storageKeeperTransfer = new StorageKeeperTransfer();

        if(ParameterUtil.isnotnull(orgId)){
            storageKeeperTransfer.setOrgId(orgId);
        }

        if(ParameterUtil.isnotnull(searchStartDate) && ParameterUtil.isnotnull(searchEndDate)){
            storageKeeperTransfer.setSearchStartDate(searchStartDate + " 00:00:00");
            storageKeeperTransfer.setSearchEndDate(searchEndDate + " 23:59:59");
        }

        if(ParameterUtil.isnotnull(houseId)){
            storageKeeperTransfer.setHouseId(houseId);
        }

        if(roleId!=null){
            storageKeeperTransfer.setRoleId(roleId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageKeeperTransfer> list = keeperTransferService.queryByKeeperTransfer(storageKeeperTransfer);

        PageInfo<StorageKeeperTransfer> pageInfo = new PageInfo<StorageKeeperTransfer>(list);
        return pageInfo;
    }


    /**
     * 新增和修改的数据进行保存
     * @param keepertransferJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改数据", notes = "新增/修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "keepertransferJson", value = "保管员移交的JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "keepertransferDetailJson", value = "移交仓的品种质量/数量详情JSON数据对象", paramType = "form"),
    })
    public Map<String, Object> save(String keepertransferJson,String keepertransferDetailJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageKeeperTransfer keeperTransfer = null;
        try {
            keeperTransfer = (StorageKeeperTransfer)mapper.readValue(keepertransferJson, StorageKeeperTransfer.class);
            //记录本次移交的记录，实际移交的动作在仓房控制类中
            List<StorageKeepertransferDetails> keepertransferDetailsList = null;
            if (keepertransferDetailJson != null) {
                keepertransferDetailsList = (List<StorageKeepertransferDetails>)mapper.readValue(keepertransferDetailJson, new TypeReference<List<StorageKeepertransferDetails>>(){});
            }
            keeperTransferService.add(keeperTransfer,keepertransferDetailsList);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取保管员移交信息ById", notes = "获取保管员移交信息ById")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public StorageKeeperTransfer loadDataById(Integer id){
        if(id != 0) {
            return  keeperTransferService.loadDataById(id);
        }
        return new StorageKeeperTransfer();
    }

    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据", notes = "根据主键id移除数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        //删除保管员移交记录以及关联的记录
        keeperTransferService.remove(id);

        StorageKeepertransferDetailsExample keepertransferDetailsExample = new StorageKeepertransferDetailsExample();
        StorageKeepertransferDetailsExample.Criteria criteria = keepertransferDetailsExample.createCriteria();
        if(ParameterUtil.isnotnull(id)){
            criteria.andKtIdEqualTo(id);
        }
        keepertransferDetailsService.removeByKtId(keepertransferDetailsExample);
        retMap.put("msg","success");
        return retMap;
    }

}
