package com.chinaitop.depot.payment.controller;

import com.chinaitop.depot.payment.model.StoragePayment;
import com.chinaitop.depot.payment.model.StoragePaymentExample;
import com.chinaitop.depot.payment.service.StoragePayMentService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.HttpRequest;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @auther mafy
 * @createtime 2017/10/25 0025
 * 费用管理类
 */
@RestController
@RequestMapping(value = "/storagePayMent")
@Api(value= "StoragePayMentController", description = "费用管理控制类")
public class StoragePayMentController {

    @Resource
    private StoragePayMentService storagePayMentService;
    /**
     * 获取费用管理列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param searchStartDate
     * @param searchEndDate
     * @return
     */
    @RequestMapping(value = "/getpaymentList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询费用管理列表", notes = "查询费用管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "费用类型", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query")

    })
    public PageInfo<StoragePayment> getpaymentList(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer houseId, Integer type, String searchStartDate, String searchEndDate,Integer orgId){
        //Integer orgId = (Integer) request.getSession().getAttribute("org_id");
        StoragePaymentExample storagePaymentExample = new StoragePaymentExample();
        StoragePaymentExample.Criteria criteria = storagePaymentExample.createCriteria();
        if(ParameterUtil.isnotnull(houseId)){
           criteria.andHouseIdEqualTo(houseId);
        }
        if(ParameterUtil.isnotnull(type)){
            criteria.andTypeEqualTo(type);
        }
        if(ParameterUtil.isnotnull(orgId)){
            criteria.andOrgIdEqualTo(orgId);
        }

        if(ParameterUtil.isnotnull(searchStartDate) && ParameterUtil.isnotnull(searchEndDate)){
            Date starDate = ParameterUtil.string2datetime(searchStartDate + " 00:00:00");
            criteria.andPayTimeGreaterThanOrEqualTo(starDate);

            Date endDate = ParameterUtil.string2datetime(searchEndDate + " 23:59:59");
            criteria.andPayTimeLessThanOrEqualTo(endDate);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StoragePayment> list = storagePayMentService.getlist(storagePaymentExample);
        PageInfo<StoragePayment> pageInfo = new PageInfo<StoragePayment>(list);
        return pageInfo;
    }
    /**
     * 获取费用ById
     * @return
     */
    @RequestMapping(value = "/getpaymentListById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取费用ById", notes = "获取费用ById")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public StoragePayment getpaymentListById(Integer id){
        return storagePayMentService.getObjById(id);
    }

    /**
     * 新增
     * @param paymentJson
     * @return
     */
    @RequestMapping(value = "edit" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增数据", notes = "新增数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "paymentJson", value = "JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "登陆人id", paramType = "orgId"),
    })
    public Map<String,String> edit(String paymentJson,Integer orgId){
        ObjectMapper mapper = new ObjectMapper();
        try {
            StoragePayment storagePayment = (StoragePayment) mapper.readValue(paymentJson, StoragePayment.class);
            storagePayment.setOrgId(orgId);
            if(ParameterUtil.isnotnull(storagePayment.getId())){
                storagePayMentService.update(storagePayment);
            }else{
                storagePayMentService.insert(storagePayment);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 移除
     * @param id
     * @return
     */
    @RequestMapping(value = "remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按ID删除费用信息", notes = "按ID删除费用信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String,String> remove(Integer id){
        Map<String,String> map = new HashMap<String, String>();
         storagePayMentService.remove(id);
        map.put("status","success");
        return map;
    }
}











