package com.chinaitop.depot.product.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.product.model.StorageProductFcbgz;
import com.chinaitop.depot.product.model.StorageProductFcbgzExample;
import com.chinaitop.depot.product.model.StorageProductKcsl;
import com.chinaitop.depot.product.service.StorageProductFcbgzService;
import com.chinaitop.depot.product.service.StorageProductKcslService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

/**
 * @auther mafy
 * @createtime 2020/10/25 0025
 * 分仓保管账类
 */
@RestController
@RequestMapping(value = "/StorageProductFcbgz")
@Api(value= "StorageProductFcbgzController", description = "成品粮油分仓保管账")
@Slf4j
public class StorageProductFcbgzController {

    @Resource
    private StorageProductFcbgzService storageProductFcbgzService;

    @Resource
    private StorageProductKcslService storageProductKcslService;

    @RequestMapping(value = "/getProductList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询分仓保管账列表", notes = "查询分仓保管账信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构代码", paramType = "query")

    })
    public PageInfo<StorageProductFcbgz> getProductList(Integer pageNum, Integer pageSize, 
    		String houseId, String wareId, String searchStartDate, String searchEndDate, Integer orgId){
        StorageProductFcbgzExample storageProductFcbgzExample = new StorageProductFcbgzExample();
        StorageProductFcbgzExample.Criteria criteria = storageProductFcbgzExample.createCriteria();
        if(ParameterUtil.isnotnull(houseId)){
           criteria.andHouseIdEqualTo(houseId);
        }
        if(ParameterUtil.isnotnull(wareId)){
            criteria.andWarehouseIdEqualTo(wareId);
         }
        if(ParameterUtil.isnotnull(orgId)){
            criteria.andOrgIdEqualTo(orgId);
        }

        if(ParameterUtil.isnotnull(searchStartDate) && ParameterUtil.isnotnull(searchEndDate)){
            Date starDate = ParameterUtil.string2datetime(searchStartDate + " 00:00:00");
            criteria.andRecordDateGreaterThanOrEqualTo(starDate);

            Date endDate = ParameterUtil.string2datetime(searchEndDate + " 23:59:59");
            criteria.andRecordDateLessThanOrEqualTo(endDate);
        }
        criteria.andDeleteStateNotEqualTo("0");
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        storageProductFcbgzExample.setOrderByClause(" record_date desc");
        List<StorageProductFcbgz> list = storageProductFcbgzService.getlist(storageProductFcbgzExample);
        PageInfo<StorageProductFcbgz> pageInfo = new PageInfo<StorageProductFcbgz>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/getNumberList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询库存数量列表", notes = "查询库存数量信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位id", paramType = "query")

    })
    public PageInfo<StorageProductKcsl> getNumberList(Integer pageNum, Integer pageSize,
                                                      Integer houseId, Integer wareId, Integer orgId){

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageProductKcsl> list = null;
        try {
			list = storageProductKcslService.getList(houseId, wareId, orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
        PageInfo<StorageProductKcsl> pageInfo = new PageInfo<StorageProductKcsl>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/getProductHouse" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="仓房下拉", notes = "新增用到的仓房下拉")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
    })
    public List<Map<String,Object>> getProductHouse(String orgId){
        Map<String,Object> map = new HashMap<String, Object>();
        map.put("orgId",orgId);
        List<Map<String,Object>> list = storageProductFcbgzService.getProductHouse(map);
        return ParameterUtil.slashCapitals(list);
    }

    @RequestMapping(value = "/saveProduct" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增数据", notes = "新增数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "productJson", value = "JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "登陆人id", paramType = "query"),
            @ApiImplicitParam(name = "typeState", value = "提交状态", paramType = "query")
    })
    public Map<String,String> edit(String productJson,Integer orgId, String typeState){
        Map<String, String> map = new HashMap<String, String>();
        try {
            map = storageProductFcbgzService.edit(productJson, orgId, typeState);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return map;
    }

    /**
     * 获取分仓保管账详情
     * @return
     */
    @RequestMapping(value = "/getProductById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取分仓保管账详情", notes = "获取分仓保管账详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public StorageProductFcbgz getProductById(String id){
        StorageProductFcbgz storageProductFcbgz = storageProductFcbgzService.getProductById(id);
        return storageProductFcbgz;
    }

    /**
     * 获取数量详情
     * @return
     */
    @RequestMapping(value = "/getNumberEdit" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取数量详情", notes = "获取数量详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "orgId", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "houseId", paramType = "query")
    })
    public StorageProductFcbgz getNumberEdit(String orgId, String houseId){
        StorageProductFcbgzExample storageProductFcbgzExample = new StorageProductFcbgzExample();
        StorageProductFcbgzExample.Criteria criteria = storageProductFcbgzExample.createCriteria();
        criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
        criteria.andHouseIdEqualTo(houseId);
        criteria.andDeleteStateEqualTo("3");
        List<StorageProductFcbgz> storageProductFcbgz = storageProductFcbgzService.getlist(storageProductFcbgzExample);
        return storageProductFcbgz.get(0);
    }

    @RequestMapping(value = "remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按ID删除分仓保管账", notes = "按ID删除分仓保管账")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String,String> remove(String id){
        Map<String,String> map = new HashMap<String, String>();
        storageProductFcbgzService.remove(id);
        map.put("status","success");
        return map;
    }
    /**
     * 根据仓房和货位查询上一条数据并回显
     * @param orgId
     * @param houseId
     * @param wareId
     * @return
     */
    @RequestMapping(value = "gethouseData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓房查询分仓保管账", notes = "根据仓房查询分仓保管账")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "form"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "form"),
            @ApiImplicitParam(name = "wareId", value = "货位id", paramType = "form")
    })
    public StorageProductFcbgz gethouseData(String orgId, String houseId, String wareId){
        StorageProductFcbgzExample example = new StorageProductFcbgzExample();
        StorageProductFcbgzExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
        criteria.andHouseIdEqualTo(houseId);
        if(ParameterUtil.isnotnull(wareId)){
            criteria.andWarehouseIdEqualTo(wareId);
        }
        example.setOrderByClause("create_time DESC");
        List<StorageProductFcbgz> storageProductFcbgzList = storageProductFcbgzService.getlist(example);
        if(storageProductFcbgzList.size() == 0){
            return null;
        }else{
            return storageProductFcbgzList.get(0);
        }
    }

    @RequestMapping(value = "gitSubmit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="分仓保管账列表提交方法", notes = "列表提交方法")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "fcbgzId", paramType = "query")
    })
    public Map<String,String> gitSubmit(String orgId, String id){
        Map<String, String> map = null;
		try {
            map = storageProductFcbgzService.getSubmit(id);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return map;
    }

    @RequestMapping(value = "restHdData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="成品粮库存数量核对时间刷新", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
    })
    public void restFcbgzData(Integer orgId) {
    	try {
    		storageProductKcslService.restHdData(orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
    }

    @RequestMapping(value = "getCplKcsl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取成品粮总库存数", notes = "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位id", paramType = "query")
    })
    public String getCplKcsl(Integer orgId, Integer houseId, Integer wareId) {
        String kcsl = "0";
        try {
            kcsl = storageProductKcslService.getCplKcsl(orgId, houseId, wareId);
        } catch (Exception e) {
            //e.printStackTrace();
            log.error(e.getMessage(), e);
        }
        return kcsl;
    }
}