package com.chinaitop.depot.registrationTable.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.chinaitop.depot.registrationTable.service.RegistrationTableService;
import com.chinaitop.depot.registrationTable.service.impl.ImportFileServiceImpl;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 登统表导入
 *
 * @author hf
 *
 */
@RestController
@RequestMapping(value = "/storage/registrationTable")
@Api(value= "RegistrationTableController", description = "登统表导入控制类")
public class RegistrationTableController {

	@Resource
	private RegistrationTableService registrationTableService;
	@Resource
	private ImportFileServiceImpl importService;

	/**
	 * 小麦导入excel
	 * @param file 文件
	 * @param fileType 类型：如xlsx
	 * @param request
	 * @return
	 */
	@RequestMapping(value="/importFileWheat", method=RequestMethod.POST)
	@ApiOperation(value="导入小麦登统表excel", notes = "导入小麦登统excel")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
			@ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form")
	})
	public String importFileWheat(MultipartFile file, String fileType, HttpServletRequest request){

		String[] titleArr = {"车号:3","仓房名称:3","货位名称:3","品名:3","生产年度:3","入库日期:3","入库数量:3","等级:4","水分:4","容重:4","总量:5","矿物质:5","无机杂质:5","有机杂质:5","总量:5","虫蚀粒:5","总量:6","黑胚粒:6","赤霉病粒:6","破损粒:5","生芽粒:5","生霉粒:5","色泽气味:4","硬度指数:4","储存方式:3"};//导入数据的title以及所在的行数
		boolean[] emptyArr = {false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false};//指定列可为空，不可为空值为false.

		List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
		String errormsg = null;
		int beginRow = 7;//数据开始行数
		try {
			errormsg = importService.importFile(file, fileType, request, titleArr, emptyArr, list, beginRow);

			if (errormsg != null && !"".equals(errormsg)) {
				return errormsg;
			}

			if (list.size()>0) {
				String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"));
				errormsg = registrationTableService.importDataWheat(list,orgId,beginRow);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return errormsg;
	}
	
	/**
	 * 玉米导入excel
	 * @param file 文件
	 * @param fileType 类型：如xlsx
	 * @param request
	 * @return
	 */
	@RequestMapping(value="/importFileCorn", method=RequestMethod.POST)
	@ApiOperation(value="导入玉米登统表excel", notes = "导入玉米登统excel")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
		@ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form")
	})
	public String importFileCorn(MultipartFile file, String fileType, HttpServletRequest request){
		
		String[] titleArr = {"车号:2","仓房名称:2","货位名称:2","品名:2","生产年度:2","入库日期:2","入库数量:2","等级:3","水分:3","容重:3","总量:4","无机杂质:4","有机杂质:4","总量:4","虫蚀粒:4","病斑粒:4","破损粒:4","生芽粒:4","生霉粒:4","自然热损伤粒:5","烘干热损伤粒:5","霉变粒:3","色泽气味:3","储存方式:2"};//导入数据的title以及所在的行数
		boolean[] emptyArr = {false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false};//指定列可为空，不可为空值为false.
		
		List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
		String errormsg = null;
		int beginRow = 6;//数据开始行数
		try {
			errormsg = importService.importFile(file, fileType, request, titleArr, emptyArr, list, beginRow);
			
			if (errormsg != null && !"".equals(errormsg)) {
				return errormsg;
			}
			
			if (list.size()>0) {
				String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"));
				errormsg = registrationTableService.importDataCorn(list,orgId,beginRow);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return errormsg;
	}
	
	/**
	 * 大豆导入excel
	 * @param file 文件
	 * @param fileType 类型：如xlsx
	 * @param request
	 * @return
	 */
	@RequestMapping(value="/importFileSoybean", method=RequestMethod.POST)
	@ApiOperation(value="导入大豆登统表excel", notes = "导入大豆登统excel")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
		@ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form")
	})
	public String importFileSoybean(MultipartFile file, String fileType, HttpServletRequest request){
		
		String[] titleArr = {"车号:3","仓房名称:3","货位名称:3","品名:3","生产年度:3","入库日期:3","入库数量:3","等级:4","水分:4","完整粒率:4","未熟粒率:4","破碎率:4","总量:5","无机杂质:5","有机杂质:5","总量:5","热损伤粒:5","虫蚀粒:5","病斑粒:5","生芽、涨大粒:5","生霉粒:5","冻伤粒:5","粗脂肪含量（干基）:4","色泽气味:4","储存方式:3"};//导入数据的title以及所在的行数
		boolean[] emptyArr = {false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false};//指定列可为空，不可为空值为false.
		
		List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
		String errormsg = null;
		int beginRow = 6;//数据开始行数
		try {
			errormsg = importService.importFile(file, fileType, request, titleArr, emptyArr, list, beginRow);
			
			if (errormsg != null && !"".equals(errormsg)) {
				return errormsg;
			}
			
			if (list.size()>0) {
				String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"));
				errormsg = registrationTableService.importDataSoybean(list,orgId,beginRow);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return errormsg;
	}
	
	/**
	 * 稻谷导入excel
	 * @param file 文件
	 * @param fileType 类型：如xlsx
	 * @param request
	 * @return
	 */
	@RequestMapping(value="/importFileRice", method=RequestMethod.POST)
	@ApiOperation(value="导入稻谷登统表excel", notes = "导入稻谷登统excel")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
		@ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form")
	})
	public String importFileRice(MultipartFile file, String fileType, HttpServletRequest request){
		
		String[] titleArr = {"车号:3","仓房名称:3","货位名称:3","品名:3","生产年度:3","入库日期:3","入库数量:3","等级:4","水分:4","出糙率:4","整精米率:4","谷外糙米:4","互混率:4","总量:5","无机杂质:5","有机杂质:5","总量:5","未熟粒:5","虫蚀粒:5","病斑粒:5","生芽粒:5","生霉粒:5","黄粒米:4","色泽气味:4","储存方式:3"};//导入数据的title以及所在的行数
		boolean[] emptyArr = {false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false};//指定列可为空，不可为空值为false.
		
		List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
		String errormsg = null;
		int beginRow = 6;//数据开始行数
		try {
			errormsg = importService.importFile(file, fileType, request, titleArr, emptyArr, list, beginRow);
			
			if (errormsg != null && !"".equals(errormsg)) {
				return errormsg;
			}
			
			if (list.size()>0) {
				String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"));
				errormsg = registrationTableService.importDataRice(list,orgId,beginRow);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return errormsg;
	}
	
	/**
	 * 大豆原油导入excel
	 * @param file 文件
	 * @param fileType 类型：如xlsx
	 * @param request
	 * @return
	 */
	@RequestMapping(value="/importFileCrudeOil", method=RequestMethod.POST)
	@ApiOperation(value="导入大豆原油登统表excel", notes = "导入大豆原油登统excel")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
		@ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form")
	})
	public String importFileCrudeOil(MultipartFile file, String fileType, HttpServletRequest request){
		
		String[] titleArr = {"车号:4","油罐名称:4","品名:4","生产年度:4","入库日期:4","入库数量:4","气味、滋味:5","水分及挥发物含量:5","不溶性杂质含量:5","酸价:5","过氧化值:5","溶剂残留量:5","储存方式:4"};//导入数据的title以及所在的行数
		boolean[] emptyArr = {false,false,false,false,false,false,false,false,false,false,false,false,false};//指定列可为空，不可为空值为false.
		
		List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
		String errormsg = null;
		int beginRow = 7;//数据开始行数
		try {
			errormsg = importService.importFile(file, fileType, request, titleArr, emptyArr, list, beginRow);
			
			if (errormsg != null && !"".equals(errormsg)) {
				return errormsg;
			}
			
			if (list.size()>0) {
				String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"));
				errormsg = registrationTableService.importDataCrudeOil(list,orgId,beginRow);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return errormsg;
	}

	@RequestMapping(value="/queryImportPzCount", method=RequestMethod.GET)
	@ApiOperation(value="查询大豆原油导入总数量", notes = "")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "json", value = "条件对象", paramType = "query"),
		@ApiImplicitParam(name = "pzlx", value = "类型(1小麦,2玉米,3大豆,4稻谷,5大豆原油)", paramType = "query")
	})
	public String queryImportPzCount(HttpServletRequest request, String json, String pzlx){

		String drzsl = "";
		try {
			drzsl = registrationTableService.queryImportPzCount(request, json, pzlx);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return drzsl;
	}
	
	@RequestMapping(value="/view", method=RequestMethod.GET)
	@ApiOperation(value="查询单位下登统表导入数量跟期初库存数量 ", notes = "")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页数", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "json", value = "条件对象", paramType = "query"),
		@ApiImplicitParam(name = "pzlx", value = "类型(1小麦,2玉米,3大豆,4稻谷,5大豆原油)", paramType = "query")
	})
	public PageInfo<Map<String, Object>> view(HttpServletRequest request, Integer pageNum, Integer pageSize, String json, String pzlx){

		PageInfo<Map<String, Object>> pageInfo = null;
		try {
			pageInfo = registrationTableService.view(request, pageNum, pageSize, json, pzlx);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}

}