package com.chinaitop.depot.registrationTable.service.impl;

import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import org.springframework.web.multipart.MultipartFile;

import com.chinaitop.depot.registrationTable.util.ExcelImportUtils;
import com.chinaitop.depot.utils.ParameterUtil;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

/**
 * @auther hf
 * @createtime 2020/08/05
 * 导入公共类，直接调用importFile方法即可
 */
@Service
public class ImportFileServiceImpl {



    public String importFile(MultipartFile file, String fileType, HttpServletRequest request, String[] titleArr, boolean[] emptyArr, List<List<String>> lists, Integer beginRow) throws Exception{

        // 服务器路径
        String rootPath = request.getSession().getServletContext().getRealPath("");
        // 文件相对路径
        String relativePath = "/upload/" + fileType;
        //创建临时文件
        createTemp(file,request,rootPath,relativePath);
        //读取临时文件，并且返回错误信息
        String fileAllpath = rootPath+relativePath+"/"+file.getOriginalFilename();

        String retVal = readExcelValue(fileAllpath,titleArr,emptyArr,lists,beginRow);

        return retVal;
    }

    /**
     * 创建临时文件
     * @param file 上传过来的文件流
     * @param request 请求
     * @param rootPath 根目录
     * @param relativePath 相对路径
     * @throws Exception
     */
    public void createTemp(MultipartFile file, HttpServletRequest request, String rootPath, String relativePath) throws Exception{
        // 如路径不存在，则创建它
        File directory = new File(rootPath + relativePath);
        if (!directory.exists()) {
            directory.mkdirs();
        }
        String filePath = relativePath + "/" + file.getOriginalFilename();
        // 复制 文件
        file.transferTo(new File(rootPath + filePath));
    }


    /**
     * 解析Excel里面的数据，目前只支持1个sheet
     * @param fileName
     * @return
     */
    public String readExcelValue(String fileName,String[] titleArr,boolean[] emptyArr,List<List<String>> list, Integer beginRow){

        //获取File
        File tempFile = new File(fileName);

        StringBuilder errorMSG = new StringBuilder("");//错误信息收集器
        int sheetNum = 1;//sheet的总数
        //循环每一个sheet
        for (int i = 0; i < sheetNum; i++) {
            String err = everySheet(getWorkbook(tempFile,fileName).getSheetAt(i),titleArr,emptyArr,list,beginRow);
            if(ParameterUtil.isnotnull(err)){
                errorMSG.append("第"+(i+1)+"个sheet，名称为："+getWorkbook(tempFile,fileName).getSheetName(i)+"，错误信息："+err);
            }
        }

        //删除临时文件
        if(tempFile.exists()){ tempFile.delete(); }

        return errorMSG.toString();
    }


    //获取workbook
    private Workbook getWorkbook(File file ,String FileName){
        Workbook wb = null;
        try {
            InputStream is = new FileInputStream(file);
            if(ExcelImportUtils.isExcel2007(FileName))
                wb = new XSSFWorkbook(is);
            else
                wb = new HSSFWorkbook(is);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return wb;
    }


    //遍历每一个sheet，获取值和错误信息
    private String  everySheet(Sheet sheet,String[] titleArr,boolean[] emptyArr,List<List<String>> list, Integer beginRow){
        String errorMsg = "", br = "<br/>";
        //去掉所有空白行
        boolean flag = false;
        for (int i = beginRow; i <= sheet.getLastRowNum();) {
			Row r = sheet.getRow(i);
			if(r == null){
				// 如果是空行（即没有任何数据、格式），直接把它以下的数据往上移动
				sheet.shiftRows(i+1, sheet.getLastRowNum(),-1);
				continue;
			}
			flag = false;
			for(Cell c:r){
				if(c.getCellType() != Cell.CELL_TYPE_BLANK){
					flag = true;
					break;
				}
			}
			if(flag){
				i++;
				continue;
			}
			else{//如果是空白行（即可能没有数据，但是有一定格式）
				if(i == sheet.getLastRowNum())//如果到了最后一行，直接将那一行remove掉
					sheet.removeRow(r);
				else//如果还没到最后一行，则数据往上移一行
				    sheet.shiftRows(i+1, sheet.getLastRowNum(),-1);
			}
		}
        //得到当前sheet的Excel的行数
        //int totalRows=sheet.getPhysicalNumberOfRows();
        int totalRows=sheet.getLastRowNum()+1;
        
        //总列数
        int totalCells = 0;
        //得到Excel的列数(前提是有行数)
        if(totalRows>=beginRow && sheet.getRow(1) != null){
            totalCells=sheet.getRow(0).getPhysicalNumberOfCells();
        }else{
            return "请确认excel的数据";
        }

        if (!ExcelImportUtils.isSame(sheet,totalCells,titleArr)){ return "导入excel和模板不一致"; }//判断标题是否正确

        //开始处理数据，循环Excel行数
        for(int r=beginRow;r<totalRows;r++){
            List<String> rowList = new ArrayList<String>();
            Row row = sheet.getRow(r);
            if (row == null){
                errorMsg += br+"第"+(r+1)+"行数据异常，请仔细检查！";
                continue;
            }

            //循环Excel的列
            for(int c = 0; c <totalCells; c++){
                Cell cell = row.getCell(c);
                if(cell == null){
                    rowList.add("");
                }else{
                    cell.setCellType(Cell.CELL_TYPE_STRING);
                    String cellVal = cell.getStringCellValue();
                    if((StringUtils.isEmpty(cellVal) && !emptyArr[c])){
                        errorMsg+=br+"第"+(r+1)+"行，第"+(c+1)+"列数据不可为空或者数据异常";
                        rowList.add("error");
                    }else{
                        //正常数据处理
                        rowList.add(cellVal);
                    }
                }
                if(c == totalCells-1) list.add(rowList);//将每一行的数据添加到list中
            }
        }
        return errorMsg;
    }
}

