package com.chinaitop.depot.registrationTable.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.registrationTable.mapper.RecordCornInfoMapper;
import com.chinaitop.depot.registrationTable.mapper.RecordCrudeoilInfoMapper;
import com.chinaitop.depot.registrationTable.mapper.RecordRiceInfoMapper;
import com.chinaitop.depot.registrationTable.mapper.RecordSoybeanInfoMapper;
import com.chinaitop.depot.registrationTable.mapper.RecordWheatInfoMapper;
import com.chinaitop.depot.registrationTable.model.RecordCornInfo;
import com.chinaitop.depot.registrationTable.model.RecordCrudeoilInfo;
import com.chinaitop.depot.registrationTable.model.RecordRiceInfo;
import com.chinaitop.depot.registrationTable.model.RecordSoybeanInfo;
import com.chinaitop.depot.registrationTable.model.RecordWheatInfo;
import com.chinaitop.depot.registrationTable.service.RegistrationTableService;
import com.chinaitop.depot.registrationTable.util.RecordUtils;
import com.chinaitop.depot.statisticalReport.mapper.StatisticalReportMapper;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

@Service
@SuppressWarnings("all")
public class RegistrationTableServiceImpl implements RegistrationTableService {

	@Resource
	private RecordWheatInfoMapper recordWheatInfoMapper;
	
	@Resource
	private RecordCornInfoMapper recordCornInfoMapper;
	
	@Resource
	private RecordSoybeanInfoMapper recordSoybeanInfoMapper;
	
	@Resource
	private RecordRiceInfoMapper recordRiceInfoMapper;
	
	@Resource
	private RecordCrudeoilInfoMapper recordCrudeoilInfoMapper;
	
	@Resource
	private StatisticalReportMapper statisticalReportMapper;

	@Override
	public String importDataWheat(List<List<String>> list, String orgId, Integer beginRow) {
		
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		List<Map<String, Object>> storeHouseList = statisticalReportMapper.getStoreHouseInfo(map);
		List<Map<String, Object>> wareHouseList = statisticalReportMapper.getWareHouseInfo(map);

		List<RecordWheatInfo> wheatList = new ArrayList<RecordWheatInfo>();
		RecordWheatInfo recordWheatInfo = null;
		String msg = "", br = "<br/>";//消息
		boolean value_flag = false;
		int storehouse_id = 0;//仓房id
		
		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			recordWheatInfo = new RecordWheatInfo();
			recordWheatInfo.setOrgId(Integer.parseInt(orgId));
			recordWheatInfo.setId(UUID.randomUUID().toString());
			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
					case 0://车号
						if (ParameterUtil.isnotnull(revList.get(j))) {
							if (!ParameterUtil.checkPlateNumberFormat(revList.get(j))) {
								msg += "第 "+(beginRow+i+1)+" 行第 1 列的值不符合车牌号规则！" + br;
								break;
							}
							recordWheatInfo.setClbh(revList.get(j));
						}
						break;
					case 1://仓房名称
						for(int n=0;n<storeHouseList.size();n++) {
							Map<String, Object> storeMap = (Map<String, Object>)storeHouseList.get(n);
							if(revList.get(j).equals(ObjectUtils.toString(storeMap.get("storehouse_name")))) {
								recordWheatInfo.setCfmc(revList.get(j));
								storehouse_id = Integer.parseInt(ObjectUtils.toString(storeMap.get("storehouse_id")));
								break;
							}
						}
						if ("".equals(recordWheatInfo.getCfmc()) || recordWheatInfo.getCfmc() == null) {
							msg += "第 "+(beginRow+i+1)+" 行第 2 列的仓房名称不存在！" + br;
							break;
						}
						break;
					case 2://货位名称
						for(int n=0;n<wareHouseList.size();n++) {
							Map<String, Object> wareMap = (Map<String, Object>)wareHouseList.get(n);
							if(storehouse_id == Integer.parseInt(ObjectUtils.toString(wareMap.get("storehouse_id")))
									&& revList.get(j).equals(ObjectUtils.toString(wareMap.get("warehouse_name")))) {
								recordWheatInfo.setHwmc(revList.get(j));
								storehouse_id = 0;//重置仓房id
								break;
							}
						}
						if ("".equals(recordWheatInfo.getHwmc()) || recordWheatInfo.getHwmc() == null) {
							msg += "第 "+(beginRow+i+1)+" 行第 3 列的货位名称不存在！" + br;
							break;
						}
						break;
					case 3://品名
						if (revList.get(j).length() > 30) {
							msg += "第 "+(beginRow+i+1)+" 行第 4 列的品名长度不能超过30！" + br;
							break;
						}
						recordWheatInfo.setPzmc(revList.get(j));
						break;
					case 4://生产年度
						if (!ParameterUtil.isYear(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 5 列的生产年度不是年份！" + br;
							break;
						}
						recordWheatInfo.setScnd(revList.get(j));
						break;
					case 5://入库日期
						if (!ParameterUtil.stringIsDate(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 6 列的入库日期格式不对！" + br;
							break;
						}
						recordWheatInfo.setRkrq(ParameterUtil.string2dates(revList.get(j)));
						break;
					case 6://入库数量
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 7 列的入库数量数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setRksl(revList.get(j));
						break;
					case 7://等级
						if (revList.get(j).length() > 10) {
							msg += "第 "+(beginRow+i+1)+" 行第 8 列的等级长度不能超过10！" + br;
							break;
						}
						recordWheatInfo.setDj(revList.get(j));
						break;
					case 8://水分
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 9 列的水分数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setSf(revList.get(j));
						break;
					case 9://容重
						if (!ParameterUtil.isMatches(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 10 列的容重数据不对(非负整数)！" + br;
							break;
						}
						recordWheatInfo.setRz(revList.get(j));
						break;
					case 10://杂质总量
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 11 列的杂质总量数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setZzzl(revList.get(j));
						break;
					case 11://矿物质
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 12 列的杂质矿物质数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setZzkwz(revList.get(j));
						break;
					case 12://无机杂质
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 13 列的无机杂质数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setWjzz(revList.get(j));
						break;
					case 13://有机杂质
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 14 列的有机杂质数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setYjzz(revList.get(j));
						break;
					case 14://不完善粒总量
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 15 列的不完善粒总量数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setBwslzl(revList.get(j));
						break;
					case 15://虫蚀粒
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 16 列的虫蚀粒数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setCsl(revList.get(j));
						break;
					case 16://病斑粒总量
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 17 列的病斑粒总量数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setBblzl(revList.get(j));
						break;
					case 17://黑胚粒
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 18 列的黑胚粒数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setHpl(revList.get(j));
						break;
					case 18://赤霉病粒
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 19 列的赤霉病粒数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setCmbl(revList.get(j));
						break;
					case 19://破损粒
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 20 列的破损粒数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setPsl(revList.get(j));
						break;
					case 20://生芽粒
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 21 列的生芽粒数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setSyl(revList.get(j));
						break;
					case 21://生霉粒
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 22 列的生霉粒数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setSml(revList.get(j));
						break;
					case 22://色泽气味
						if (revList.get(j).length() > 5) {
							msg += "第 "+(beginRow+i+1)+" 行第 23 列的色泽气味长度不能超过5位！" + br;
							break;
						}
						recordWheatInfo.setSzqw(revList.get(j));
						break;
					case 23://硬度指数
						if (!ParameterUtil.isNumber(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 24 列的硬度指数数据不对(正数且最多三位小数)！" + br;
							break;
						}
						recordWheatInfo.setYdzs(revList.get(j));
						break;
					case 24://存储方式
						if (revList.get(j).length() > 5) {
							msg += "第 "+(beginRow+i+1)+" 行第 25 列的存储方式长度不能超过5位！" + br;
							break;
						}
						recordWheatInfo.setCcfs(revList.get(j));
						//添加到list，所有数据都没问题才一起insert数据库
						if (recordWheatInfo != null) {
							wheatList.add(recordWheatInfo);
						}
						break;
					default :
						break;
				}

			}

		}
		if("".equals(msg)) {
			for(RecordWheatInfo lists:wheatList) {
				recordWheatInfoMapper.insert(lists);
			}
		}
		return msg;
	}
	
	@Override
	public String importDataCorn(List<List<String>> list, String orgId, Integer beginRow) {
		
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		List<Map<String, Object>> storeHouseList = statisticalReportMapper.getStoreHouseInfo(map);
		List<Map<String, Object>> wareHouseList = statisticalReportMapper.getWareHouseInfo(map);
		
		List<RecordCornInfo> cornList = new ArrayList<RecordCornInfo>();
		RecordCornInfo recordCornInfo = null;
		String msg = "", br = "<br/>";//消息
		boolean value_flag = false;
		int storehouse_id = 0;//仓房id
		
		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			recordCornInfo = new RecordCornInfo();
			recordCornInfo.setOrgId(Integer.parseInt(orgId));
			recordCornInfo.setId(UUID.randomUUID().toString());
			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
				case 0://车号
					if (ParameterUtil.isnotnull(revList.get(j))) {
						if (!ParameterUtil.checkPlateNumberFormat(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 1 列的值不符合车牌号规则！" + br;
							break;
						}
						recordCornInfo.setClbh(revList.get(j));
					}
					break;
				case 1://仓房名称
					for(int n=0;n<storeHouseList.size();n++) {
						Map<String, Object> storeMap = (Map<String, Object>)storeHouseList.get(n);
						if(revList.get(j).equals(ObjectUtils.toString(storeMap.get("storehouse_name")))) {
							recordCornInfo.setCfmc(revList.get(j));
							storehouse_id = Integer.parseInt(ObjectUtils.toString(storeMap.get("storehouse_id")));
							break;
						}
					}
					if ("".equals(recordCornInfo.getCfmc()) || recordCornInfo.getCfmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 2 列的仓房名称不存在！" + br;
						break;
					}
					break;
				case 2://货位名称
					for(int n=0;n<wareHouseList.size();n++) {
						Map<String, Object> wareMap = (Map<String, Object>)wareHouseList.get(n);
						if(storehouse_id == Integer.parseInt(ObjectUtils.toString(wareMap.get("storehouse_id")))
								&& revList.get(j).equals(ObjectUtils.toString(wareMap.get("warehouse_name")))) {
							recordCornInfo.setHwmc(revList.get(j));
							storehouse_id = 0;//重置仓房id
							break;
						}
					}
					if ("".equals(recordCornInfo.getHwmc()) || recordCornInfo.getHwmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 3 列的货位名称不存在！" + br;
						break;
					}
					break;
				case 3://品名
					if (revList.get(j).length() > 30) {
						msg += "第 "+(beginRow+i+1)+" 行第 4 列的品名长度不能超过30！" + br;
						break;
					}
					recordCornInfo.setPzmc(revList.get(j));
					break;
				case 4://生产年度
					if (!ParameterUtil.isYear(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 5 列的生产年度不是年份！" + br;
						break;
					}
					recordCornInfo.setScnd(revList.get(j));
					break;
				case 5://入库日期
					if (!ParameterUtil.stringIsDate(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 6 列的入库日期格式不对！" + br;
						break;
					}
					recordCornInfo.setRkrq(ParameterUtil.string2dates(revList.get(j)));
					break;
				case 6://入库数量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 7 列的入库数量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setRksl(revList.get(j));
					break;
				case 7://等级
					if (revList.get(j).length() > 10) {
						msg += "第 "+(beginRow+i+1)+" 行第 8 列的等级长度不能超过10！" + br;
						break;
					}
					recordCornInfo.setDj(revList.get(j));
					break;
				case 8://水分
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 9 列的水分数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setSf(revList.get(j));
					break;
				case 9://容重
					if (!ParameterUtil.isMatches(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 10 列的容重数据不对(非负整数)！" + br;
						break;
					}
					recordCornInfo.setRz(revList.get(j));
					break;
				case 10://杂质总量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 11 列的杂质总量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setZzzl(revList.get(j));
					break;
				case 11://无机杂质
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 12 列的无机杂质数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setWjzz(revList.get(j));
					break;
				case 12://有机杂质
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 13 列的有机杂质数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setYjzz(revList.get(j));
					break;
				case 13://不完善粒总量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 14 列的不完善粒总量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setBwslzl(revList.get(j));
					break;
				case 14://虫蚀粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 15 列的虫蚀粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setCsl(revList.get(j));
					break;
				case 15://病斑粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 16 列的病斑粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setBbl(revList.get(j));
					break;
				case 16://破损粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 17 列的破损粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setPsl(revList.get(j));
					break;
				case 17://生芽粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 18 列的生芽粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setSyl(revList.get(j));
					break;
				case 18://生霉粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 19 列的生霉粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setSml(revList.get(j));
					break;
				case 19://自然热损伤粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 20 列的自然热损伤粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setZrrssl(revList.get(j));
					break;
				case 20://烘干热损伤粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 21 列的烘干热损伤粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setHgrssl(revList.get(j));
					break;
				case 21://霉变粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 22 列的霉变粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCornInfo.setMbl(revList.get(j));
					break;
				case 22://色泽气味
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 23 列的色泽气味长度不能超过5位！" + br;
						break;
					}
					recordCornInfo.setSzqw(revList.get(j));
					break;
				case 23://存储方式
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 24 列的存储方式长度不能超过5位！" + br;
						break;
					}
					recordCornInfo.setCcfs(revList.get(j));
					//添加到list，所有数据都没问题才一起insert数据库
					if (recordCornInfo != null) {
						cornList.add(recordCornInfo);
					}
					break;
				default :
					break;
				}
				
			}
			
		}
		if("".equals(msg)) {
			for(RecordCornInfo lists:cornList) {
				recordCornInfoMapper.insert(lists);
			}
		}
		return msg;
	}
	
	@Override
	public String importDataSoybean(List<List<String>> list, String orgId, Integer beginRow) {
		
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		List<Map<String, Object>> storeHouseList = statisticalReportMapper.getStoreHouseInfo(map);
		List<Map<String, Object>> wareHouseList = statisticalReportMapper.getWareHouseInfo(map);
		
		List<RecordSoybeanInfo> soybeanList = new ArrayList<RecordSoybeanInfo>();
		RecordSoybeanInfo recordSoybeanInfo = null;
		String msg = "", br = "<br/>";//消息
		boolean value_flag = false;
		int storehouse_id = 0;//仓房id
		
		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			recordSoybeanInfo = new RecordSoybeanInfo();
			recordSoybeanInfo.setOrgId(Integer.parseInt(orgId));
			recordSoybeanInfo.setId(UUID.randomUUID().toString());
			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
				case 0://车号
					if (ParameterUtil.isnotnull(revList.get(j))) {
						if (!ParameterUtil.checkPlateNumberFormat(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 1 列的值不符合车牌号规则！" + br;
							break;
						}
						recordSoybeanInfo.setClbh(revList.get(j));
					}
					break;
				case 1://仓房名称
					for(int n=0;n<storeHouseList.size();n++) {
						Map<String, Object> storeMap = (Map<String, Object>)storeHouseList.get(n);
						if(revList.get(j).equals(ObjectUtils.toString(storeMap.get("storehouse_name")))) {
							recordSoybeanInfo.setCfmc(revList.get(j));
							storehouse_id = Integer.parseInt(ObjectUtils.toString(storeMap.get("storehouse_id")));
							break;
						}
					}
					if ("".equals(recordSoybeanInfo.getCfmc()) || recordSoybeanInfo.getCfmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 2 列的仓房名称不存在！" + br;
						break;
					}
					break;
				case 2://货位名称
					for(int n=0;n<wareHouseList.size();n++) {
						Map<String, Object> wareMap = (Map<String, Object>)wareHouseList.get(n);
						if(storehouse_id == Integer.parseInt(ObjectUtils.toString(wareMap.get("storehouse_id")))
								&& revList.get(j).equals(ObjectUtils.toString(wareMap.get("warehouse_name")))) {
							recordSoybeanInfo.setHwmc(revList.get(j));
							storehouse_id = 0;//重置仓房id
							break;
						}
					}
					if ("".equals(recordSoybeanInfo.getHwmc()) || recordSoybeanInfo.getHwmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 3 列的货位名称不存在！" + br;
						break;
					}
					break;
				case 3://品名
					if (revList.get(j).length() > 30) {
						msg += "第 "+(beginRow+i+1)+" 行第 4 列的品名长度不能超过30！" + br;
						break;
					}
					recordSoybeanInfo.setPzmc(revList.get(j));
					break;
				case 4://生产年度
					if (!ParameterUtil.isYear(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 5 列的生产年度不是年份！" + br;
						break;
					}
					recordSoybeanInfo.setScnd(revList.get(j));
					break;
				case 5://入库日期
					if (!ParameterUtil.stringIsDate(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 6 列的入库日期格式不对！" + br;
						break;
					}
					recordSoybeanInfo.setRkrq(ParameterUtil.string2dates(revList.get(j)));
					break;
				case 6://入库数量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 7 列的入库数量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setRksl(revList.get(j));
					break;
				case 7://等级
					if (revList.get(j).length() > 10) {
						msg += "第 "+(beginRow+i+1)+" 行第 8 列的等级长度不能超过10！" + br;
						break;
					}
					recordSoybeanInfo.setDj(revList.get(j));
					break;
				case 8://水分
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 9 列的水分数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setSf(revList.get(j));
					break;
				case 9://完整粒率
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 10 列的完整粒率数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setWzll(revList.get(j));
					break;
				case 10://未熟粒率
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 11 列的未熟粒率数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setWsll(revList.get(j));
					break;
				case 11://破碎率
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 12 列的破碎率数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setPsl(revList.get(j));
					break;
				case 12://杂质总量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 13 列的杂质总量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setZzzl(revList.get(j));
					break;
				case 13://无机杂质
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 14 列的无机杂质数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setWjzz(revList.get(j));
					break;
				case 14://有机杂质
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 15 列的有机杂质数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setYjzz(revList.get(j));
					break;
				case 15://损伤粒率总量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 16 列的损伤粒率总量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setSsllzl(revList.get(j));
					break;
				case 16://热损伤粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 17 列的热损伤粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setRssl(revList.get(j));
					break;
				case 17://虫蚀粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 18 列的虫蚀粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setCsl(revList.get(j));
					break;
				case 18://病斑粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 19 列的病斑粒总量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setBbl(revList.get(j));
					break;
				case 19://生芽、涨大粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 20 列的生芽、涨大粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setSyzdl(revList.get(j));
					break;
				case 20://生霉粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 21 列的生霉粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setSml(revList.get(j));
					break;
				case 21://冻伤粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 22 列的冻伤粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setDsl(revList.get(j));
					break;
				case 22://粗脂肪含量（干基）
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 23 列的粗脂肪含量（干基）数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordSoybeanInfo.setCzfhl(revList.get(j));
					break;
				case 23://色泽气味
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 24 列的色泽气味长度不能超过5位！" + br;
						break;
					}
					recordSoybeanInfo.setSzqw(revList.get(j));
					break;
				case 24://存储方式
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 25 列的存储方式长度不能超过5位！" + br;
						break;
					}
					recordSoybeanInfo.setCcfs(revList.get(j));
					//添加到list，所有数据都没问题才一起insert数据库
					if (recordSoybeanInfo != null) {
						soybeanList.add(recordSoybeanInfo);
					}
					break;
				default :
					break;
				}
				
			}
			
		}
		if("".equals(msg)) {
			for(RecordSoybeanInfo lists:soybeanList) {
				recordSoybeanInfoMapper.insert(lists);
			}
		}
		return msg;
	}
	
	@Override
	public String importDataRice(List<List<String>> list, String orgId, Integer beginRow) {
		
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		List<Map<String, Object>> storeHouseList = statisticalReportMapper.getStoreHouseInfo(map);
		List<Map<String, Object>> wareHouseList = statisticalReportMapper.getWareHouseInfo(map);
		
		List<RecordRiceInfo> riceList = new ArrayList<RecordRiceInfo>();
		RecordRiceInfo recordRiceInfo = null;
		String msg = "", br = "<br/>";//消息
		boolean value_flag = false;
		int storehouse_id = 0;//仓房id
		
		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			recordRiceInfo = new RecordRiceInfo();
			recordRiceInfo.setOrgId(Integer.parseInt(orgId));
			recordRiceInfo.setId(UUID.randomUUID().toString());
			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
				case 0://车号
					if (ParameterUtil.isnotnull(revList.get(j))) {
						if (!ParameterUtil.checkPlateNumberFormat(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 1 列的值不符合车牌号规则！" + br;
							break;
						}
						recordRiceInfo.setClbh(revList.get(j));
					}
					break;
				case 1://仓房名称
					for(int n=0;n<storeHouseList.size();n++) {
						Map<String, Object> storeMap = (Map<String, Object>)storeHouseList.get(n);
						if(revList.get(j).equals(ObjectUtils.toString(storeMap.get("storehouse_name")))) {
							recordRiceInfo.setCfmc(revList.get(j));
							storehouse_id = Integer.parseInt(ObjectUtils.toString(storeMap.get("storehouse_id")));
							break;
						}
					}
					if ("".equals(recordRiceInfo.getCfmc()) || recordRiceInfo.getCfmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 2 列的仓房名称不存在！" + br;
						break;
					}
					break;
				case 2://货位名称
					for(int n=0;n<wareHouseList.size();n++) {
						Map<String, Object> wareMap = (Map<String, Object>)wareHouseList.get(n);
						if(storehouse_id == Integer.parseInt(ObjectUtils.toString(wareMap.get("storehouse_id")))
								&& revList.get(j).equals(ObjectUtils.toString(wareMap.get("warehouse_name")))) {
							recordRiceInfo.setHwmc(revList.get(j));
							storehouse_id = 0;//重置仓房id
							break;
						}
					}
					if ("".equals(recordRiceInfo.getHwmc()) || recordRiceInfo.getHwmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 3 列的货位名称不存在！" + br;
						break;
					}
					break;
				case 3://品名
					if (revList.get(j).length() > 30) {
						msg += "第 "+(beginRow+i+1)+" 行第 4 列的品名长度不能超过30！" + br;
						break;
					}
					recordRiceInfo.setPzmc(revList.get(j));
					break;
				case 4://生产年度
					if (!ParameterUtil.isYear(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 5 列的生产年度不是年份！" + br;
						break;
					}
					recordRiceInfo.setScnd(revList.get(j));
					break;
				case 5://入库日期
					if (!ParameterUtil.stringIsDate(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 6 列的入库日期格式不对！" + br;
						break;
					}
					recordRiceInfo.setRkrq(ParameterUtil.string2dates(revList.get(j)));
					break;
				case 6://入库数量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 7 列的入库数量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setRksl(revList.get(j));
					break;
				case 7://等级
					if (revList.get(j).length() > 10) {
						msg += "第 "+(beginRow+i+1)+" 行第 8 列的等级长度不能超过10！" + br;
						break;
					}
					recordRiceInfo.setDj(revList.get(j));
					break;
				case 8://水分
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 9 列的水分数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setSf(revList.get(j));
					break;
				case 9://出糙率
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 10 列的出糙率数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setCcl(revList.get(j));
					break;
				case 10://整精米率
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 11 列的整精米率数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setZjml(revList.get(j));
					break;
				case 11://谷外糙米
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 12 列的谷外糙米数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setGwcm(revList.get(j));
					break;
				case 12://互混率
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 13 列的互混率数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setHhl(revList.get(j));
					break;
				case 13://杂质总量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行的第 14 列的杂质总量数据不对(正数且最多三位小数)！";
						break;
					}
					recordRiceInfo.setZzzl(revList.get(j));
					break;
				case 14://无机杂质
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 15 列的无机杂质数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setWjzz(revList.get(j));
					break;
				case 15://有机杂质
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 16 列的有机杂质数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setYjzz(revList.get(j));
					break;
				case 16://不完善粒总量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 17 列的不完善粒总量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setBwslzl(revList.get(j));
					break;
				case 17://未熟粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 18 列的未熟粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setWsl(revList.get(j));
					break;
				case 18://虫蚀粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 19 列的虫蚀粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setCsl(revList.get(j));
					break;
				case 19://病斑粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 20 列的病斑粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setBbl(revList.get(j));
					break;
				case 20://生芽粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 21 列的生芽粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setSyl(revList.get(j));
					break;
				case 21://生霉粒
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 22 列的生霉粒数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setSml(revList.get(j));
					break;
				case 22://黄粒米
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 23 列的黄粒米数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordRiceInfo.setHlm(revList.get(j));
					break;
				case 23://色泽气味
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 24 列的色泽气味长度不能超过5位！" + br;
						break;
					}
					recordRiceInfo.setSzqw(revList.get(j));
					break;
				case 24://存储方式
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 25 列的存储方式长度不能超过5位！" + br;
						break;
					}
					recordRiceInfo.setCcfs(revList.get(j));
					//添加到list，所有数据都没问题才一起insert数据库
					if (recordRiceInfo != null) {
						riceList.add(recordRiceInfo);
					}
					break;
				default :
					break;
				}
				
			}
			
		}
		if("".equals(msg)) {
			for(RecordRiceInfo lists:riceList) {
				recordRiceInfoMapper.insert(lists);
			}
		}
		return msg;
	}
	
	@Override
	public String importDataCrudeOil(List<List<String>> list, String orgId, Integer beginRow) {
		
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		List<Map<String, Object>> tankList = statisticalReportMapper.getTankInfo(map);
		
		List<RecordCrudeoilInfo> crudeOilList = new ArrayList<RecordCrudeoilInfo>();
		RecordCrudeoilInfo recordCrudeoilInfo = null;
		String msg = "", br = "<br/>";//消息
		boolean value_flag = false;
		
		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			recordCrudeoilInfo = new RecordCrudeoilInfo();
			recordCrudeoilInfo.setOrgId(Integer.parseInt(orgId));
			recordCrudeoilInfo.setId(UUID.randomUUID().toString());
			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
				case 0://车号
					if (ParameterUtil.isnotnull(revList.get(j))) {
						if (!ParameterUtil.checkPlateNumberFormat(revList.get(j))) {
							msg += "第 "+(beginRow+i+1)+" 行第 1 列的值不符合车牌号规则！" + br;
							break;
						}
						recordCrudeoilInfo.setClbh(revList.get(j));
					}
					break;
				case 1://油罐名称
					for(int n=0;n<tankList.size();n++) {
						Map<String, Object> tankMap = (Map<String, Object>)tankList.get(n);
						if(revList.get(j).equals(ObjectUtils.toString(tankMap.get("storagetank_name")))) {
							recordCrudeoilInfo.setYgmc(revList.get(j));
							break;
						}
					}
					if ("".equals(recordCrudeoilInfo.getYgmc()) || recordCrudeoilInfo.getYgmc() == null) {
						msg += "第 "+(beginRow+i+1)+" 行第 2 列的油罐名称不存在！" + br;
						break;
					}
					break;
				case 2://品名
					if (revList.get(j).length() > 30) {
						msg += "第 "+(beginRow+i+1)+" 行第 3 列的品名长度不能超过30！" + br;
						break;
					}
					recordCrudeoilInfo.setPzmc(revList.get(j));
					break;
				case 3://生产年度
					if (!ParameterUtil.isYear(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 4 列的生产年度不是年份！" + br;
						break;
					}
					recordCrudeoilInfo.setScnd(revList.get(j));
					break;
				case 4://入库日期
					if (!ParameterUtil.stringIsDate(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 5 列的入库日期格式不对！" + br;
						break;
					}
					recordCrudeoilInfo.setRkrq(ParameterUtil.string2dates(revList.get(j)));
					break;
				case 5://入库数量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 6 列的入库数量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCrudeoilInfo.setRksl(revList.get(j));
					break;
				case 6://气味、滋味
					if (revList.get(j).length() > 10) {
						msg += "第 "+(beginRow+i+1)+" 行第 7 列的气味、滋味不能超过10！" + br;
						break;
					}
					recordCrudeoilInfo.setQwzw(revList.get(j));
					break;
				case 7://水分及挥发物含量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 8 列的水分及挥发物含量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCrudeoilInfo.setSfjhfwhl(revList.get(j));
					break;
				case 8://不溶性杂质含量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 9 列的不溶性杂质含量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCrudeoilInfo.setBrxzzhl(revList.get(j));
					break;
				case 9://酸价
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 10 列的酸价数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCrudeoilInfo.setSj(revList.get(j));
					break;
				case 10://过氧化值
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 11 列的过氧化值数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCrudeoilInfo.setGyhz(revList.get(j));
					break;
				case 11://溶剂残留量
					if (!ParameterUtil.isNumber(revList.get(j))) {
						msg += "第 "+(beginRow+i+1)+" 行第 12 列的溶剂残留量数据不对(正数且最多三位小数)！" + br;
						break;
					}
					recordCrudeoilInfo.setRjcll(revList.get(j));
					break;
				case 12://存储方式
					if (revList.get(j).length() > 5) {
						msg += "第 "+(beginRow+i+1)+" 行第 13 列的存储方式长度不能超过5位！" + br;
						break;
					}
					recordCrudeoilInfo.setCcfs(revList.get(j));
					//添加到list，所有数据都没问题才一起insert数据库
					if (recordCrudeoilInfo != null) {
						crudeOilList.add(recordCrudeoilInfo);
					}
					break;
				default :
					break;
				}
				
			}
			
		}
		if("".equals(msg)) {
			for(RecordCrudeoilInfo lists:crudeOilList) {
				recordCrudeoilInfoMapper.insert(lists);
			}
		}
		return msg;
	}

	@Override
	public String queryImportPzCount(HttpServletRequest request, String json, String pzlx) {

		Map<String, Object> param = objectToMap(request, json);

		String drzsl = "0";
		if (RecordUtils.TYPE_ONE.equalsIgnoreCase(pzlx)) {
			drzsl = recordWheatInfoMapper.countByConditions(param);
		} else if (RecordUtils.TYPE_TWO.equalsIgnoreCase(pzlx)) {
			drzsl = recordCornInfoMapper.countByConditions(param);
		} else if (RecordUtils.TYPE_THREE.equalsIgnoreCase(pzlx)) {
			drzsl = recordSoybeanInfoMapper.countByConditions(param);
		} else if (RecordUtils.TYPE_FOUR.equalsIgnoreCase(pzlx)) {
			drzsl = recordRiceInfoMapper.countByConditions(param);
		} else if (RecordUtils.TYPE_FIVE.equalsIgnoreCase(pzlx)) {
			drzsl = recordCrudeoilInfoMapper.countByConditions(param);
		}

		return drzsl;
	}

	/**
	 * json解析封装
	 * 
	 * @param request
	 * @param json
	 * @return
	 */
	private Map<String, Object> objectToMap(HttpServletRequest request, String json) {
		JSONObject json_object = JSONObject.parseObject(json);

		//参数对象
		Map<String, Object> param = new HashMap<String, Object>();

		//仓房ID
		String houseId = ObjectUtils.toString(json_object.get("houseId"), "");
		if (!"".equals(houseId)) {
			param.put("houseId", Integer.parseInt(houseId));
		}

		//货位ID
		String warehouseId = ObjectUtils.toString(json_object.get("warehouseId"), "");
		if (!"".equals(warehouseId)) {
			param.put("warehouseId", Integer.parseInt(warehouseId));
		}

		//油罐ID
		String tankId = ObjectUtils.toString(json_object.get("tankId"), "");
		if (!"".equals(tankId)) {
			param.put("tankId", Integer.parseInt(tankId));
		}

		//开始时间
		String startDate = ObjectUtils.toString(json_object.get("startDate"), "");
		if (!"".equals(startDate)) {
			param.put("startDate", startDate+" 00:00:00");
		}

		//结束时间
		String endDate = ObjectUtils.toString(json_object.get("endDate"), "");
		if (!"".equals(endDate)) {
			param.put("endDate", endDate+" 23:59:59");
		}

		//单位ID
		param.put("orgId", request.getSession().getAttribute("orgId"));
		return param;
	}

	@Override
	public PageInfo<Map<String, Object>> view(HttpServletRequest request, Integer pageNum, Integer pageSize, String json, String pzlx) {
		Map<String, Object> param = objectToMap(request, json);

		PageInfo<Map<String, Object>> pageInfo = null;
		List<Map<String, Object>> list = null;
		Map<String, Object> params = null;
		Map<String, Object> resultobj = null;
		try {
			if(null != pageNum && null != pageSize){
				PageHelper.startPage(pageNum, pageSize);
			}
			if (RecordUtils.TYPE_ONE.equals(pzlx)) {
				list = recordWheatInfoMapper.queryGroupSumRksl(param);
			} else if (RecordUtils.TYPE_TWO.equals(pzlx)) {
				list = recordCornInfoMapper.queryGroupSumRksl(param);
			} else if (RecordUtils.TYPE_THREE.equals(pzlx)) {
				list = recordSoybeanInfoMapper.queryGroupSumRksl(param);
			} else if (RecordUtils.TYPE_FOUR.equals(pzlx)) {
				list = recordRiceInfoMapper.queryGroupSumRksl(param);
			} else if (RecordUtils.TYPE_FIVE.equals(pzlx)) {
				list = recordCrudeoilInfoMapper.queryGroupSumRksl(param);
			}
			pageInfo = new PageInfo<Map<String, Object>>(list);
			if (null != pageInfo && pageInfo.getList().size() > 0) {
				String kcsl = "0";
				for (int i = 0; i < pageInfo.getList().size(); i++) {
					resultobj = pageInfo.getList().get(i);
					params = new HashMap<String, Object>();
					params.put("houseId", ObjectUtils.toString(resultobj.get("ch"), ""));
					params.put("warehouseId", ObjectUtils.toString(resultobj.get("hwh"), ""));
					params.put("pz", ObjectUtils.toString(resultobj.get("enumid"), ""));
					params.put("orgId", ObjectUtils.toString(param.get("orgId"), ""));
					kcsl = recordWheatInfoMapper.queryCrkQckcSum(params);
					resultobj.put("kcsl", kcsl);
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}

}
