package com.chinaitop.depot.risk.controller;

import com.chinaitop.depot.risk.model.ContentPreControlAlarm;
import com.chinaitop.depot.risk.service.ContentPreControlAlarmService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * 内控预警列表
 * @author aihua
 * @date 2022-04-16 15:06
 */
@RestController
@RequestMapping("/contentPreControlAlarm")
@Api(value = "ContentPreControlAlarmController", description = "内控预警列表-主页")
@RequiredArgsConstructor
public class ContentPreControlAlarmController {

    private final ContentPreControlAlarmService contentPreControlAlarmService;

    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询内控预警列表", notes = "查询内控预警信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
            @ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query")
    })
    public ResponseEntity<PageInfo<ContentPreControlAlarm>> listPage(Integer pageNum, Integer pageSize, Integer orgId, String startDate, String endDate){

        if (orgId == null) {
            return ResponseEntity.failed("组织机构ID不能为空！");
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        Map<String, Object> queryMap = Maps.newHashMap();
        if (StringUtils.isNotBlank(startDate)) {
            queryMap.put("startDate", ParameterUtil.string2datetime(startDate));
        }
        if (StringUtils.isNotBlank(endDate)) {
            queryMap.put("endDate", ParameterUtil.string2datetime(endDate));
        }

        queryMap.put("orgId", orgId);
        return ResponseEntity.ok(new PageInfo<>(contentPreControlAlarmService.selectListPage(queryMap)));
    }
}
