package com.chinaitop.depot.risk.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.risk.model.RiskFollow;
import com.chinaitop.depot.risk.service.RiskFollowService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * 安全隐患跟踪
 * @author aihua
 * @date 2022-04-17 09:43
 */
@RestController
@RequestMapping("/riskFollow")
@Api(value = "RiskFollowController", description = "安全隐患跟踪-主页")
@RequiredArgsConstructor
@Slf4j
public class RiskFollowController {

    private final RiskFollowService riskFollowService;

    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询安全隐患跟踪列表", notes = "查询风险管控跟踪列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public ResponseEntity<PageInfo<RiskFollow>> listPage(Integer pageNum, Integer pageSize, Integer orgId){
        if (orgId == null) {
            return ResponseEntity.failed("组织机构ID不能为空！");
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        Map<String, Object> queryMap = Maps.newHashMap();
        queryMap.put("orgId", orgId);
        List<RiskFollow> riskManagements = riskFollowService.selectListPage(queryMap);
        PageInfo<RiskFollow> pageInfo = new PageInfo<>(riskManagements);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/saveData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存安全隐患跟踪", notes = "保存安全隐患跟踪")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity saveData(String riskJson) {
        try {
            log.info("保存安全隐患跟踪saveData：" + riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                RiskFollow riskFollow = JSONObject.parseObject(riskJson, RiskFollow.class);
                riskFollowService.saveData(riskFollow);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/updateData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "更新安全隐患", notes = "更新安全隐患")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity updateData(String riskJson) {
        try {
            log.info("风险管控updateDate：" + riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                RiskFollow riskFollow = JSONObject.parseObject(riskJson, RiskFollow.class);
                if (riskFollow.getId() == null) {
                    return ResponseEntity.failed("更新数据ID不能为空！");
                }
                riskFollowService.updateDate(riskFollow);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteRisk", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据信息", notes = "根据主键id移除数据信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public ResponseEntity deleteRisk(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            riskFollowService.deleteRisk(id);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "queryById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public ResponseEntity<RiskFollow> queryById(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            return ResponseEntity.ok(riskFollowService.queryById(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
    }

}

