package com.chinaitop.depot.risk.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.risk.model.RiskManagement;
import com.chinaitop.depot.risk.service.RiskManagementService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * 风险管控ctrl
 * @author aihua
 * @date 2022-04-17 09:43
 */
@RestController
@RequestMapping("/riskManagement")
@Api(value = "RiskManagementController", description = "风险管控-主页")
@RequiredArgsConstructor
@Slf4j
public class RiskManagementController {

    private final RiskManagementService riskManagementService;

    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询风险管控", notes = "查询风险管控信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
            @ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query")
    })
    public ResponseEntity<PageInfo<RiskManagement>> listPage(Integer pageNum, Integer pageSize, Integer orgId, Integer fxlx, Integer fxfj){

        if (orgId == null) {
            return ResponseEntity.failed("组织机构ID不能为空！");
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        Map<String, Object> queryMap = Maps.newHashMap();
        if (StringUtils.isNotBlank(fxlx+"")) {
            queryMap.put("fxlx", fxlx);
        }
        if (fxfj != null ) {
            queryMap.put("fxfj", fxfj.toString());
        }
        if (StringUtils.isNotBlank(orgId+"")) {
            queryMap.put("orgId", orgId);
        }
        return ResponseEntity.ok(new PageInfo<>(riskManagementService.selectListPage(queryMap)));
    }

    @RequestMapping(value = "/saveData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存风险管控", notes = "保存风险管控")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity saveData(String riskJson) {
        try {
            log.info("风险管控saveData：" + riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                RiskManagement riskManagement = JSONObject.parseObject(riskJson, RiskManagement.class);
                riskManagementService.saveData(riskManagement);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/updateData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "更新风险管控", notes = "更新风险管控")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity updateData(String riskJson) {
        try {
            log.info("风险管控updateDate：" + riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                RiskManagement riskManagement = JSONObject.parseObject(riskJson, RiskManagement.class);
                if (riskManagement.getId() == null) {
                    return ResponseEntity.failed("更新数据ID不能为空！");
                }
                riskManagementService.updateDate(riskManagement);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteRisk", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据信息", notes = "根据主键id移除数据信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public ResponseEntity deleteRisk(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            riskManagementService.deleteRisk(id);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "queryById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public ResponseEntity<RiskManagement> queryById(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            return ResponseEntity.ok(riskManagementService.queryById(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
    }
}
