package com.chinaitop.depot.risk.controller;

import com.chinaitop.depot.feign.BasicFeignClient;
import com.chinaitop.depot.feign.BusinessFile;
import com.chinaitop.depot.risk.model.StorageSafeManageWithBLOBs;
import com.chinaitop.depot.risk.service.StorageSafeManageService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/StorageSafeManageController")
@Api(value = "StorageSafeManageController", description = "安全管理控制类")
public class StorageSafeManageController {

    private final static Logger logger = LoggerFactory.getLogger(StorageSafeManageController.class);
    @Resource
    private StorageSafeManageService storageSafeManageService;
    
    @Resource
    private BasicFeignClient basicFeignClient;
    
    
    
    
    

    @RequestMapping(value = "/getPageInfoList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询安全管理列表", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
            @ApiImplicitParam(name = "fxlx", value = "风险类型", paramType = "query"),
            @ApiImplicitParam(name = "fxfj", value = "风险分级", paramType = "query")
    })
    public PageInfo<StorageSafeManageWithBLOBs> getPageInfoList(Integer pageNum, Integer pageSize, Integer orgId,
                                                                Integer fxlx, Integer fxfj) {

        PageInfo<StorageSafeManageWithBLOBs> pageInfo = null;
        List<StorageSafeManageWithBLOBs> list = null;
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        try {
            list = storageSafeManageService.findbyConditions(orgId, fxlx, fxfj);
            pageInfo = new PageInfo<>(list);
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
        }

        return pageInfo;
    }

    @RequestMapping(value = "/getFindByPkCondition",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="按主键查询一条数据", notes = "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键唯一ID", paramType = "query")
    })
    public Map<String, Object> getFindByPkCondition(String id) {

    	Map<String, Object> modelMap = new HashMap<String, Object>();
        StorageSafeManageWithBLOBs storageSafeManageWithBLOBs = null;

        try {
            storageSafeManageWithBLOBs = storageSafeManageService.findbyPKConditions(id);
            modelMap.put("storageSafeManageWithBLOBs", storageSafeManageWithBLOBs);
            String fileType = "safeManage";
            String order = "create_time desc";
            Integer bid = Integer.valueOf(id);
            List<BusinessFile> fileList= basicFeignClient.getList(bid, fileType, order, storageSafeManageWithBLOBs.getOrgId());
            modelMap.put("fileList", fileList);
            
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
        }

        return modelMap;
    }

    @RequestMapping(value = "/saveAndUpdate",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="修改或新增数据", notes = "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "storageSafeManage", value = "数据对象JSON串", paramType = "form")
    })
    public Map<String, String> saveAndUpdate(String storageSafeManage,String fileIds, String deleteFileIds) {

        Map<String, String> map = new HashMap<>();

        try {
            ObjectMapper objectMapper = new ObjectMapper();
            StorageSafeManageWithBLOBs storageSafeManageWithBLOBs = objectMapper.readValue(storageSafeManage, StorageSafeManageWithBLOBs.class);
            storageSafeManageService.saveAndUpdate(storageSafeManageWithBLOBs,fileIds,deleteFileIds);
            map.put("msg", "操作成功！");
            map.put("status", "200");
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
            map.put("msg", "操作失败！");
            map.put("status", "500");
        }

        return map;
    }

    @RequestMapping(value = "/remove",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="删除一条数据", notes = "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键唯一ID", paramType = "form")
    })
    public Map<String, String> remove(String id,Integer orgId) {

        Map<String, String> map = new HashMap<>();

        try {
            storageSafeManageService.deleteById(id,orgId);
            map.put("msg", "操作成功！");
            map.put("status", "200");
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
            map.put("msg", "操作失败！");
            map.put("status", "500");
        }

        return map;
    }
}
