package com.chinaitop.depot.risk.controller;

import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.risk.model.ViolationWarningAlarm;
import com.chinaitop.depot.risk.service.ViolationWarningAlarmService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Maps;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

/**
 * 违规预警
 * @author fanxw
 * @date 2024-05-09 15:06
 */
@RestController
@RequestMapping("/violationWarningAlarm")
@Api(value = "ViolationWarningAlarmController", description = "违规预警-主页")
@RequiredArgsConstructor
@Slf4j
public class ViolationWarningAlarmController {

    private final ViolationWarningAlarmService violationWarningAlarmService;

    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询违规预警", notes = "查询违规预警信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
            @ApiImplicitParam(name = "violationType", value = "违规类型", paramType = "query"),
            @ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query")
    })
    public ResponseEntity<PageInfo<ViolationWarningAlarm>> listPage(Integer pageNum, Integer pageSize, Integer orgId,Integer violationType, String startDate, String endDate){

        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        Map<String, Object> queryMap = Maps.newHashMap();
        if (StringUtils.isNotBlank(startDate)) {
            queryMap.put("startDate", ParameterUtil.string2datetime(startDate));
        }
        if (StringUtils.isNotBlank(endDate)) {
            queryMap.put("endDate", ParameterUtil.string2datetime(endDate));
        }
        if (violationType != null) {
            queryMap.put("violationType", violationType);
        }
        queryMap.put("orgId", orgId);
        return ResponseEntity.ok(new PageInfo<>(violationWarningAlarmService.selectListPage(queryMap)));
    }

    @RequestMapping(value = "queryById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public ResponseEntity<ViolationWarningAlarm> queryById(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            return ResponseEntity.ok(violationWarningAlarmService.queryById(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
    }

    @SuppressWarnings("all")
	@RequestMapping(value = "/updateData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "更新违规预警", notes = "更新违规预警")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity updateData(String riskJson) {
        try {
            log.info("违规预警updateDate：{}", riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                ViolationWarningAlarm violationWarningAlarm = JSONObject.parseObject(riskJson, ViolationWarningAlarm.class);
                if (violationWarningAlarm.getId() == null) {
                    return ResponseEntity.failed("更新数据ID不能为空！");
                }

                violationWarningAlarmService.updateDate(violationWarningAlarm);

                return ResponseEntity.ok();
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }
}
