package com.chinaitop.depot.risk.service.impl;

import com.chinaitop.depot.risk.mapper.ContentPreControlAlarmMapper;
import com.chinaitop.depot.risk.mapper.ViolationWarningAlarmMapper;
import com.chinaitop.depot.risk.model.ContentPreControlAlarm;
import com.chinaitop.depot.risk.model.ViolationWarningAlarm;
import com.chinaitop.depot.risk.request.ContentPreControlAndViolationWarningAlarmReq;
import com.chinaitop.depot.risk.service.ContentPreControlAndViolationWarningAlarmService;
import com.chinaitop.depot.utils.DateUtil;
import com.chinaitop.depot.utils.ParameterUtil;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.Optional;

/**
 * 出入库调用存储内控预警和违规预警实现类
 *
 * @author aihua
 * @date 2022-04-19 16:07
 */
@Service
@RequiredArgsConstructor
public class ContentPreControlAndViolationWarningAlarmServiceImpl implements ContentPreControlAndViolationWarningAlarmService {

    private final ContentPreControlAlarmMapper contentPreControlAlarmMapper;
    private final ViolationWarningAlarmMapper violationWarningAlarmMapper;

    @Override
    public void saveData(ContentPreControlAndViolationWarningAlarmReq alarmReq)  throws Exception {
        Optional.ofNullable(alarmReq).flatMap(req -> Optional.ofNullable(req.getContentPreControlAlarm()).map(contentAlarm -> ContentPreControlAlarm.builder()
                .carNumber(contentAlarm.getCarNumber())
                .alarmType(contentAlarm.getAlarmType())
                .alarmContent(contentAlarm.getAlarmContent())
                .alarmTime(ParameterUtil.string2datetime(contentAlarm.getAlarmTime()))
                .orgId(alarmReq.getOrgId())
                .createTime(DateUtil.getNow())
                .build())).ifPresent(contentPreControlAlarmMapper::insert);
        Optional.ofNullable(alarmReq).flatMap(req -> Optional.ofNullable(req.getViolationWarningAlarm()).map(violationAlarm -> ViolationWarningAlarm.builder()
                .alarmPublishTime(ParameterUtil.string2datetime(violationAlarm.getAlarmPublishTime()))
                .violationSubjectType("单位")
                .offender(violationAlarm.getOffender())
                .violationType(violationAlarm.getViolationType())
                .involvingLibraryPoints(violationAlarm.getInvolvingLibraryPoints())
                .violationDetail(violationAlarm.getViolationDetail())
                .currentStatus(0) // 未处置
                .orgId(alarmReq.getOrgId())
                .createTime(DateUtil.getNow())
                .build())).ifPresent(violationWarningAlarmMapper::insert);
    }
}
