package com.chinaitop.depot.risk.service.impl;

import com.chinaitop.depot.risk.mapper.RiskFollowMapper;
import com.chinaitop.depot.risk.model.RiskFollow;
import com.chinaitop.depot.risk.model.RiskManagement;
import com.chinaitop.depot.risk.service.RiskFollowService;
import com.chinaitop.depot.utils.DateUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 安全隐患跟踪处理实现类
 * @author aihua
 * @date 2022-04-17 16:34
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class RiskFollowServiceImpl implements RiskFollowService {

    private final RiskFollowMapper riskFollowMapper;

    /**
     * 分页查询风险管控list
     * @param queryMap 查询条件
     * @return {@link RiskManagement} list
     */
    @Override
    public List<RiskFollow> selectListPage(Map<String, Object> queryMap) {
        return riskFollowMapper.selectListPage(queryMap);
    }

    /**
     * 新增风险管控
     * @param riskFollow 风险管控实体
     */
    @Override
    public void saveData(RiskFollow riskFollow) {
        riskFollow.setCreateTime(new Date());
        riskFollowMapper.insert(riskFollow);
    }

    /**
     * 更新风险管控
     * @param riskFollow 风险管控实体
     */
    @Override
    public void updateDate(RiskFollow riskFollow) {
        riskFollowMapper.updateById(riskFollow);
    }

    /**
     * 根据ID查询风险管控
     * @param id 主键ID
     * @return 风险管控
     */
    @Override
    public RiskFollow queryById(Integer id) {
        return riskFollowMapper.selectById(id);
    }

    /**
     * 删除风险管控
     * @param id 主键ID
     */
    @Override
    public void deleteRisk(Integer id) {
        riskFollowMapper.deleteById(id);
    }
}
