package com.chinaitop.depot.risk.service.impl;

import com.chinaitop.depot.risk.mapper.RiskManagementMapper;
import com.chinaitop.depot.risk.model.RiskManagement;
import com.chinaitop.depot.risk.service.RiskManagementService;
import com.chinaitop.depot.utils.DateUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 风险管控实现类
 * @author aihua
 * @date 2022-04-17 09:48
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class RiskManagementServiceImpl implements RiskManagementService {

    private final RiskManagementMapper riskManagementMapper;

    /**
     * 分页查询风险管控list
     * @param queryMap 查询条件
     * @return {@link RiskManagement} list
     */
    @Override
    public List<RiskManagement> selectListPage(Map<String, Object> queryMap) {
        return riskManagementMapper.selectListPage(queryMap);
    }

    /**
     * 新增风险管控
     * @param riskManagement 风险管控实体
     */
    @Override
    public void saveData(RiskManagement riskManagement) {
        riskManagement.setCreateTime(new Date());
        riskManagementMapper.insert(riskManagement);
    }

    /**
     * 更新风险管控
     * @param riskManagement 风险管控实体
     */
    @Override
    public void updateDate(RiskManagement riskManagement) {
        riskManagement.setModifyTime(new Date());
        riskManagementMapper.updateById(riskManagement);
    }

    /**
     * 根据ID查询风险管控
     * @param id 主键ID
     * @return 风险管控
     */
    @Override
    public RiskManagement queryById(Integer id) {
        return riskManagementMapper.selectById(id);
    }

    /**
     * 删除风险管控
     * @param id 主键ID
     */
    @Override
    public void deleteRisk(Integer id) {
        riskManagementMapper.deleteById(id);
    }
}
