package com.chinaitop.depot.risk.service.impl;

import com.chinaitop.depot.feign.BasicFeignClient;
import com.chinaitop.depot.risk.mapper.StorageSafeManageMapper;
import com.chinaitop.depot.risk.model.StorageSafeManageExample;
import com.chinaitop.depot.risk.model.StorageSafeManageWithBLOBs;
import com.chinaitop.depot.risk.service.StorageSafeManageService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class StorageSafeManageServiceImpl implements StorageSafeManageService {

    @Resource
    private StorageSafeManageMapper storageSafeManageMapper;
    
    @Resource
    private BasicFeignClient basicFeignClient;
    
    @Resource
    private RestTemplate restTemplate;

    @Value("${jsgjjsjUrl}")
    private String jsgjjsjUrl;
    
    @Override
    public List<StorageSafeManageWithBLOBs> findbyConditions(Integer orgId, Integer fxlx, Integer fxfj) throws Exception {

        StorageSafeManageExample example = new StorageSafeManageExample();
        StorageSafeManageExample.Criteria criteria = example.createCriteria();
        if (null != orgId)
            criteria.andOrgIdEqualTo(orgId);
        if (null != fxlx)
            criteria.andFxlxEqualTo(fxlx);
        if (null != fxfj)
            criteria.andFxfjEqualTo(fxfj);
        example.setOrderByClause(" createtime desc");
        List<StorageSafeManageWithBLOBs> list = storageSafeManageMapper.selectByExampleWithBLOBs(example);

        return list;
    }

    @Override
    public StorageSafeManageWithBLOBs findbyPKConditions(String id) throws Exception {

        StorageSafeManageWithBLOBs storageSafeManage = storageSafeManageMapper.selectByPrimaryKey(id);
        return storageSafeManage;
    }

    @Override
    public void saveAndUpdate(StorageSafeManageWithBLOBs storageSafeManage,String fileIds, String deleteFileIds) throws Exception {

        //获取当前时间：yyyy-MM-dd HH:mm:ss
        String date = ParameterUtil.getSysDateTime();
        
        //生成风险点编码
        Map<String, Object> map = storageSafeManageMapper.getBasicEnumObj(storageSafeManage.getCounty());
        String xzqhdm = map.get("gbcode").toString();
        storageSafeManage.setFxdbm(getFxdbm(xzqhdm, date));
        if (storageSafeManage.getId() != null) {
           //修改
            storageSafeManage.setCzbz("u");
            storageSafeManage.setZhgxsj(date);
            storageSafeManageMapper.updateByPrimaryKeyWithBLOBs(storageSafeManage);
            //附件
            basicFeignClient.updateFile(fileIds, storageSafeManage.getId(),"safeManage");
            basicFeignClient.deleteFile(deleteFileIds);
            
            this.gjjjk(storageSafeManage.getId()+"", storageSafeManage.getOrgId(), "u");
            
        } else {
        	//新增
            //String uuid = UUID.randomUUID().toString().replace("-", "");
    		String[] idArray = date.split(" ");
    		String[] rq = idArray[0].split("-");
    		String[] sj = idArray[1].split(":");
    		
    		String uid = rq[1]+rq[2]+sj[0]+sj[1]+sj[2];
    		int id = Integer.valueOf(uid);
            storageSafeManage.setId(id);
            storageSafeManage.setCreatetime(ParameterUtil.string2datetime(date));
            storageSafeManage.setCzbz("i");
            storageSafeManage.setZhgxsj(date);
            storageSafeManageMapper.insert(storageSafeManage);
            //附件
            basicFeignClient.updateFile(fileIds, id,"safeManage");
            this.gjjjk(id+"", storageSafeManage.getOrgId(), "i");
        }
       
    }

    @Override
    public void deleteById(String id,Integer orgId) throws Exception {
        storageSafeManageMapper.deleteByPrimaryKey(id);
        this.gjjjk(id, orgId, "d");

    }

    /**
     * 生成风险点编码
     * 6位行政区划代码+8位风险识别日期（YYYYMMDD）+4位风险顺序号（如:0001）
     * @param xzqhdm 行政区划代码
     * @param date 当前时间格式：yyyy-MM-dd HH:mm:ss
     * @return
     */
    private String getFxdbm(String xzqhdm, String date) {
        String fxdbm = "";


        StringBuffer sbf = new StringBuffer(100);
        //6位行政区划代码
        sbf.append(xzqhdm);
        //8位风险识别日期（YYYYMMDD）
        sbf.append(date.substring(0, 10).replace("-", "").trim());
        //4位风险顺序号(为避免重复，这里取分和秒)
        sbf.append(date.substring(date.length()-5, date.length()).replace(":", "").trim());

        fxdbm = sbf.toString();

        return fxdbm;
    }
    
    /**
   	 * 国家局数据
   	 */
       public void gjjjk(String id, Integer orgId,String czbz) {
           
         String tableName = "ODS_UP_AQGLXXJK";
  		/**
           * restTemplate调用
           */
          //String url = "http://localhost:9022/recPublish/sendMessage";//
          //发送post请求，并打印结果，以String类型接收响应结果JSON字符串
  		
        MultiValueMap<String, Object> sendMap = new LinkedMultiValueMap<>();
  		sendMap.add("tableName", tableName);
  		sendMap.add("czbz", czbz);
  		sendMap.add("ywId", id);
  		sendMap.add("orgId", orgId);

          restTemplate.postForObject(jsgjjsjUrl, sendMap, String.class);
       }
}
