package com.chinaitop.depot.safeProduce.common.controller;

import com.chinaitop.depot.safeProduce.common.util.ZipUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.zip.ZipOutputStream;

@RestController
@RequestMapping("")
@SuppressWarnings("all")
public class DownloadController {

    @Value("${web.upload-path}")
	private String uploadPath;

	/**
	 * 文件下载
	 *
	 * @param filePath
	 * @param response
	 * @throws IOException
	 */
	@RequestMapping("/download")
	public void download(String filePath, HttpServletRequest request, String type, String originalFileName, HttpServletResponse response) throws IOException {
	    String rootPath = "";
		// 判断windows(指定盘符 D:/upload)和linux(根路径下 /upload)
	    if (uploadPath.indexOf(":") != -1){
			rootPath = StringUtils.substringBeforeLast(uploadPath, "/");
		}
		// path是指欲下载的文件的路径。
		File file = new File(rootPath + filePath);
		// 取得文件名。
		String fileName = file.getName();
		String fileType = fileName.substring(fileName.lastIndexOf(".")+1);
		// 以流的形式下载文件。
		response.setHeader("content-type", "application/octet-stream");
        if("pdf".equals(fileType)){
           response.setContentType("application/pdf;charset=GBK");
        }else if("xls".equals(fileType) || "xlsx".equals(fileType)){
           response.setContentType("application/msexcel;charset=GBK");
        }else if("doc".equals(fileType) || "docx".equals(fileType)){
           response.setContentType("application/msword;charset=GBK");
        }else if("txt".equals(fileType)){
        	response.setContentType("text/plain;charset=GBK");
        }else {
        	response.setContentType("application/octet-stream");
	    }
		response.setHeader("Content-Disposition", "attachment;filename=" +
				new String(fileName.getBytes("GB2312"), "ISO8859-1"));
		byte[] buff = new byte[1024];
		BufferedInputStream bis = null;
		OutputStream os = null;
		try {
			os = response.getOutputStream();
			bis = new BufferedInputStream(new FileInputStream(file));
			int i = bis.read(buff);
			while (i != -1) {
				os.write(buff, 0, buff.length);
				os.flush();
				i = bis.read(buff);
			}
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (bis != null) {
				try {
					bis.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
	}

	/**
     * 打包压缩下载文件
     */
    @RequestMapping(value = "/downLoadZipFile")
    public void downLoadZipFile(HttpServletRequest request, HttpServletResponse response, String fileName, String filePaths) throws IOException{
    	// 服务器路径
		String rootPath = "";
		// 判断windows(指定盘符 D:/upload)和linux(根路径下 /upload)
		if (uploadPath.indexOf(":") != -1){
			rootPath = StringUtils.substringBeforeLast(uploadPath, "/");
		}
		response.setContentType("APPLICATION/OCTET-STREAM");
        response.setHeader("Content-Disposition","attachment; filename="+
        		new String(fileName.getBytes("GB2312"), "ISO8859-1") + ".zip");
        ZipOutputStream out = new ZipOutputStream(response.getOutputStream());
        try {
            for(String filePath : filePaths.split(";")){
                ZipUtils.doCompress(rootPath+filePath, out);
            }
            response.flushBuffer();
        } catch (Exception e) {
            e.printStackTrace();
        }finally{
            out.close();
        }
    }

}
