package com.chinaitop.depot.safeProduce.controller;

import com.chinaitop.depot.safeProduce.model.StorageSafeAccidentManage;
import com.chinaitop.depot.safeProduce.model.StorageSafeAccidentManageExample;
import com.chinaitop.depot.safeProduce.service.StorageSafeAccidentManageService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 安全事故管理
 * @create 2018-10-16 11:17
 */
@RestController
@SuppressWarnings("all")
@RequestMapping(value = "/safeAccidentManage")
public class StorageSafeAccidentManageController {

    @Resource
    private StorageSafeAccidentManageService accidentManageService;

    /**
     * 分页获取
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "安全生产通知列表", notes = "安全生产通知列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<StorageSafeAccidentManage> listPage(Integer pageNum, Integer pageSize, Integer houseId, Integer orgId) {
        StorageSafeAccidentManageExample example = new StorageSafeAccidentManageExample();
        StorageSafeAccidentManageExample.Criteria criteria = example.createCriteria();
        if (houseId != null)
            criteria.andHouseIdEqualTo(houseId);
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        if (orgId != null)
            criteria.andOrgIdEqualTo(orgId);
        example.setOrderByClause("reported_time DESC");
        List<StorageSafeAccidentManage> list = accidentManageService.queryByExample(example);
        PageInfo<StorageSafeAccidentManage> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 保存数据，包括新增和修改
     *
     * @param safeProduceAccidentJson
     * @return
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    @ApiOperation(value = "保存数据，包括新增和修改", notes = "保存,新增,修改信息")
    @ApiImplicitParam(name = "safeProduceAccidentJson", value = "json数据", paramType = "query", dataType = "string")
    public Map<String, Object> save(String safeProduceAccidentJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            StorageSafeAccidentManage AccidentManage = mapper.readValue(safeProduceAccidentJson, StorageSafeAccidentManage.class);
            if (AccidentManage.getId() == null) {
                accidentManageService.add(AccidentManage);
            } else {
//                accidentManageService.update(AccidentManage);
            }
            modelMap.put("status", "success");
        } catch (IOException e) {
            e.printStackTrace();
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 根据id获取数据
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.GET)
    @ApiOperation(value = "根据编号获取数据", notes = "单条信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public StorageSafeAccidentManage edit(Integer id) {
        StorageSafeAccidentManage AccidentManage = new StorageSafeAccidentManage();
        if (id != null) {
            AccidentManage = accidentManageService.findById(id);
        }
        return AccidentManage;
    }


}
