package com.chinaitop.depot.safeProduce.controller;

import com.chinaitop.depot.safeProduce.common.util.DeleteFileUtils;
import com.chinaitop.depot.safeProduce.model.StorageSafeProduce;
import com.chinaitop.depot.safeProduce.model.StorageSafeProduceExample;
import com.chinaitop.depot.safeProduce.service.StorageSafeProduceService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 安全生产:
 * 安全生产管理制度
 * 安全生产应急预案
 * 安全管理生产责任
 *
 * @author sunhongbing
 * @Date 2017/10/19
 */
@RestController
@SuppressWarnings("all")
@RequestMapping(value = "/safeProduce")
@Api(value = "StorageSafeProduceController", description = "安全生产类")
public class StorageSafeProduceController {
    @Resource
    private StorageSafeProduceService safeProduceService;

    /**
     * 分页获取
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "安全生产列表", notes = "安全生产列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "type", value = "安全生产类型 0:管理制度 1:应急预案 2:管理责任书", paramType = "query"),
            @ApiImplicitParam(name = "fileName", value = "文件名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public PageInfo<StorageSafeProduce> listPage(Integer pageNum, Integer pageSize, String type, String fileName, Integer orgId) {
        StorageSafeProduceExample example = new StorageSafeProduceExample();
        StorageSafeProduceExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(fileName)) {
            criteria.andFileNameLike("%" + fileName + "%");
        }
        if (StringUtils.isNotBlank(type)) {
            criteria.andTypeEqualTo(type);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        if (orgId != null) {
            criteria.andOrgIdEqualTo(orgId);
        }
        example.setOrderByClause("operation_time DESC");
        List<StorageSafeProduce> list = safeProduceService.queryByExample(example);
        PageInfo<StorageSafeProduce> pageInfo = new PageInfo<StorageSafeProduce>(list);
        return pageInfo;
    }

    /**
     * 根据编号获取数据
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.GET)
    @ApiOperation(value = "根据编号获取数据", notes = "单条安全生产信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public StorageSafeProduce edit(Integer id) {
        StorageSafeProduce storageSafeProduce = new StorageSafeProduce();
        if (id != null) {
            storageSafeProduce = safeProduceService.findById(id);
        }
        return storageSafeProduce;
    }

    /**
     * 保存数据，包括新增和修改
     *
     * @param storageSafeProduceJson
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    @ApiOperation(value = "保存数据，包括新增和修改", notes = "保存,新增,修改安全生产信息")
    @ApiImplicitParam(name = "storageSafeProduceJson", value = "安全生产json数据", paramType = "query", dataType = "string")
    public Map<String, Object> save(String storageSafeProduceJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            StorageSafeProduce storageSafeProduce = mapper.readValue(storageSafeProduceJson, StorageSafeProduce.class);
            // 创建时间
            storageSafeProduce.setOperationTime(new Date());
            if (storageSafeProduce.getId() == null) {
                safeProduceService.add(storageSafeProduce);
            } else {
                safeProduceService.update(storageSafeProduce);
            }
            modelMap.put("status", "success");
        } catch (IOException e) {
            e.printStackTrace();
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 根据编号删除数据
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/remove", method = RequestMethod.POST)
    @ApiOperation(value = "根据编号删除数据", notes = "删除安全生产信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "信息id", paramType = "query"),
            @ApiImplicitParam(name = "fileUrl", value = "文件路径", paramType = "query")
    })
    public Map<String, Object> remove(Integer id, String fileUrl) {
        Map<String, Object> modelMap = new HashMap<>();
        if (null != id) {
            int remove = safeProduceService.remove(id, fileUrl);
            if (remove > 0) {
                modelMap.put("status", "success");
                return modelMap;
            }
        }
        modelMap.put("status", "error");
        return modelMap;
    }

    /**
     * 根据编号删除数据
     *
     * @param fileUrl
     * @return
     */
    @Value("${web.upload-path}")
    private String uploadPath;

    @RequestMapping(value = "/deleteOnlyFile", method = RequestMethod.GET)
    @ApiOperation(value = "自动删除单个文件", notes = "删除安全生产单个文件")
    @ApiImplicitParam(name = "fileUrl", value = "文件路径", paramType = "query")
    public void deleteOnlyFile(String fileUrl) {
        if (StringUtils.isNotBlank(fileUrl)) {
            DeleteFileUtils.deleteFiles(fileUrl, uploadPath);
        }
    }

}
