package com.chinaitop.depot.safeProduce.controller;

import com.chinaitop.depot.safeProduce.model.StorageSafeProduceNotify;
import com.chinaitop.depot.safeProduce.model.StorageSafeProduceNotifyExample;
import com.chinaitop.depot.safeProduce.service.StorageSafeProduceNotifyService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 安全生产通告
 * @create 2018-10-12 11:11
 */

@RestController
@SuppressWarnings("all")
@RequestMapping(value = "/safeProduceNotify")
@Api(value = "StorageSafeProduceNotifyController", description = "安全生产通知类")
public class StorageSafeProduceNotifyController {

    @Resource
    private StorageSafeProduceNotifyService safeProduceNotifyService;

    /**
     * 分页获取
     */
    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "安全生产通知列表", notes = "安全生产通知列表信息, 支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query", defaultValue = "1"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query", defaultValue = "10"),
            @ApiImplicitParam(name = "fileName", value = "文件名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public PageInfo<StorageSafeProduceNotify> listPage(Integer pageNum, Integer pageSize, String fileName, Integer orgId){
        StorageSafeProduceNotifyExample example = new StorageSafeProduceNotifyExample();
        StorageSafeProduceNotifyExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(fileName)) {
            criteria.andFileNameLike("%" + fileName + "%");
        }
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        if (orgId != null) {
            criteria.andOrgIdEqualTo(orgId);
        }
        example.setOrderByClause("operation_time DESC");
        List<StorageSafeProduceNotify> list=safeProduceNotifyService.queryByExample(example);
        PageInfo<StorageSafeProduceNotify> pageInfo =new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 保存数据，包括新增和修改
     * @param safeProduceNotifyJson
     * @return
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    @ApiOperation(value = "保存数据，包括新增和修改", notes = "保存,新增,修改信息")
    @ApiImplicitParam(name = "safeProduceNotifyJson", value = "安全生产通知json数据", paramType = "query", dataType = "string")
    public Map<String, Object> save(String safeProduceNotifyJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            StorageSafeProduceNotify safeProduceNotify = mapper.readValue(safeProduceNotifyJson, StorageSafeProduceNotify.class);
            if (safeProduceNotify.getId() == null) {
                safeProduceNotifyService.add(safeProduceNotify);
            } else {
                safeProduceNotifyService.update(safeProduceNotify);
            }
            modelMap.put("status", "success");
        } catch (IOException e) {
            e.printStackTrace();
            modelMap.put("status", "error");
        }
        return modelMap;
    }

    /**
     * 根据id获取数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/edit", method = RequestMethod.GET)
    @ApiOperation(value = "根据编号获取数据", notes = "单条信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public StorageSafeProduceNotify edit(Integer id) {
        StorageSafeProduceNotify safeProduceNotify = new StorageSafeProduceNotify();
        if (id != null) {
            safeProduceNotify = safeProduceNotifyService.findById(id);
        }
        return safeProduceNotify;
    }

    /**
     * 根据id删除数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/remove", method = RequestMethod.POST)
    @ApiOperation(value = "根据编号删除数据", notes = "删除信息")
    @ApiImplicitParam(name = "id", value = "信息id", paramType = "query")
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> modelMap = new HashMap<>();
        if (null != id){
            int result = safeProduceNotifyService.remove(id);
            if (result > 0) {
                modelMap.put("status", "success");
            } else {
                modelMap.put("status", "error");
            }
        } else {
            modelMap.put("status", "error");
        }
        return modelMap;
    }

}
