package com.chinaitop.depot.sptData.controller;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.sptData.model.SptDataVO;
import com.chinaitop.depot.sptData.model.StorageDewingWarning;
import com.chinaitop.depot.sptData.model.StorageHumidityWarning;
import com.chinaitop.depot.sptData.model.StorageTemperatureWarning;
import com.chinaitop.depot.sptData.model.StorageTemperaturepointWarning;
import com.chinaitop.depot.sptData.service.SptService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RequestMapping(value="/spt")
@Api(tags="市平台接口")
@RestController
@Slf4j
public class SptController {

	@Resource
	private SptService sptService;
	
	@RequestMapping(value="/getSxtgzsList", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台摄像头故障数列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqmc", value = "组织机构名称", paramType = "query"),
        @ApiImplicitParam(name = "bjsj", value = "报警日期", paramType = "query")
	})
	public SptDataVO getSxtgzsList(Integer pageNum, Integer pageSize, String kqmc, String bjsj) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getSxtgzsList(pageNum, pageSize, kqmc, bjsj);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	@RequestMapping(value="/getCwdgzsList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取市平台测温点故障数列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区国标编码", paramType = "query"),
        @ApiImplicitParam(name = "bjsj", value = "报警日期", paramType = "query")
	})
	public PageInfo<StorageTemperaturepointWarning> getCwdgzsList(Integer pageNum, Integer pageSize, String kqbm, String bjsj) {
		PageInfo<StorageTemperaturepointWarning> pageInfo = null;
		try {
			if (pageNum != null && pageSize != null) {
	            PageHelper.startPage(pageNum, pageSize);
	        }
			List<StorageTemperaturepointWarning> list = sptService.getCwdgzsList(pageNum, pageSize, kqbm, bjsj);
			pageInfo = new PageInfo<>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return pageInfo;
	}
	
	@RequestMapping(value="/getTempAlarmList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="温度报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "组织id", paramType = "query"),
        @ApiImplicitParam(name = "searchEndDate", value = "结束时间", paramType = "query"),
        @ApiImplicitParam(name = "searchStartDate", value = "开始时间", paramType = "query")
	})
	public PageInfo<StorageTemperatureWarning> getTempAlarmList(Integer pageNum, Integer pageSize, String kqbm,String cfbm,
			String searchStartDate, String searchEndDate) {
		
		PageInfo<StorageTemperatureWarning> pageInfo = null;
		List<StorageTemperatureWarning> list = null;
		try {
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = sptService.getTempAlarmList(kqbm , cfbm,searchStartDate,searchEndDate);
			pageInfo = new PageInfo<StorageTemperatureWarning>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return pageInfo;
		
	}
	
	@RequestMapping(value="/getJybgcqyjList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取市平台检验报告超期预警列表", notes = "支持分页,支持仓房模糊查询")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区标准编码", paramType = "query"),
        @ApiImplicitParam(name = "cfmc", value = "仓房名称", paramType = "query")
	})
	public SptDataVO getJybgcqyjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getJybgcqyjList(pageNum, pageSize, kqbm, cfmc);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}

	@RequestMapping(value="/getJkqyjxxList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取市平台架空期预警信息列表", notes = "支持分页,支持仓房模糊查询")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区标准编码", paramType = "query"),
        @ApiImplicitParam(name = "xybh", value = "协议编号", paramType = "query"),
        @ApiImplicitParam(name = "mxpz", value = "明细品种编码", paramType = "query")
	})
	public SptDataVO getJkqyjxxList(Integer pageNum, Integer pageSize, String kqbm, String xybh, String mxpz) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getJkqyjxxList(pageNum, pageSize, kqbm, xybh, mxpz);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}

	@RequestMapping(value="/getZqlyjxxList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取市平台转圈粮预警列表", notes = "支持分页,支持仓房模糊查询")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区标准编码", paramType = "query"),
        @ApiImplicitParam(name = "cphm", value = "车牌号码", paramType = "query"),
        @ApiImplicitParam(name = "mxpz", value = "明细品种编码", paramType = "query"),
        @ApiImplicitParam(name = "startTime", value = "出入库开始时间", paramType = "query"),
        @ApiImplicitParam(name = "endTime", value = "出入库结束时间", paramType = "query")
	})
	public SptDataVO getZqlyjxxList(Integer pageNum, Integer pageSize, String kqbm, String cphm, String mxpz, String startTime, String endTime) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getZqlyjxxList(pageNum, pageSize, kqbm, cphm, mxpz, startTime, endTime);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	
	@RequestMapping(value="/getHumidnessAlarmList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="湿度报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "组织id", paramType = "query"),
        @ApiImplicitParam(name = "searchEndDate", value = "结束时间", paramType = "query"),
        @ApiImplicitParam(name = "searchStartDate", value = "开始时间", paramType = "query")
	})
	public PageInfo<StorageHumidityWarning> getHumidnessAlarmList(Integer pageNum, Integer pageSize, String kqbm,String cfbm,
			String searchStartDate, String searchEndDate) {
		
		PageInfo<StorageHumidityWarning> pageInfo = null;
		List<StorageHumidityWarning> list = null;
		try {
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = sptService.getHumidnessAlarmList(kqbm , cfbm,searchStartDate,searchEndDate);
			pageInfo = new PageInfo<StorageHumidityWarning>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return pageInfo;
		
	}
	
	
	@RequestMapping(value="/getDewingAlarmList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="湿度报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "组织id", paramType = "query"),
        @ApiImplicitParam(name = "searchEndDate", value = "结束时间", paramType = "query"),
        @ApiImplicitParam(name = "searchStartDate", value = "开始时间", paramType = "query")
	})
	public PageInfo<StorageDewingWarning> getDewingAlarmList(Integer pageNum, Integer pageSize, String kqbm,String cfbm,
			String searchStartDate, String searchEndDate) {
		
		PageInfo<StorageDewingWarning> pageInfo = null;
		List<StorageDewingWarning> list = null;
		try {
			if (null != pageNum && null != pageSize) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = sptService.getDewingAlarmList(kqbm , cfbm,searchStartDate,searchEndDate);
			pageInfo = new PageInfo<StorageDewingWarning>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return pageInfo;
		
	}
	
	@RequestMapping(value="/getkccxbjList", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台库存超限报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区编码", paramType = "query"),
        @ApiImplicitParam(name = "cfmc", value = "仓房名称", paramType = "query")
	})
	public SptDataVO getkccxbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getkccxbjList(pageNum, pageSize, kqbm, cfmc);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	@RequestMapping(value="/getkckcbjList", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台库存空仓报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区编码", paramType = "query"),
        @ApiImplicitParam(name = "cfmc", value = "仓房名称", paramType = "query"),
        @ApiImplicitParam(name = "cfzt", value = "仓房状态 1:空仓 2:半仓", paramType = "query")
	})
	public SptDataVO getkckcbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc, Integer cfzt) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getkckcbjList(pageNum, pageSize, kqbm, cfmc, cfzt);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	@RequestMapping(value="/getCccxbjList", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台存储超限报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kqbm", value = "库区编码", paramType = "query"),
        @ApiImplicitParam(name = "cfmc", value = "仓房名称", paramType = "query"),
        @ApiImplicitParam(name = "pzbm", value = "品种编码", paramType = "query")
	})
	public SptDataVO getCccxbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc, String pzbm) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getCccxbjList(pageNum, pageSize, kqbm, cfmc, pzbm);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	@RequestMapping(value="/getDsfzjList", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台第三方质检列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "pageType", value = "分页类型", paramType = "query"),
        //@ApiImplicitParam(name = "kqmc", value = "库区名称", paramType = "query"),
        @ApiImplicitParam(name = "cfmc", value = "库区编码", paramType = "query"),
        @ApiImplicitParam(name = "cfmc", value = "仓房名称", paramType = "query"),
        @ApiImplicitParam(name = "pzmc", value = "品种名称", paramType = "query"),
        @ApiImplicitParam(name = "wtsbh", value = "委托书编号", paramType = "query"),
        @ApiImplicitParam(name = "wtkssj", value = "委托起始时间", paramType = "query"),
        @ApiImplicitParam(name = "wtjssj", value = "委托结束时间", paramType = "query")
	})
	public SptDataVO getDsfzjList(Integer pageNum, Integer pageSize, Integer pageType, String kqmc, 
			String cfmc, String pzmc, String wtsbh, String wtkssj, String wtjssj) {
		//{"applySubTypeName":"","applyNumber":"","houseName":"","applyDateBegin":"","applyDateEnd":"","pageType":2,"pageSize":10,"pageNum":1}
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getDsfzjList(pageNum, pageSize,pageType, kqmc, cfmc, pzmc,wtsbh,wtkssj,wtjssj);
			
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	
	@RequestMapping(value="/getDsfzjById", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台第三方质检列详情", notes = "获取市平台第三方质检列详情")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "fid", value = "第三方质检id", paramType = "query")
	})
	public SptDataVO getDsfzjById(Long fid) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getDsfzjById(fid);
			
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	@RequestMapping(value="/getZcfzList", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台财务报表列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "type", value = "类型", paramType = "query"),
        @ApiImplicitParam(name = "kqdm", value = "库区代码", paramType = "query"),
        @ApiImplicitParam(name = "bbsj", value = "填报期数", paramType = "query")
	})
	public SptDataVO getZcfzList(Integer pageNum, Integer pageSize, String type, String dwdm,String bbsj) {
			
		
		//{"type":"asset","kqdm":"91120223104141086Y001","pageNum":1,"pageSize":10,"total":6,"page":1,"bbsj":"202402"}
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getZcfzList(pageNum, pageSize,type, dwdm,bbsj);
			
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	@RequestMapping(value="/getZcfzById", method = RequestMethod.GET)
	@ApiOperation(value="获取市平台财务报表详情", notes = "获取市平台财务报表详情")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "财务报表id", paramType = "query")
	})
	public SptDataVO getZcfzById(String id) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getZcfzById(id);
			
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
	
	
	
	@RequestMapping(value="/getSptSpjktjList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取市平台视频监控统计列表", notes = "")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "datas", value = "参数集", paramType = "query"),
        @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public SptDataVO getSptSpjktjList(Integer pageNum, Integer pageSize, String datas, String orgId) {
		SptDataVO sptDataVO = null;
		try {
			sptDataVO = sptService.getSptSpjktjList(pageNum, pageSize, datas, orgId);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return sptDataVO;
	}
}
