package com.chinaitop.depot.sptData.service;

import java.io.IOException;
import java.util.List;

import com.chinaitop.depot.sptData.model.SptDataVO;
import com.chinaitop.depot.sptData.model.StorageDewingWarning;
import com.chinaitop.depot.sptData.model.StorageHumidityWarning;
import com.chinaitop.depot.sptData.model.StorageTemperatureWarning;
import com.chinaitop.depot.sptData.model.StorageTemperaturepointWarning;

public interface SptService {

	/**
	 * 获取市平台摄像头故障数接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqmc 库区名称
	 * @param bjsj 报警时间
	 * @return
	 * @throws Exception
	 */
	SptDataVO getSxtgzsList(Integer pageNum, Integer pageSize, String kqmc, String bjsj) throws Exception;

	/**
	 * 获取市平台测温点故障数接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区国标编码
	 * @param bjsj 报警时间
	 * @return
	 * @throws Exception
	 */
	List<StorageTemperaturepointWarning> getCwdgzsList(Integer pageNum, Integer pageSize, String kqbm, String bjsj) throws Exception;

	/**
	 * 温度预警
	 * @param kqbm 库区国标编码
	 * @param cfbm 仓房编码
	 * @param searchStartDate 起始时间
	 * @param searchEndDate 结束时间
	 * @return
	 * @throws Exception
	 */
	List<StorageTemperatureWarning> getTempAlarmList(String kqbm,String cfbm,
			String searchStartDate, String searchEndDate) throws Exception;
	
	/**
	 * 获取市平台检验报告超期预警接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区标准编码
	 * @param cfmc 仓房名称
	 * @return
	 * @throws Exception
	 */
	SptDataVO getJybgcqyjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc) throws Exception;
	
	/**
	 * 获取市平台查架空期预警信息接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区标准编码
	 * @param xybh 协议编号
	 * @param mxpz 品种
	 * @return
	 * @throws Exception
	 */
	SptDataVO getJkqyjxxList(Integer pageNum, Integer pageSize, String kqbm, String xybh, String mxpz) throws Exception;

	/**
	 * 获取市平台转圈粮预警信息接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区标准编码
	 * @param cphm 车牌号码
	 * @param mxpz 明细品种
	 * @param startTime 开始时间
	 * @param endTime 结束时间
	 * @return
	 * @throws Exception
	 */
	SptDataVO getZqlyjxxList(Integer pageNum, Integer pageSize, String kqbm, String cphm, String mxpz, String startTime, String endTime) throws Exception;

	/**
	 * 湿度预警
	 * @param kqbm 库区国标编码
	 * @param cfbm 仓房编码
	 * @param searchStartDate 起始时间
	 * @param searchEndDate 结束时间
	 * @return
	 * @throws Exception
	 */
	List<StorageHumidityWarning> getHumidnessAlarmList(String kqbm, String cfbm, String searchStartDate,
			String searchEndDate) throws Exception;

	/**
	 * 结露预警
	 * @param kqbm 库区国标编码
	 * @param cfbm 仓房编码
	 * @param searchStartDate 起始时间
	 * @param searchEndDate 结束时间
	 * @return
	 * @throws Exception
	 */
	List<StorageDewingWarning> getDewingAlarmList(String kqbm, String cfbm, String searchStartDate,
			String searchEndDate) throws Exception;

	/**
	 * 获取市平台库存超限报警接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区标准编码
	 * @param cfmc 仓房名称
	 * @return
	 * @throws Exception
	 */
	SptDataVO getkccxbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc) throws Exception;

	/**
	 * 获取市平台库存空仓报警接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区标准编码
	 * @param cfmc 仓房名称
	 * @param cfzt 仓房状态 1:空仓 2:半仓
	 * @return
	 * @throws Exception
	 */
	SptDataVO getkckcbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc, Integer cfzt) throws Exception;

	/**
	 * 获取市平台存储超限报警接口数据
	 * @param pageNum
	 * @param pageSize
	 * @param kqbm 库区标准编码
	 * @param cfmc 仓房名称
	 * @param pzbm 品种编码
	 * @return
	 * @throws Exception
	 */
	SptDataVO getCccxbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc, String pzbm) throws Exception;

	
	
	
	/**
	 * 获取市平台第三方质检列表接口
	 * @param pageNum
	 * @param pageSize
	 * @param pageType
	 * @param kqmc
	 * @param cfmc
	 * @param pzmc
	 * @param wtsbh
	 * @param wtkssj
	 * @param wtjssj
	 * @return
	 * @throws Exception
	 */
	SptDataVO getDsfzjList(Integer pageNum, Integer pageSize, Integer pageType, String kqmc, String cfmc, String pzmc,
			String wtsbh, String wtkssj, String wtjssj) throws Exception;

	/**
	 * 第三方质检详情
	 * @param fid
	 * @return
	 */
	SptDataVO getDsfzjById(Long fid) throws Exception;

	
	
	SptDataVO getZcfzList(Integer pageNum, Integer pageSize, String type, String dwdm, String bbsj) throws Exception;

	SptDataVO getZcfzById(String id) throws Exception;
	
	
	/**
	 * 查询市平台视频监控统计列表
	 * @param pageNum
	 * @param pageSize
	 * @param datas
	 * @param orgId
	 * @return
	 * @throws Exception 
	 */
	SptDataVO getSptSpjktjList(Integer pageNum, Integer pageSize, String datas, String orgId) throws Exception;
}
