package com.chinaitop.depot.sptData.service.impl;

import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.sptData.mapper.SptDataMapper;
import com.chinaitop.depot.sptData.mapper.StorageDewingWarningMapper;
import com.chinaitop.depot.sptData.mapper.StorageHumidityWarningMapper;
import com.chinaitop.depot.sptData.mapper.StorageTemperatureWarningMapper;
import com.chinaitop.depot.sptData.mapper.StorageTemperaturepointWarningMapper;
import com.chinaitop.depot.sptData.model.SptDataVO;
import com.chinaitop.depot.sptData.model.StorageDewingWarning;
import com.chinaitop.depot.sptData.model.StorageHumidityWarning;
import com.chinaitop.depot.sptData.model.StorageTemperatureWarning;
import com.chinaitop.depot.sptData.model.StorageTemperatureWarningExample;
import com.chinaitop.depot.sptData.model.StorageTemperaturepointWarning;
import com.chinaitop.depot.sptData.model.StorageTemperaturepointWarningExample;
import com.chinaitop.depot.sptData.service.SptService;
import com.chinaitop.depot.sptData.utils.PageHelperUtils;
import com.chinaitop.depot.system.service.SysCodeService;
import com.chinaitop.depot.utils.DateUtil;
import com.chinaitop.depot.utils.OkHttpUtil;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;

@Service
@SuppressWarnings("all")
public class SptServiceImpl implements SptService {

	@Resource
	private SysCodeService sysCodeService;

	@Resource
	private StorageTemperaturepointWarningMapper storageTemperaturepointWarningMapper;
	
	@Resource
	private StorageTemperatureWarningMapper storageTemperatureWarningMapper;
	
	@Resource
	private StorageHumidityWarningMapper storageHumidityWarningMapper;
	
	@Resource
	private StorageDewingWarningMapper storageDewingWarningMapper;

	@Resource
	private SptDataMapper sptDataMapper;
	

	@Override
	public SptDataVO getSxtgzsList(Integer pageNum, Integer pageSize, String kqmc, String bjsj)
			throws Exception {

		String path = sysCodeService.getSVal(10, "sxtgzs");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("/").append(pageNum).append("/").append(pageSize);
		if (StringUtils.isNotBlank(kqmc)) {
			sbf.append("?").append("kqmc=").append(kqmc);
		}
		if (StringUtils.isNotBlank(bjsj)) {
			sbf.append("&bjsj=").append(bjsj);
		}
		String result_data = OkHttpUtil.get(sbf.toString());
		ObjectMapper mapper = new ObjectMapper();
		SptDataVO sptDataVO = mapper.readValue(result_data, SptDataVO.class);

		return sptDataVO;
	}

	@Override
	public List<StorageTemperaturepointWarning> getCwdgzsList(Integer pageNum, Integer pageSize, String kqbm, String bjsj)
			throws Exception {

		StorageTemperaturepointWarningExample example = new StorageTemperaturepointWarningExample();
		StorageTemperaturepointWarningExample.Criteria criteria = example.createCriteria();

		if (StringUtils.isNotBlank(kqbm)) {
			criteria.andKqbmEqualTo(kqbm);
		}

		if (StringUtils.isNotBlank(bjsj)) {
			Date sTime = ParameterUtil.string2datetime(bjsj+" 00:00:00");
			Date eTime = ParameterUtil.string2datetime(bjsj+" 23:59:59");
			criteria.andBjsjBetween(sTime, eTime);
		}

		example.setOrderByClause("bjsj desc");

		List<StorageTemperaturepointWarning> list = storageTemperaturepointWarningMapper.selectByExample(example);

		return list;
	}

	@Override
	public List<StorageTemperatureWarning> getTempAlarmList(String kqbm,String cfbm,
			String searchStartDate, String searchEndDate)  throws Exception {
		
		
		Map<String,Object> map = new HashMap<String,Object>();
		if(kqbm != null && kqbm != ""){
			map.put("kqbm", kqbm);
		}
		if(cfbm != null && cfbm != ""){
			map.put("cfbm", cfbm);
		}
		if(searchStartDate != null && searchStartDate != ""){
			map.put("searchStartDate", searchStartDate+" 00:00:00");
		}
		if(searchEndDate != null && searchEndDate != ""){
			map.put("searchEndDate", searchEndDate+" 23:59:59");
		}
		
		List<StorageTemperatureWarning> list = storageTemperatureWarningMapper.selectTempAlarmList(map);
		return list;
		
	}
	
	@Override
	public SptDataVO getJybgcqyjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc) throws Exception {

		String path = sysCodeService.getSVal(10, "jybgcqy");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("/").append(1).append("/").append(10000);

		StringBuffer param = new StringBuffer();

		if (StringUtils.isNotBlank(kqbm)) {
			param.append("&kqbm=").append(kqbm);
		}
		if (StringUtils.isNotBlank(cfmc)) {
			param.append("&cfmc=").append(cfmc);
		}
		String result_data = OkHttpUtil.postXWFU(sbf.toString(), param.toString());
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			//处理分页数据
			datas = PageHelperUtils.pageHelper(datas, pageNum, pageSize);
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}

		return sptDataVO;
	}

	@Override
	public SptDataVO getJkqyjxxList(Integer pageNum, Integer pageSize, String kqbm, String xybh, String mxpz)
			throws Exception {

		String path = sysCodeService.getSVal(10, "jkqyj");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("/").append(1).append("/").append(10000);

		JSONObject param = new JSONObject();
		if (StringUtils.isNotBlank(kqbm)) {
			param.put("kqbm", kqbm);
		}
		if (StringUtils.isNotBlank(xybh)) {
			param.put("xybh", xybh);
		}
		if (StringUtils.isNotBlank(mxpz)) {
			param.put("pzbm", mxpz);
		}
		String result_data = OkHttpUtil.postJSON(sbf.toString(), param.toString());
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			//处理分页数据
			datas = PageHelperUtils.pageHelper(datas, pageNum, pageSize);
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}

		return sptDataVO;
	}

	@Override
	public SptDataVO getZqlyjxxList(Integer pageNum, Integer pageSize, String kqbm, String cphm, String mxpz,
			String startTime, String endTime) throws Exception {

		String path = sysCodeService.getSVal(10, "zqlyj");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("/").append(1).append("/").append(10000);

		JSONObject param = new JSONObject();
		if (StringUtils.isNotBlank(kqbm)) {
			param.put("kqbm", kqbm);
		}
		if (StringUtils.isNotBlank(cphm)) {
			param.put("cch", cphm);
		}
		if (StringUtils.isNotBlank(mxpz)) {
			param.put("pzbm", mxpz);
		}
		if (StringUtils.isNotBlank(startTime)) {
			param.put("startDate", startTime);
		}
		if (StringUtils.isNotBlank(endTime)) {
			param.put("endDate", endTime);
		}
		String result_data = OkHttpUtil.postJSON(sbf.toString(), param.toString());
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			//处理分页数据
			datas = PageHelperUtils.pageHelper(datas, pageNum, pageSize);
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}

		return sptDataVO;
	}

	@Override
	public List<StorageHumidityWarning> getHumidnessAlarmList(String kqbm, String cfbm, String searchStartDate,
			String searchEndDate) {

		Map<String,Object> map = new HashMap<String,Object>();
		if(kqbm != null && kqbm != ""){
			map.put("kqbm", kqbm);
		}
		if(cfbm != null && cfbm != ""){
			map.put("cfbm", cfbm);
		}
		if(searchStartDate != null && searchStartDate != ""){
			map.put("searchStartDate", searchStartDate+" 00:00:00");
		}
		if(searchEndDate != null && searchEndDate != ""){
			map.put("searchEndDate", searchEndDate+" 23:59:59");
		}
		
		List<StorageHumidityWarning> list = storageHumidityWarningMapper.selectHumidnessAlarmList(map);
		
		return list;
	}

	@Override
	public List<StorageDewingWarning> getDewingAlarmList(String kqbm, String cfbm, String searchStartDate,
			String searchEndDate) {
		Map<String,Object> map = new HashMap<String,Object>();
		if(kqbm != null && kqbm != ""){
			map.put("kqbm", kqbm);
		}
		if(cfbm != null && cfbm != ""){
			map.put("cfbm", cfbm);
		}
		if(searchStartDate != null && searchStartDate != ""){
			map.put("searchStartDate", searchStartDate+" 00:00:00");
		}
		if(searchEndDate != null && searchEndDate != ""){
			map.put("searchEndDate", searchEndDate+" 23:59:59");
		}
		
		List<StorageDewingWarning> list = storageDewingWarningMapper.selectDewingAlarmList(map);
		return list;
	}

	@Override
	public SptDataVO getkccxbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc) throws Exception {
		String path = sysCodeService.getSVal(10, "kccxbj");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("?pageNum=").append(pageNum).append("&pageSize=").append(pageSize);
		if (StringUtils.isNotBlank(kqbm)) {
			sbf.append("&kqbm=").append(kqbm);
		}
		if (StringUtils.isNotBlank(cfmc)) {
			sbf.append("&cfmc=").append(cfmc);
		}
		String result_data = OkHttpUtil.get(sbf.toString());
		ObjectMapper mapper = new ObjectMapper();
		SptDataVO sptDataVO = mapper.readValue(result_data, SptDataVO.class);

		return sptDataVO;
	}

	@Override
	public SptDataVO getkckcbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc, Integer cfzt)
			throws Exception {
		String path = sysCodeService.getSVal(10, "kckcbj");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("?pageNum=").append(pageNum).append("&pageSize=").append(pageSize);
		if (StringUtils.isNotBlank(kqbm)) {
			sbf.append("&kqbm=").append(kqbm);
		}
		if (StringUtils.isNotBlank(cfmc)) {
			sbf.append("&cfmc=").append(cfmc);
		}
		if (null != cfzt) {
			sbf.append("&cfzt=").append(cfzt);
		}
		String result_data = OkHttpUtil.get(sbf.toString());
		ObjectMapper mapper = new ObjectMapper();
		SptDataVO sptDataVO = mapper.readValue(result_data, SptDataVO.class);

		return sptDataVO;
	}

	@Override
	public SptDataVO getCccxbjList(Integer pageNum, Integer pageSize, String kqbm, String cfmc, String pzbm)
			throws Exception {
		String path = sysCodeService.getSVal(10, "cccxbj");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("?pageNum=").append(pageNum).append("&pageSize=").append(pageSize);
		if (StringUtils.isNotBlank(kqbm)) {
			sbf.append("&kqbm=").append(kqbm);
		}
		if (StringUtils.isNotBlank(cfmc)) {
			sbf.append("&cfmc=").append(cfmc);
		}
		if (StringUtils.isNotBlank(pzbm)) {
			sbf.append("&pzbm=").append(pzbm);
		}
		String result_data = OkHttpUtil.get(sbf.toString());
		ObjectMapper mapper = new ObjectMapper();
		SptDataVO sptDataVO = mapper.readValue(result_data, SptDataVO.class);

		return sptDataVO;
	}

	@Override
	public SptDataVO getDsfzjList(Integer pageNum, Integer pageSize, Integer pageType, String kqmc, String cfmc,
			String pzmc, String wtsbh, String wtkssj, String wtjssj) throws Exception {
		String path = sysCodeService.getSVal(10, "dsfzjlb");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("?pageNum=").append(pageNum).append("&pageSize=").append(pageSize).append("&pageType=").append(pageType);
		
		JSONObject param = new JSONObject();
		if (StringUtils.isNotBlank(wtsbh)) {//委托书编号
			param.put("entrustNum", wtsbh);
		}
		if (StringUtils.isNotBlank(pzmc)) {//委托品种
			param.put("applySubTypeName", pzmc);
		}
		if (StringUtils.isNotBlank(cfmc)) {//仓房名称
			param.put("houseName", cfmc);
		}
		if (StringUtils.isNotBlank(wtkssj)) {//委托开始时间
			param.put("entrustDateBegin", wtkssj);
		}
		if (StringUtils.isNotBlank(wtjssj)) {//委托结束时间
			param.put("entrustDateEnd", wtjssj);
		}
		if (StringUtils.isNotBlank(kqmc)) {//库区名称
			param.put("beInspectOrgName", kqmc);
		}
		
		//调用登录接口 获取token
		String token = sptToken();

		String result_data = OkHttpUtil.postJSONToken(sbf.toString(), param.toString(),token);
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			//处理分页数据
			datas = PageHelperUtils.pageHelper(datas, pageNum, pageSize);
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}
		

		return sptDataVO;
	}

	@Override
	public SptDataVO getDsfzjById(Long fid) throws Exception {
		String path = sysCodeService.getSVal(10, "dsfzjxq");
		StringBuffer sbf = new StringBuffer(50);
		sbf.append(path).append("/").append(fid);
		
		String result_data = OkHttpUtil.get(sbf.toString());
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}
		
		return sptDataVO;
	}

	@Override
	public SptDataVO getZcfzList(Integer pageNum, Integer pageSize, String type, String dwdm, String bbsj) throws Exception {

		String path = sysCodeService.getSVal(10, "cwbblb");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("/").append(type).append("/").append("page").append("/").append(pageNum).append("/").append(pageSize);

		JSONObject param = new JSONObject();
		if (StringUtils.isNotBlank(dwdm)) {//单位代码
			param.put("dwdm", dwdm);
		}
		if (StringUtils.isNotBlank(bbsj)) {//填报期数
			param.put("bbsj", bbsj);
		}

		String result_data = OkHttpUtil.postJSON(sbf.toString(),param.toString());
		
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			//处理分页数据
			//datas = PageHelperUtils.pageHelper(datas, pageNum, pageSize);
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}
		return sptDataVO;
	
	}

	@Override
	public SptDataVO getZcfzById(String id) throws Exception {
		// TODO Auto-generated method stub
		String path = sysCodeService.getSVal(10, "cwbbxq");
		StringBuffer sbf = new StringBuffer(50);
		sbf.append(path).append("/").append(id);
		
		String result_data = OkHttpUtil.get(sbf.toString());
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String status = datasAll.getString("status");
		SptDataVO sptDataVO = new SptDataVO();
		
		if ("ERROR".equals(status)) {
			sptDataVO.setMsg(datasAll.getString("msg"));
			sptDataVO.setCode("500");
		} else {
			String datas = datasAll.getString("data");
			sptDataVO.setData(JSONObject.parseObject(datas));
			sptDataVO.setCode("200");
		}
		
		return sptDataVO;
	}

	@Override
	public SptDataVO getSptSpjktjList(Integer pageNum, Integer pageSize, String datas, String orgId) throws Exception {
		
		//通过库区编码查询市平台的企业机构代码,如：LS001074002
		String qyjgdm = sptDataMapper.getQyjgdm(orgId);

		JSONObject object = JSONObject.parseObject(datas);
		object.put("orgCode", qyjgdm);//用新的值覆盖原来的值

		String path = sysCodeService.getSVal(10, "spjktj");
		StringBuffer sbf = new StringBuffer(50);
		if (null == pageNum) {
			pageNum = 1;
		}
		if (null == pageSize) {
			pageSize = 10;
		}
		sbf.append(path).append("?pageNo=1&pageSize=10000");
		String result_data = OkHttpUtil.postJSON(sbf.toString(), object.toString());
		JSONObject datasAll = JSONObject.parseObject(result_data);
		String data = datasAll.getString("data");
		JSONObject json_data = JSONObject.parseObject(data);
		json_data.put("items", json_data.getString("list"));
		datas = PageHelperUtils.pageHelper(json_data.toString(), pageNum, pageSize);
		SptDataVO sptDataVO = new SptDataVO();
		
		//处理分页数据
		sptDataVO.setData(JSONObject.parseObject(datas));
		sptDataVO.setCode(datasAll.getString("code"));
		sptDataVO.setMsg(datasAll.getString("msg"));

		return sptDataVO;
	}

	public String sptToken() throws Exception {
		String pathLogin = sysCodeService.getSVal(10, "sptdl");//获取市平台登录的链接

		//拼接市平台登录URL
		StringBuffer sbfLogin = new StringBuffer(50);
		sbfLogin.append(pathLogin).append("/").append(1).append("/").append("cbl").append("/").append("Lscbj@1234");
		JSONObject param1 = new JSONObject();
	    param1.put("sign", "1");
	    param1.put("username", "cbl");
		param1.put("password", "Lscbj@1234");

		//请求并获取token
		String result_data1 = OkHttpUtil.postJSON(sbfLogin.toString(),param1.toString());
		JSONObject datasAll1 = JSONObject.parseObject(result_data1);
		String token = datasAll1.getJSONObject("data").getString("token");

		return token;
	}
}
