package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.storage.model.StorageFestivalbeforeCheck;
import com.chinaitop.depot.storage.model.StorageFestivalbeforeCheckExample;
import com.chinaitop.depot.storage.service.StorageFestivalbeforeCheckService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2018/1/24
 * 节前安全检查
 */
@RestController
@SuppressWarnings("all")
@RequestMapping(value = "/festivalbeforeCheck")
@Api(value= "StorageFestivalbeforeCheckController", description = "节前安全检查控制类")
public class StorageFestivalbeforeCheckController {
    @Resource
    private StorageFestivalbeforeCheckService festivalbeforeCheckService;

    
    /**
     * 分页获取
     * @throws Exception 
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="查询节前安全检查", notes = "查询节前安全检查列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query")
    })
    public PageInfo<StorageFestivalbeforeCheck> listPage(HttpServletRequest request, Integer pageNum, Integer pageSize, String houseId, String searchStartDate, String searchEndDate) throws Exception{
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        //查询条件
        Map<String, Object> mapQuery = new HashMap<>();
        if (StringUtils.isNotBlank(houseId))
            mapQuery.put("houseId", Integer.valueOf(houseId));
        if (StringUtils.isNotBlank(searchStartDate))
            mapQuery.put("starDate", ParameterUtil.string2datetime(searchStartDate+" 00:00:00"));
        if (StringUtils.isNotBlank(searchEndDate))
            mapQuery.put("endDate", ParameterUtil.string2datetime(searchEndDate+" 23:59:59"));
        if (null != orgId)
            mapQuery.put("orgId", orgId);
        if (pageNum!=null && pageSize!=null)
            PageHelper.startPage(pageNum, pageSize);
        List<StorageFestivalbeforeCheck> list = festivalbeforeCheckService.queryByFestivalbeforeCheck(mapQuery);
        PageInfo<StorageFestivalbeforeCheck> pageInfo = new PageInfo<StorageFestivalbeforeCheck>(list);
        return pageInfo;
    }

    /**
     * 新增和修改的数据进行保存
     * @param festivalbeforeJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改数据", notes = "新增/修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "festivalbeforeJson", value = "JSON数据对象", paramType = "form"),
    })
    public Map<String, Object> save(String festivalbeforeJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageFestivalbeforeCheck festivalbefore = null;
        try {
            festivalbefore = (StorageFestivalbeforeCheck)mapper.readValue(festivalbeforeJson, StorageFestivalbeforeCheck.class);
            festivalbeforeCheckService.save(festivalbefore);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取节前检查信息ById", notes = "获取节前检查信息ById")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public StorageFestivalbeforeCheck loadDataById(int id){
        return festivalbeforeCheckService.loadDataById(id);
    }
    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据", notes = "根据主键id移除数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        if (null != id) {
            festivalbeforeCheckService.remove(id);
            retMap.put("msg","success");
        } else {
            retMap.put("msg","error");
        }
        return retMap;
    }
}
