package com.chinaitop.depot.storage.controller;

import com.chinaitop.depot.storage.model.StorageFoodothercheck;
import com.chinaitop.depot.storage.model.StorageFoodothercheckExample;
import com.chinaitop.depot.storage.service.StorageFoodothercheckService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author sunhongbing
 * @Date 2017/10/22
 * 粮情检查管理中其他检查
 */
@RestController
@RequestMapping(value={"/foodotherCheck"})
@Api(value= "StorageFoodotherCheckController", description = "粮情检查管理中其他检查控制类")
public class StorageFoodotherCheckController {
    @Resource
    private StorageFoodothercheckService foodotherCheckService;

    /**
     * 分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询其他检查", notes = "查询其他检查信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query")
    })
    public PageInfo<StorageFoodothercheck> listPage(HttpServletRequest request, Integer pageNum, Integer pageSize, Integer houseId, String searchStartDate, String searchEndDate){
        // 获取组织id
        Integer orgId = (Integer) request.getSession().getAttribute("orgId");
        //查询条件
        Map<String, Object> mapQuery = new HashMap<>();
        if (ParameterUtil.isnotnull(houseId))
            mapQuery.put("houseId", houseId);
        if(ParameterUtil.isnotnull(searchStartDate))
            mapQuery.put("starDate", searchStartDate);
        if(ParameterUtil.isnotnull(searchEndDate))
            mapQuery.put("endDate", searchEndDate);
        if (null != orgId)
            mapQuery.put("orgId", orgId);
        if(pageNum !=null &&pageSize != null )
            PageHelper.startPage(pageNum, pageSize);
        List<StorageFoodothercheck> list = foodotherCheckService.queryByFoodotherCheck(mapQuery);
        PageInfo<StorageFoodothercheck> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 新增和修改的数据进行保存
     * @param foodotherCheckJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="新增数据", notes = "新增数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "foodotherCheckJson", value = "JSON数据对象", paramType = "form"),
    })
    public Map<String, Object> save(String foodotherCheckJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageFoodothercheck foodotherCheck = null;
        try {
            foodotherCheck = (StorageFoodothercheck)mapper.readValue(foodotherCheckJson, StorageFoodothercheck.class);
            foodotherCheckService.save(foodotherCheck);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public StorageFoodothercheck loadDataById(int id){
        return foodotherCheckService.loadDataById(id);
    }

    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据信息", notes = "根据主键id移除数据信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        if (null != id) {
            foodotherCheckService.remove(id);
            retMap.put("msg","success");
        } else {
            retMap.put("msg","error");
        }
        return retMap;
    }

}
