package com.chinaitop.depot.storage.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.storage.model.StorageThreetempcheck;
import com.chinaitop.depot.storage.service.StorageThreetempcheckService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * @author sunhongbing
 * @Date 2017/10/22
 * 粮情检查管理中三温检查
 */
@RestController
@RequestMapping(value = {"/threetempCheck"})
@Api(value = "StorageThreetempCheckController", description = "粮情检查管理中三温检查控制类")
public class StorageThreetempCheckController {
    @Resource
    private StorageThreetempcheckService threetempCheckService;

    /**
     * 分页获取 从智能仓房获取数据
     */
    @RequestMapping(value = "/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询三温检查", notes = "查询三温检查信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "机构id", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "开始日期", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "结束日期", paramType = "query")
    })
    public PageInfo<Map<String, Object>> listPage(Integer pageNum, Integer pageSize, String houseCode, String searchStartDate, String searchEndDate, Integer orgId) {
        // 查询条件map
        Map<String, Object> map = new HashMap<>();
        // 仓房编码
        if (ParameterUtil.isnotnull(houseCode))
            map.put("storehouse", houseCode);
        // 查询开始时间
        if (StringUtils.isNotBlank(searchStartDate))
            map.put("startDate", ParameterUtil.string2datetime(searchStartDate + " 00:00:00"));
        // 查询结束时间
        if (StringUtils.isNotBlank(searchEndDate))
            map.put("endDate", ParameterUtil.string2datetime(searchEndDate + " 23:59:59"));
        if (null != orgId)
            map.put("orgId", orgId);
        // 分页参数
        if (pageNum != null && pageSize != null)
            PageHelper.startPage(pageNum, pageSize);
        // 获取智能仓房三温数据
        List<Map<String, Object>> list = threetempCheckService.getThreeTempData(map);
        PageInfo<Map<String, Object>> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 根据id加载对应数据
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "获取费用ById", notes = "获取费用ById")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public StorageThreetempcheck loadDataById(int id) {
        return threetempCheckService.loadDataById(id);
    }

    /**
     * 根据主键id移除数据
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "根据主键id移除数据", notes = "根据主键id移除数据信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> retMap = new HashMap<String, Object>();
        if (null != id) {
            threetempCheckService.remove(id);
            retMap.put("msg", "success");
        } else {
            retMap.put("msg", "error");
        }
        return retMap;
    }

    /**
     * 三温图 数据 智能仓房获取数据
     * 查询当前仓房所在同一天(00到24点的数据)
     */
    @RequestMapping(value = "/chartData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "三温图 数据", notes = "查询当前仓房所在同一天(00到24点的数据)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "checkDate", value = "检查日期", paramType = "query")
    })
    public List<Map<String, Object>> chartData(String houseId, String checkDate, String orgId) {
        Map<String, Object> map = new HashMap<>();
        if (StringUtils.isNotBlank(houseId))
            map.put("storehouse", houseId);
        if (StringUtils.isNotBlank(checkDate)) {
            // 开始时间前推三天
            Date startDate = new Date((ParameterUtil.string2datetime(checkDate + " 00:00:00").getTime() / 1000 - 3600 * 24 * 2) * 1000);
            map.put("startDate", startDate);
            map.put("endDate", ParameterUtil.string2datetime(checkDate + " 23:59:59"));
        }
        if (StringUtils.isNotBlank(orgId)) {
            map.put("orgId", orgId);
        }
        List<Map<String, Object>> list = threetempCheckService.getThreeTempData(map);
        return list;
    }

    /**
     * 查询周粮情分析
     *
     * @param map
     * @return
     */
    @RequestMapping(value = "/editTwo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询周粮情分析", notes = "查询一条周粮情分析数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "数据集合", paramType = "query")
    })
    public Map<String, Object> editTwo(String map, Integer weekParams) {

        JSONObject jsonMap = JSON.parseObject(map, JSONObject.class);

        if (jsonMap.size() == 0) {
            return null;
        }

        Map<String, Object> threeTempMap = new HashMap<>();
        /* 参数对象 */
        Map<String, Object> parementMap = new HashMap<>();
        if (StringUtils.isNotBlank(jsonMap.getString("houseId")))
            parementMap.put("storehouse", jsonMap.getString("houseId"));
        if (StringUtils.isNotBlank(jsonMap.getString("startDate"))) {
            parementMap.put("startDate", ParameterUtil.string2date(jsonMap.getString("startDate") + " 00:00:00"));
        }
        if (StringUtils.isNotBlank(jsonMap.getString("endDate"))) {
            parementMap.put("endDate", ParameterUtil.string2date(jsonMap.getString("endDate") + " 23:59:59"));
        }
        if (null != weekParams) {
            parementMap.put("weekParams", weekParams); //用于周粮情的判断，以区分智能仓房的三温检查
        }
        parementMap.put("orders", " time asc");
        List<Map<String, Object>> list = threetempCheckService.getThreeTempData(parementMap);


//        StorageThreetempcheckExample example = new StorageThreetempcheckExample();
//        StorageThreetempcheckExample.Criteria criteria = example.createCriteria();
//        criteria.andHouseIdEqualTo(Integer.parseInt(jsonMap.getString("houseId")));
//        criteria.andCheckDateGreaterThanOrEqualTo(ParameterUtil.string2date(jsonMap.getString("startDate") + " 00:00:00"));
//        criteria.andCheckDateLessThanOrEqualTo(ParameterUtil.string2date(jsonMap.getString("endDate") + " 23:59:59"));
//        criteria.andOrgIdEqualTo(Integer.parseInt(jsonMap.getString("orgId")));
//        example.setOrderByClause("check_date asc");
//
//        List<StorageThreetempcheck> threeTempList = threetempCheckService.selectByExample(example);

        threeTempMap.put("threeTempCheckList", list);

        return threeTempMap;
    }

    /**
     * 查询月粮情分析
     *
     * @param threeTempJson
     * @return
     */
    @RequestMapping(value = "/monthEditTwo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询月粮情分析", notes = "查询一条月粮情分析数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "数据集合", paramType = "query")
    })
    public Map<String, Object> monthEditTwo(String threeTempJson) {

        if (threeTempJson.length() == 0) {
            return null;
        }

        Map<String, Object> threeTempMap = new HashMap<>();
        List<Map<String, Object>> list = new ArrayList<Map<String, Object>>();


        List<JSONObject> array = JSON.parseArray(threeTempJson, JSONObject.class);
        for (JSONObject obj : array) {
//            StorageThreetempcheckExample example = new StorageThreetempcheckExample();
//            StorageThreetempcheckExample.Criteria criteria = example.createCriteria();
//            criteria.andHouseIdEqualTo(Integer.parseInt(obj.getString("houseId")));
//            criteria.andCheckDateGreaterThanOrEqualTo(ParameterUtil.string2datetime(obj.getString("startDate") + " 00:00:00"));
//            criteria.andCheckDateLessThanOrEqualTo(ParameterUtil.string2datetime(obj.getString("endDate") + " 23:59:59"));
//            criteria.andOrgIdEqualTo(Integer.parseInt(obj.getString("orgId")));
//            example.setOrderByClause("check_date asc");
//
//            List<StorageThreetempcheck> threeTempList = threetempCheckService.selectByExample(example);

            /* 参数对象 */
            Map<String, Object> parementMap = new HashMap<>();
            if (StringUtils.isNotBlank(obj.getString("houseId")))
                parementMap.put("storehouse", obj.getString("houseId"));
            if (StringUtils.isNotBlank(obj.getString("startDate"))) {
                parementMap.put("startDate", ParameterUtil.string2date(obj.getString("startDate") + " 00:00:00"));
            }
            if (StringUtils.isNotBlank(obj.getString("endDate"))) {
                parementMap.put("endDate", ParameterUtil.string2date(obj.getString("endDate") + " 23:59:59"));
            }
            parementMap.put("orders", " time asc");
            List<Map<String, Object>> threeTempList = threetempCheckService.getThreeTempData(parementMap);
            list.add(threeTempList.get(0));
        }

        if (null == list || list.size() == 0) {
            list = new ArrayList<Map<String, Object>>();
        }

        threeTempMap.put("threeTempCheckList", list);

        return threeTempMap;
    }
}
