package com.chinaitop.depot.storage.service.impl;

import com.chinaitop.depot.storage.mapper.StorageGrainDisposalMapper;
import com.chinaitop.depot.storage.model.StorageGrainDisposal;
import com.chinaitop.depot.storage.model.StorageGrainDisposalView;
import com.chinaitop.depot.storage.service.StorageGrainDisposalService;
import com.chinaitop.depot.utils.DateUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 粮情处置实现类
 * @author aihua
 * @date 2022-04-17 14:40
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class StorageGrainDisposalServiceImpl implements StorageGrainDisposalService {
    private final StorageGrainDisposalMapper storageGrainDisposalMapper;

    /**
     * 查询粮情处置分页
     * @param queryMap 查询条件
     * @return {@link StorageGrainDisposalView} list
     */
    @Override
    public List<StorageGrainDisposalView> selectListPage(Map<String, Object> queryMap) {
        return storageGrainDisposalMapper.selectListPage(queryMap);
    }

    /**
     * 保存数据
     * @param storageGrainDisposal 粮情处置对象
     */
    @Override
    public void saveData(StorageGrainDisposal storageGrainDisposal) {
        storageGrainDisposal.setCreateTime(DateUtil.getNow());
        storageGrainDisposalMapper.saveData(storageGrainDisposal);
    }

    /**
     * 更新粮情处置
     * @param storageGrainDisposal 更新对象
     */
    @Override
    public void updateDate(StorageGrainDisposal storageGrainDisposal) {
        storageGrainDisposal.setModifyTime(DateUtil.getNow());
        storageGrainDisposalMapper.updateDate(storageGrainDisposal);
    }

    /**
     * 删除粮情处置
     * @param id 主键ID
     */
    @Override
    public void deleteById(Integer id) {
        storageGrainDisposalMapper.deleteById(id);
    }

    /**
     * 根据ID查询详情
     * @param id 主键ID
     * @return {@link StorageGrainDisposal} 信息
     */
    @Override
    public StorageGrainDisposal queryById(Integer id) {
        return storageGrainDisposalMapper.queryById(id);
    }
}
