package com.chinaitop.depot.warningAndAlarm.controller;

import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.chinaitop.depot.warningAndAlarm.model.StorageJkqWarning;
import com.chinaitop.depot.warningAndAlarm.model.StorageRotationWarning;
import com.chinaitop.depot.warningAndAlarm.model.StorageRotationWarningWithBLOBs;
import com.chinaitop.depot.warningAndAlarm.service.YjbjService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RequestMapping(value="/yjbj")
@Api(value= "YjBjController", description="预警报警功能控制类")
@RestController
@Slf4j
@SuppressWarnings("all")
public class YjBjController {

	@Resource
	private YjbjService yjbjService;

	@RequestMapping(value="/getLhyjPageInfoList", method = RequestMethod.GET)
	@ApiOperation(value="轮换预警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "orgId", value = "库ID", paramType = "query"),
        @ApiImplicitParam(name = "ch", value = "仓房ID", paramType = "query"),
        @ApiImplicitParam(name = "hwh", value = "货位ID", paramType = "query"),
        @ApiImplicitParam(name = "lspz", value = "粮食品种ID", paramType = "query")
	})
	public ResponseEntity<PageInfo<StorageRotationWarning>> getLhyjPageInfoList(Integer pageNum, Integer pageSize, Integer orgId, Integer ch, Integer hwh, Integer lspz) {
		PageInfo<StorageRotationWarning> pageInfo = null;
		try {
			if (pageNum != null && pageSize != null) {
	            PageHelper.startPage(pageNum, pageSize);
	        }
			List<StorageRotationWarning> list = yjbjService.queryLhyjList(orgId, ch, hwh, lspz);
			pageInfo = new PageInfo<>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return ResponseEntity.ok(pageInfo);
	}

	@RequestMapping(value="/getYlwlPageInfoList", method = RequestMethod.GET)
	@ApiOperation(value="应轮未轮报警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "orgId", value = "库ID", paramType = "query"),
        @ApiImplicitParam(name = "ch", value = "仓房ID", paramType = "query"),
        @ApiImplicitParam(name = "hwh", value = "货位ID", paramType = "query"),
        @ApiImplicitParam(name = "lspz", value = "粮食品种ID", paramType = "query"),
        @ApiImplicitParam(name = "rksj", value = "入库时间", paramType = "query")
	})
	public ResponseEntity<PageInfo<StorageRotationWarning>> getYlwlPageInfoList(Integer pageNum, Integer pageSize, Integer orgId, Integer ch, Integer hwh, Integer lspz,String rksj) {
		PageInfo<StorageRotationWarning> pageInfo = null;
		try {
			if (pageNum != null && pageSize != null) {
	            PageHelper.startPage(pageNum, pageSize);
	        }
			List<StorageRotationWarning> list = yjbjService.queryYlwlList(orgId, ch, hwh, lspz, rksj);
			pageInfo = new PageInfo<>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return ResponseEntity.ok(pageInfo);
	}

	@RequestMapping(value = "queryById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "query"),
    })
    public ResponseEntity<StorageRotationWarningWithBLOBs> queryById(String id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            return ResponseEntity.ok(yjbjService.queryById(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
    }

	@RequestMapping(value="/editLhyj", method = RequestMethod.GET)
	@ApiOperation(value="预警报警数据更新", notes = "")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "lhyjJson", value = "数据对象", paramType = "form")
	})
	public ResponseEntity editLhyj(String lhyjJson) {
		try {
			if (StringUtils.isNotBlank(lhyjJson)) {
				StorageRotationWarningWithBLOBs storageRotationWarningWithBLOBs = JSONObject.parseObject(lhyjJson, StorageRotationWarningWithBLOBs.class);
                if (storageRotationWarningWithBLOBs.getId() == null) {
                    return ResponseEntity.failed("数据ID不能为空！");
                }

                yjbjService.updateDate(storageRotationWarningWithBLOBs);
            }
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			return ResponseEntity.ok(e.getMessage(), lhyjJson);
		}
		return ResponseEntity.ok();
	}

	@RequestMapping(value="/getJkqPageInfoList", method = RequestMethod.GET)
	@ApiOperation(value="架空期预警列表", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "orgId", value = "库ID", paramType = "query"),
        @ApiImplicitParam(name = "ch", value = "仓房ID", paramType = "query"),
        @ApiImplicitParam(name = "hwh", value = "货位ID", paramType = "query"),
        @ApiImplicitParam(name = "jhwh", value = "计划文号", paramType = "query"),
        @ApiImplicitParam(name = "lhnd", value = "轮换年度", paramType = "query")
	})
	public ResponseEntity<PageInfo<StorageJkqWarning>> getJkqPageInfoList(Integer pageNum, Integer pageSize, Integer orgId, 
			Integer ch, Integer hwh, String jhwh, String lhnd) {
		PageInfo<StorageJkqWarning> pageInfo = null;
		try {
			if (pageNum != null && pageSize != null) {
	            PageHelper.startPage(pageNum, pageSize);
	        }
			List<StorageJkqWarning> list = yjbjService.queryJkqyjList(orgId, ch, hwh, jhwh, lhnd);
			pageInfo = new PageInfo<>(list);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
		return ResponseEntity.ok(pageInfo);
	}

	@RequestMapping(value = "queryByIdJkq", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据id加载架空期数据", notes = "根据id加载架空期数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "query"),
    })
    public ResponseEntity<StorageJkqWarning> queryByIdJkq(String id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            return ResponseEntity.ok(yjbjService.queryByIdJkq(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
    }

	@RequestMapping(value="/editJkqyj", method = RequestMethod.GET)
	@ApiOperation(value="架空期预警数据更新", notes = "")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "jkqyjJson", value = "数据对象", paramType = "form")
	})
	public ResponseEntity editJkqyj(String jkqyjJson) {
		try {
			if (StringUtils.isNotBlank(jkqyjJson)) {
				StorageJkqWarning storageJkqWarning = JSONObject.parseObject(jkqyjJson, StorageJkqWarning.class);
                if (storageJkqWarning.getId() == null) {
                    return ResponseEntity.failed("数据ID不能为空！");
                }

                yjbjService.updateDate(storageJkqWarning);
            }
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			return ResponseEntity.ok(e.getMessage(), jkqyjJson);
		}
		return ResponseEntity.ok();
	}
}
