package com.chinaitop.depot.warningAndAlarm.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.chinaitop.depot.warningAndAlarm.common.StatusUtils;
import com.chinaitop.depot.warningAndAlarm.mapper.StorageJkqWarningMapper;
import com.chinaitop.depot.warningAndAlarm.mapper.StorageRotationWarningMapper;
import com.chinaitop.depot.warningAndAlarm.mapper.TimedTaskMapper;
import com.chinaitop.depot.warningAndAlarm.model.StorageJkqWarning;
import com.chinaitop.depot.warningAndAlarm.model.StorageJkqWarningExample;
import com.chinaitop.depot.warningAndAlarm.model.StorageRotationWarning;
import com.chinaitop.depot.warningAndAlarm.model.StorageRotationWarningExample;
import com.chinaitop.depot.warningAndAlarm.model.StorageRotationWarningExample.Criteria;
import com.chinaitop.depot.warningAndAlarm.model.StorageRotationWarningWithBLOBs;
import com.chinaitop.depot.warningAndAlarm.service.TimedTaskService;

@Service
public class TimedTaskServiceImpl implements TimedTaskService {

	@Resource
	private TimedTaskMapper timedTaskMapper;

	@Resource
	private StorageRotationWarningMapper storageRotationWarningMapper;

	@Resource
	private StorageJkqWarningMapper storageJkqWarningMapper;

	@Override
	public void insertYlwl() throws Exception {

		List<StorageRotationWarningWithBLOBs> list = timedTaskMapper.selectYlwl();

		if (null != list && list.size() > 0) {
			StorageRotationWarningWithBLOBs s = null;
			for (int i = 0; i < list.size(); i++) {
				s = list.get(i);
				boolean k = checkDataLhyjbj(s, "1");
				if (!k) {//如果有了，那就不在增加了，否则就重复报警了
					Date date = new Date();
					s.setScsj(date);
					s.setClzt(StatusUtils.STATUS_0);
					s.setUpdatetime(date);
					storageRotationWarningMapper.insert(s);
				}
			}
		}
	}

	/**
	 * 检查一条轮换预警数据是否已经存在
	 * @param rotationWarning 
	 * @param bjlx 报警类型(0:轮换预警,1:应轮未轮)
	 * @return
	 */
	private boolean checkDataLhyjbj(StorageRotationWarningWithBLOBs rotationWarning, String bjlx) {
		boolean b = false;
		StorageRotationWarningExample example = new StorageRotationWarningExample();
		Criteria criteria = example.createCriteria();
		criteria.andHwhEqualTo(rotationWarning.getHwh());
		criteria.andChEqualTo(rotationWarning.getCh());
		criteria.andZhycrqEqualTo(rotationWarning.getZhycrq());
		criteria.andBjlxEqualTo(bjlx);
		List<StorageRotationWarning> list = storageRotationWarningMapper.selectByExample(example);
		if (null != list && list.size() > 0) {
			b = true;
		}
		return b;
	}

	@Override
	public void insertLhyj() throws Exception {

		List<StorageRotationWarningWithBLOBs> list = timedTaskMapper.selectLhyj();

		if (null != list && list.size() > 0) {
			StorageRotationWarningWithBLOBs s = null;
			for (int i = 0; i < list.size(); i++) {
				s = list.get(i);
				boolean k = checkDataLhyjbj(s, "0");
				if (!k) {//如果有了，那就不在增加了，否则就重复报警了
					Date date = new Date();
					s.setScsj(date);
					s.setClzt(StatusUtils.STATUS_0);
					s.setUpdatetime(date);
					storageRotationWarningMapper.insert(s);
				}
			}
		}
	}

	@Override
	public void insertJkqyj() throws Exception {

		List<StorageJkqWarning> list = timedTaskMapper.selectJkqjyqzsj();

		if (null != list && list.size() > 0) {
			StorageJkqWarning s = null;
			for (int i = 0; i < list.size(); i++) {
				s = list.get(i);
				
				//查询架空期截止日期、架空期状态、报警日期
				s = selectJkqjyqtsj(s);

				boolean k = checkDataJkqyj(s);
				Date date = new Date();
				if (!k) {//如果有了，那就不在增加了，否则就重复报警了
					s.setScsj(date);
					s.setClzt(StatusUtils.STATUS_0);
					s.setUpdatetime(date);
					storageJkqWarningMapper.insert(s);
				} else {
					s.setUpdatetime(date);
					storageJkqWarningMapper.updateByPrimaryKey(s);
				}
			}
		}
	}

	/**
	 * 查询架空期截止日期、架空期状态、报警日期
	 * @param s
	 * @return
	 */
	private StorageJkqWarning selectJkqjyqtsj(StorageJkqWarning s) {
		
		//组装查询条件
		Map<String, String> map = new HashMap<>();
		map.put("hwh", s.getHwh().toString());
		map.put("startDate", s.getStartDate());
		map.put("endDate", s.getEndDate());

		//查询
		StorageJkqWarning sj = timedTaskMapper.selectJkqjyqtsj(map);

		if (null != sj) {
			s.setJkqjzr(sj.getJkqjzr());
			s.setJkqzt(sj.getJkqzt());
			s.setYjrq(sj.getYjrq());
		}

		return s;
	}

	/**
	 * 校验架空期数据是否已经存在
	 * 查询条件：仓房、货位、计划文号、轮换年度
	 * @param storageJkqWarning
	 * @return
	 */
	public boolean checkDataJkqyj(StorageJkqWarning storageJkqWarning) {

		boolean b = false;

		StorageJkqWarningExample example = new StorageJkqWarningExample();
		StorageJkqWarningExample.Criteria criteria = example.createCriteria();

		criteria.andHwhEqualTo(storageJkqWarning.getHwh());
		criteria.andChEqualTo(storageJkqWarning.getCh());
		criteria.andJhwhEqualTo(storageJkqWarning.getJhwh());
		criteria.andLhndEqualTo(storageJkqWarning.getLhnd());

		List<StorageJkqWarning> list = storageJkqWarningMapper.selectByExample(example);
		if (null != list && list.size() > 0) {
			b = true;
		}

		return b;
	}
}
